(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
Dispersion
:[font = subtitle; inactive; nohscroll; center; ]

(Advection Equation)
:[font = name; inactive; nohscroll; ]

                                   Victor G. Ganzha and Evgenii V. Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled
                                  V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]

Numerical Solutions For Partial Differential Equations: Problem Solving
Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = section; inactive; ]
Initialisation
:[font = input; nowordwrap; ]

Needs[Algebra`ReIm`]
:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program disp1.ma which follows below performs the dispersion 
analysis of scalar explicit two-level difference schemes approximat-
ing the one-dimensional advection equation. The description of the 
algorithm for dispersion analysis can  be  found in Section 3.8 of the 
above book.
:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]

Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

ClearAll[disp1];

:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the form of a difference scheme by modifying the body of the
function sch1 or sch2, see below Section "Examples of Difference
Schemes".
:[font = subsection; inactive; ]
Step 3
:[font = special4; inactive; nowordwrap; nohscroll; ]
Specify the form of the nondimensional variable kappa in terms of which 
the stability region is to be determined. The corresponding transformati-
on rule should follow the expression for the difference scheme (see exa-
mples below) and should  be in  the same cell as the difference scheme 
itself. Load and compile  the difference scheme together with the transf-
ormation rule.

:[font = subsection; inactive; ]
Step 4
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input data by entering them in the line (see Section
"Examples of the Input Data"):
:[font = input; nowordwrap; ]

disp1[5, -1.0, 1.0, sch1]
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line and wait for the result of symbolic computation. The
meaning of the input parameters is explained in the Section
"Parameters Used in Program disp1.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; ]

ClearAll[disp1, a, k];
disp1[kt_, cpl_, cpr_, sc_] := 
(
<< Algebra`ReIm`;
Print["The package Algebra`ReIm` is loaded"];
(* --- The variables xi, cp, dt, a, k are declared
                            to be real --------- *)
xi/: Im[xi] = 0;
cp/: Im[cp] = 0;
dt/: Im[dt] = 0;
a/: Im[a] = 0;
k/: Im[k] = 0;
Print["Determination of omega from the original PDE"];
(* ---- Substitution of a Fourier harmonic into
	the partial differential equation ------- *)
dif1 = D[Exp[I*k*x - I*omega*t], t] +
               a*D[Exp[I*k*x - I*omega*t], x];
OutputForm[dif1] >> dispres.m;

(* ---- Divide the both sides of obtained equation
           by Exp[I*(k*x - omega*t)] ----------- *)
dif1 = dif1/Exp[I*(k*x - omega*t)]; 
dif1 = Simplify[dif1];
OutputForm[dif1] >>> dispres.m;
sol0 = Solve[dif1==0, omega];
omega = omega /. sol0; omega = omega[[1]];
Print["omega = ", omega];
  OutputForm[omega] >>> dispres.m;
(* -- Calculation of the expression for the step 
  operator corresponding to the original PDE --- *)
S0 = Exp[I*(k*x-omega*(t+dt))]/Exp[I*(k*x-omega*t)];
S0 = Simplify[S0];
OutputForm[S0] >>> dispres.m;
ims0 = Im[S0];   res0 = Re[S0];
    OutputForm[ims0] >>> dispres.m;
           OutputForm[res0] >>> dispres.m;
Phi0 = ArcTan[ims0/res0];  Phi0 = Simplify[Phi0];
Phi0 = Phi0 /. cap;  Phi0 = Simplify[Phi0];
Print["Phi0 = ", Phi0];
     OutputForm[Phi0] >>> dispres.m;

(* ---- Substitution of a Fourier harmonic into
        the difference scheme ------------------ *)
  sc0 = sc/. cap;     
Print["The difference scheme under consideration"];
Print[sc0, " = 0"];
  sc0 >>> dispres.m;
  sc1 = sc0 /. {u[j_, n_] -> l^n*Exp[I*j*xi]};
(* -- Divide the both sides of obtained equation
           by l^n Exp[I*j*xi] ------------------ *)
      sc3 = sc1/(l^n*Exp[I*j*xi]) //Expand;
  sc2 = Simplify[sc3];
sol = Solve[sc2==0, l];
l1 = Simplify[l /. sol] ;
l4 = ComplexExpand[l1];                  
Print["The amplification factor of scheme has",
      " the form"];
Print["lambda = ", l4];
OutputForm[l4] >>> dispres.m;
rel = Re[l4] // Simplify;
iml = Im[l4] // Simplify;
OutputForm[rel] >>> dispres.m;
OutputForm[iml] >>> dispres.m;
          Print["Re(lambda) = ", rel];
          Print["Im(lambda) = ", iml];
Phih = ArcTan[iml/rel];
                         err = Phih - Phi0;
Print["The phase error = ", err];
tayl = Series[err, {xi, 0, kt}];  
tayl = Simplify[tayl];
Print["The expression for the dispersion error"];
Print["E(\kappa,\xi) obtained by the Taylor expansion "];
Print["around the point \xi = 0 has the form"];
Print["E(kappa, xi) = ", tayl];
                  OutputForm[tayl] >>> dispres.m;
gr1=Plot3D[err[[1]], {xi,0, 2 Pi}, {cp, cpl, cpr},
       AxesLabel -> {"xi", "kappa", "E"}];
Display["fig3_12b", gr1];
(* --------- End of the procedure disp1 -------- *)
	  )

:[font = section; inactive; ]
Parameters Used in Program disp1.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]

___________________________________________________
 Parameter                               Description  
___________________________________________________
kt                     the number of terms in the Tailor expansion of the
                        phase error err; kt > 1;
cpl                   the left end of the stability interval of the
                       difference scheme under consideration;
cpr                  the right end of the stability interval of the
                       difference scheme under consideration; cpl < cpr;
sc                   the left-hand side of the difference equation sc = 0.
 _____________________________________________________

:[font = section; inactive; ]
Examples of Difference Schemes

:[font = special4; inactive; nowordwrap; nohscroll; ]
Attention! Only the letter j can be used to denote the number of the grid 
node on the x-axis, and only the letter n can be used to denote the time 
level.

:[font = subsection; inactive; ]
Example 1
:[font = input; startGroup; nowordwrap; ]
ClearAll[sch1];
(*  The difference equation under consideration  *)
  sch1 =
(* The Lax-Wendroff scheme for advection equation*)
 ( ut = (u[j,n+1] - u[j,n])/dt;
            ux = (u[j + 1,n] - u[j - 1,n])/(2*h1);
uxx = (u[j+1,n] - 2*u[j, n] + u[j - 1, n])/(h1*h1);
                       ut + a*ux - dt/2*a^2*uxx  )
(* ---------- dt is the time step ------------- *)

(* - Transformation rule for the introduction of the
      nondimensional variable cp ----------- *)
      cap = {a -> cp*h1/dt, k -> xi/h1}

:[font = output; inactive; formatted; output; nowordwrap; ]
(-u[j, n] + u[j, 1 + n])/dt + 
  (a*(-u[-1 + j, n] + u[1 + j, n]))/(2*h1) - 
  (a^2*dt*(u[-1 + j, n] - 2*u[j, n] + u[1 + j, n]))/
   (2*h1^2)




;[o]
-u[j, n] + u[j, 1 + n]
---------------------- + 
          dt
 
 a (-u[-1 + j, n] + u[1 + j, n])
 ------------------------------- - 
              2 h1
 
  2
 a  dt (u[-1 + j, n] - 2 u[j, n] + u[1 + j, n])
 ----------------------------------------------
                         2
                     2 h1
:[font = output; inactive; formatted; output; endGroup; nowordwrap; ]
{a -> (cp*h1)/dt, k -> xi/h1}




;[o]
      cp h1       xi
{a -> -----, k -> --}
       dt         h1
:[font = subsection; inactive; ]
Example 2
:[font = input; nowordwrap; ]

(* ---- Scheme of Jameson (1981) for advection 
      equation (2.1.1) ----------------------- *)
ClearAll[sch2];
sch2 =
( ut1 = (u[j,n+1] - u[j,n])/dt +
          a*(u[j+1,n] - u[j-1,n])/(2*h1);
uxx = a^2*(u[j+2,n]-2*u[j,n]+u[j-2,n])*dt/(4*h1^2);
 ut1 - uxx )
(* --------- dt is the time step ------------- *)
 cap = {a -> cp*h1/dt, k -> xi/h1}


:[font = output; inactive; formatted; output; nowordwrap; ]
(-u[j, n] + u[j, 1 + n])/dt + 
  (a*(-u[-1 + j, n] + u[1 + j, n]))/(2*h1) - 
  (a^2*dt*(u[-2 + j, n] - 2*u[j, n] + u[2 + j, n]))/
   (4*h1^2)




;[o]
-u[j, n] + u[j, 1 + n]
---------------------- + 
          dt
 
 a (-u[-1 + j, n] + u[1 + j, n])
 ------------------------------- - 
              2 h1
 
  2
 a  dt (u[-2 + j, n] - 2 u[j, n] + u[2 + j, n])
 ----------------------------------------------
                         2
                     4 h1
:[font = output; inactive; formatted; output; nowordwrap; ]
{a -> (cp*h1)/dt, k -> xi/h1}




;[o]
      cp h1       xi
{a -> -----, k -> --}
       dt         h1
:[font = section; inactive; ]
Examples of the Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]

disp1[5, -1.0, 1.0, sch1]

:[font = print; inactive; formatted; output; nowordwrap; ]
No Input Form Generated



;[o]
The package Algebra`ReIm` is loaded
Determination of omega from the original PDE
omega = a k
Phi0 = -ArcTan[Tan[cp xi]]
The difference scheme under consideration
-u[j, n] + u[j, 1 + n]
---------------------- + 
          dt
 
  cp (-u[-1 + j, n] + u[1 + j, n])
  -------------------------------- - 
                2 dt
 
    2
  cp  (u[-1 + j, n] - 2 u[j, n] + u[1 + j, n])
  -------------------------------------------- = 0
                      2 dt
The amplification factor of scheme has the form
                2     2
lambda = {1 - cp  + cp  Cos[xi] - I cp Sin[xi]}
                    2     2
Re(lambda) = {1 - cp  + cp  Cos[xi]}
Im(lambda) = {-(cp Sin[xi])}
                                cp Sin[xi]
The phase error = {-ArcTan[---------------------] + 
                                 2     2
                           1 - cp  + cp  Cos[xi]
 
   ArcTan[Tan[cp xi]]}
The expression for the dispersion error
E(\kappa,\xi) obtained by the Taylor expansion 
around the point \xi = 0 has the form
                        3
                 cp   cp     3
E(kappa, xi) = {(-- - ---) xi  + 
                 6     6
 
                2       4    5
   cp (-1 - 5 cp  + 6 cp ) xi         6
   --------------------------- + O[xi] }
               120
:[font = postscript; inactive; output; BITMAP; PostScript; pictureLeft = 100; pictureTop = 0; pictureWidth = 300; pictureHeight = 246; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: .82055 
MathPictureStart
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0249355 0.99742 -0.0396341 0.99742 [
[(0)] .05113 .25884 1 .93395 Msboxa
[(2)] .23273 .18737 .938 1 Msboxa
[(4)] .42876 .11027 .80527 1 Msboxa
[(6)] .64102 .02686 .67254 1 Msboxa
[(xi)] .30204 .09689 .86223 1 Msboxa
[(-1)] .69093 .02039 -1 .39157 Msboxa
[(-0.5)] .76901 .13994 -1 .36413 Msboxa
[(0)] .83872 .24668 -1 .34028 Msboxa
[(0.5)] .90133 .34257 -1 .31937 Msboxa
[(1)] .95788 .42917 -1 .30087 Msboxa
[(kappa)] .89773 .2266 -1 .34028 Msboxa
[(-2)] .04326 .30559 1 -0.38491 Msboxa
[(0)] .03155 .37899 1 -0.37036 Msboxa
[(2)] .01924 .45613 1 -0.35498 Msboxa
[(E)] -0.02691 .40064 1 -0.37036 Msboxa
[ 0 0 0 0 ]
[ 1 .82055 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06024 .26735 m
.67932 .02494 L
s
P
p
.002 w
.06024 .26735 m
.0648 .2716 L
s
P
[(0)] .05113 .25884 1 .93395 Mshowa
p
.002 w
.24126 .19647 m
.24553 .20101 L
s
P
[(2)] .23273 .18737 .938 1 Mshowa
p
.002 w
.43658 .11999 m
.44049 .12484 L
s
P
[(4)] .42876 .11027 .80527 1 Mshowa
p
.002 w
.64798 .03721 m
.65146 .04238 L
s
P
[(6)] .64102 .02686 .67254 1 Mshowa
p
.001 w
.09538 .25359 m
.09808 .25618 L
s
P
p
.001 w
.13104 .23963 m
.1337 .24225 L
s
P
p
.001 w
.16723 .22546 m
.16986 .22811 L
s
P
p
.001 w
.20396 .21107 m
.20656 .21376 L
s
P
p
.001 w
.27913 .18164 m
.28165 .1844 L
s
P
p
.001 w
.31758 .16658 m
.32006 .16938 L
s
P
p
.001 w
.35663 .15129 m
.35907 .15413 L
s
P
p
.001 w
.39629 .13576 m
.39869 .13864 L
s
P
p
.001 w
.47752 .10396 m
.47981 .10691 L
s
P
p
.001 w
.5191 .08767 m
.52135 .09066 L
s
P
p
.001 w
.56137 .07112 m
.56356 .07415 L
s
P
p
.001 w
.60432 .05431 m
.60646 .05737 L
s
P
[(xi)] .30204 .09689 .86223 1 Mshowa
P
p
p
.002 w
.67932 .02494 m
.94594 .43277 L
s
P
p
.002 w
.67932 .02494 m
.67352 .02721 L
s
P
[(-1)] .69093 .02039 -1 .39157 Mshowa
p
.002 w
.7573 .14421 m
.75144 .14634 L
s
P
[(-0.5)] .76901 .13994 -1 .36413 Mshowa
p
.002 w
.82692 .2507 m
.82101 .25271 L
s
P
[(0)] .83872 .24668 -1 .34028 Mshowa
p
.002 w
.88945 .34636 m
.88352 .34826 L
s
P
[(0.5)] .90133 .34257 -1 .31937 Mshowa
p
.002 w
.94594 .43277 m
.93997 .43456 L
s
P
[(1)] .95788 .42917 -1 .30087 Mshowa
p
.001 w
.69566 .04992 m
.69217 .05127 L
s
P
p
.001 w
.71161 .07432 m
.70811 .07565 L
s
P
p
.001 w
.72719 .09816 m
.72369 .09947 L
s
P
p
.001 w
.74242 .12145 m
.73891 .12274 L
s
P
p
.001 w
.77184 .16646 m
.76832 .16772 L
s
P
p
.001 w
.78607 .18822 m
.78254 .18947 L
s
P
p
.001 w
.79998 .2095 m
.79645 .21074 L
s
P
p
.001 w
.81359 .23032 m
.81006 .23154 L
s
P
p
.001 w
.83995 .27064 m
.83641 .27183 L
s
P
p
.001 w
.85272 .29017 m
.84917 .29135 L
s
P
p
.001 w
.86522 .30929 m
.86166 .31045 L
s
P
p
.001 w
.87746 .32802 m
.8739 .32917 L
s
P
p
.001 w
.90121 .36434 m
.89764 .36546 L
s
P
p
.001 w
.91272 .38196 m
.90915 .38307 L
s
P
p
.001 w
.92402 .39923 m
.92044 .40033 L
s
P
p
.001 w
.93508 .41616 m
.93151 .41725 L
s
P
[(kappa)] .89773 .2266 -1 .34028 Mshowa
P
p
p
.002 w
.06024 .26735 m
.02494 .49015 L
s
P
p
.002 w
.05489 .30111 m
.06071 .29887 L
s
P
[(-2)] .04326 .30559 1 -0.38491 Mshowa
p
.002 w
.04324 .37466 m
.04908 .37249 L
s
P
[(0)] .03155 .37899 1 -0.37036 Mshowa
p
.002 w
.03099 .45196 m
.03686 .44987 L
s
P
[(2)] .01924 .45613 1 -0.35498 Mshowa
p
.001 w
.05261 .31553 m
.0561 .3142 L
s
P
p
.001 w
.0503 .3301 m
.0538 .32877 L
s
P
p
.001 w
.04797 .34481 m
.05147 .34349 L
s
P
p
.001 w
.04561 .35966 m
.04912 .35835 L
s
P
p
.001 w
.04084 .38981 m
.04435 .38852 L
s
P
p
.001 w
.03841 .40511 m
.04193 .40383 L
s
P
p
.001 w
.03596 .42057 m
.03948 .4193 L
s
P
p
.001 w
.03349 .43618 m
.03701 .43492 L
s
P
p
.001 w
.05716 .28683 m
.06064 .28548 L
s
P
p
.001 w
.0594 .27268 m
.06288 .27132 L
s
P
p
.001 w
.02846 .46789 m
.03199 .46665 L
s
P
p
.001 w
.02591 .48399 m
.02944 .48276 L
s
P
[(E)] -0.02691 .40064 1 -0.37036 Mshowa
P
0 0 m
1 0 L
1 .82055 L
0 .82055 L
closepath
clip
newpath
p
.002 w
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.40296 .79562 L
s
.40296 .79562 m
.41001 .59401 L
s
.41001 .59401 m
.06024 .26735 L
s
.67932 .02494 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.67932 .02494 m
.06024 .26735 L
s
.41001 .59401 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.40296 .79562 L
s
.40296 .79562 m
.41001 .59401 L
s
P
p
.655 .751 .921 r
.0015 w
.38505 .67298 .40659 .69179 .44251 .68166 .42128 .6627 Metetra
.648 .751 .924 r
.42128 .6627 .44251 .68166 .47894 .67139 .45802 .65281 Metetra
.641 .755 .932 r
.45802 .65281 .47894 .67139 .51588 .66097 .49531 .64334 Metetra
.64 .768 .941 r
.49531 .64334 .51588 .66097 .55336 .65041 .53316 .63361 Metetra
.658 .785 .942 r
.53316 .63361 .55336 .65041 .59138 .63969 .57158 .62203 Metetra
.707 .791 .916 r
.57158 .62203 .59138 .63969 .62995 .62881 .61042 .60549 Metetra
.752 .752 .852 r
.61042 .60549 .62995 .62881 .66909 .61778 .64941 .58119 Metetra
.721 .664 .793 r
.64941 .58119 .66909 .61778 .7088 .60658 .68867 .55673 Metetra
.665 .59 .761 r
.68867 .55673 .7088 .60658 .74911 .59522 .72868 .5396 Metetra
0 0 .487 r
.72868 .5396 .74911 .59522 .79003 .58368 .77832 .64085 Metetra
.475 .146 .328 r
.77832 .64085 .79003 .58368 .83156 .57197 .8215 .63033 Metetra
.478 .151 .333 r
.8215 .63033 .83156 .57197 .87373 .56008 .86541 .61977 Metetra
0 0 .045 r
.86541 .61977 .87373 .56008 .91654 .54801 .89633 .49298 Metetra
.638 .567 .759 r
.89633 .49298 .91654 .54801 .96002 .53575 .93984 .48036 Metetra
.654 .751 .921 r
.36293 .65367 .38505 .67298 .42128 .6627 .39948 .64318 Metetra
.643 .749 .926 r
.39948 .64318 .42128 .6627 .45802 .65281 .43654 .63344 Metetra
.627 .749 .934 r
.43654 .63344 .45802 .65281 .49531 .64334 .47416 .62487 Metetra
.609 .755 .948 r
.47416 .62487 .49531 .64334 .53316 .63361 .51238 .61734 Metetra
.928 .763 .657 r
.51238 .61734 .53316 .63361 .57158 .62203 .55034 .50239 Metetra
.596 .452 .656 r
.55034 .50239 .57158 .62203 .61042 .60549 .58859 .49454 Metetra
.393 .321 .656 r
.58859 .49454 .61042 .60549 .64941 .58119 .62938 .54396 Metetra
0 .099 .655 r
.62938 .54396 .64941 .58119 .68867 .55673 .67245 .59613 Metetra
.438 .058 .218 r
.67245 .59613 .68867 .55673 .72868 .5396 .71429 .58861 Metetra
.468 .115 .284 r
.71429 .58861 .72868 .5396 .77832 .64085 .75691 .58111 Metetra
.615 .545 .752 r
.75691 .58111 .77832 .64085 .8215 .63033 .80026 .57268 Metetra
.622 .555 .759 r
.80026 .57268 .8215 .63033 .86541 .61977 .84428 .56284 Metetra
.629 .563 .761 r
.84428 .56284 .86541 .61977 .89633 .49298 .88892 .55142 Metetra
.462 .133 .321 r
.88892 .55142 .89633 .49298 .93984 .48036 .93418 .53882 Metetra
.654 .751 .921 r
.34022 .63385 .36293 .65367 .39948 .64318 .37709 .62309 Metetra
.642 .748 .926 r
.37709 .62309 .39948 .64318 .43654 .63344 .41448 .61324 Metetra
.62 .743 .935 r
.41448 .61324 .43654 .63344 .47416 .62487 .45242 .60501 Metetra
.588 .739 .948 r
.45242 .60501 .47416 .62487 .51238 .61734 .49097 .59891 Metetra
.526 .734 .97 r
.49097 .59891 .51238 .61734 .55034 .50239 .53025 .59608 Metetra
.553 .258 .421 r
.53025 .59608 .55034 .50239 .58859 .49454 .57044 .60023 Metetra
.094 0 .281 r
.57044 .60023 .58859 .49454 .62938 .54396 .60899 .50605 Metetra
.367 .485 .847 r
.60899 .50605 .62938 .54396 .67245 .59613 .65051 .52315 Metetra
.557 .481 .724 r
.65051 .52315 .67245 .59613 .71429 .58861 .69269 .52643 Metetra
.59 .524 .749 r
.69269 .52643 .71429 .58861 .75691 .58111 .7355 .52272 Metetra
.607 .545 .759 r
.7355 .52272 .75691 .58111 .80026 .57268 .77894 .51549 Metetra
.619 .556 .762 r
.77894 .51549 .80026 .57268 .84428 .56284 .82301 .50576 Metetra
.628 .563 .762 r
.82301 .50576 .84428 .56284 .88892 .55142 .86768 .494 Metetra
.634 .567 .762 r
.86768 .494 .88892 .55142 .93418 .53882 .91297 .48089 Metetra
.654 .751 .921 r
.31689 .61349 .34022 .63385 .37709 .62309 .3541 .60241 Metetra
.642 .748 .925 r
.3541 .60241 .37709 .62309 .41448 .61324 .39182 .59219 Metetra
.622 .741 .932 r
.39182 .59219 .41448 .61324 .45242 .60501 .4301 .58359 Metetra
.591 .73 .94 r
.4301 .58359 .45242 .60501 .49097 .59891 .46898 .57727 Metetra
.545 .713 .95 r
.46898 .57727 .49097 .59891 .53025 .59608 .50858 .57407 Metetra
.475 .682 .957 r
.50858 .57407 .53025 .59608 .57044 .60023 .54905 .57513 Metetra
.428 .631 .939 r
.54905 .57513 .57044 .60023 .60899 .50605 .59057 .58036 Metetra
.546 .223 .372 r
.59057 .58036 .60899 .50605 .65051 .52315 .63321 .58572 Metetra
.63321 .58572 .65051 .52315 .69269 .52643 .67134 .47102 Metetra
.591 .543 .77 r
.67134 .47102 .69269 .52643 .7355 .52272 .71409 .4666 Metetra
.608 .553 .767 r
.71409 .4666 .7355 .52272 .77894 .51549 .75752 .45885 Metetra
.62 .56 .765 r
.75752 .45885 .77894 .51549 .82301 .50576 .80158 .44849 Metetra
.629 .564 .763 r
.80158 .44849 .82301 .50576 .86768 .494 .84625 .43611 Metetra
.634 .567 .762 r
.84625 .43611 .86768 .494 .91297 .48089 .89157 .42246 Metetra
.654 .751 .921 r
.29291 .59257 .31689 .61349 .3541 .60241 .33046 .58113 Metetra
.646 .748 .924 r
.33046 .58113 .3541 .60241 .39182 .59219 .36854 .57031 Metetra
.63 .741 .928 r
.36854 .57031 .39182 .59219 .4301 .58359 .40718 .56074 Metetra
.609 .728 .93 r
.40718 .56074 .4301 .58359 .46898 .57727 .44642 .55287 Metetra
.585 .708 .928 r
.44642 .55287 .46898 .57727 .50858 .57407 .48635 .547 Metetra
.565 .68 .917 r
.48635 .547 .50858 .57407 .54905 .57513 .52707 .54316 Metetra
.559 .642 .888 r
.52707 .54316 .54905 .57513 .59057 .58036 .56869 .5407 Metetra
.57 .601 .845 r
.56869 .5407 .59057 .58036 .63321 .58572 .61124 .53818 Metetra
.584 .574 .808 r
.61124 .53818 .63321 .58572 .67134 .47102 .65469 .53411 Metetra
.476 .134 .306 r
.65469 .53411 .67134 .47102 .71409 .4666 .69899 .52772 Metetra
.46 .115 .293 r
.69899 .52772 .71409 .4666 .75752 .45885 .74405 .51893 Metetra
.446 .101 .285 r
.74405 .51893 .75752 .45885 .80158 .44849 .78983 .50797 Metetra
.78983 .50797 .80158 .44849 .84625 .43611 .82465 .37775 Metetra
.634 .567 .762 r
.82465 .37775 .84625 .43611 .89157 .42246 .86998 .36351 Metetra
.655 .751 .921 r
.26827 .57106 .29291 .59257 .33046 .58113 .30616 .55924 Metetra
.65 .749 .922 r
.30616 .55924 .33046 .58113 .36854 .57031 .34461 .54766 Metetra
.642 .743 .922 r
.34461 .54766 .36854 .57031 .40718 .56074 .38364 .53667 Metetra
.633 .731 .919 r
.38364 .53667 .40718 .56074 .44642 .55287 .42327 .52649 Metetra
.623 .711 .909 r
.42327 .52649 .44642 .55287 .48635 .547 .46357 .51717 Metetra
.617 .684 .891 r
.46357 .51717 .48635 .547 .52707 .54316 .50459 .50855 Metetra
.613 .653 .865 r
.50459 .50855 .52707 .54316 .56869 .5407 .54638 .50028 Metetra
.613 .622 .836 r
.54638 .50028 .56869 .5407 .61124 .53818 .58898 .49184 Metetra
.615 .597 .81 r
.58898 .49184 .61124 .53818 .65469 .53411 .63238 .48273 Metetra
.618 .582 .791 r
.63238 .48273 .65469 .53411 .69899 .52772 .67658 .47255 Metetra
.621 .573 .778 r
.67658 .47255 .69899 .52772 .74405 .51893 .72155 .4611 Metetra
.625 .568 .77 r
.72155 .4611 .74405 .51893 .78983 .50797 .76726 .44841 Metetra
.628 .567 .766 r
.76726 .44841 .78983 .50797 .82465 .37775 .81372 .43466 Metetra
.412 .058 .252 r
.81372 .43466 .82465 .37775 .86998 .36351 .86093 .42021 Metetra
.656 .751 .92 r
.24293 .54895 .26827 .57106 .30616 .55924 .28117 .5367 Metetra
.656 .751 .92 r
.28117 .5367 .30616 .55924 .34461 .54766 .32001 .52427 Metetra
.656 .746 .916 r
.32001 .52427 .34461 .54766 .38364 .53667 .35946 .51164 Metetra
.656 .735 .908 r
.35946 .51164 .38364 .53667 .42327 .52649 .39953 .49881 Metetra
.656 .717 .894 r
.39953 .49881 .42327 .52649 .46357 .51717 .44024 .48578 Metetra
.654 .692 .874 r
.44024 .48578 .46357 .51717 .50459 .50855 .48161 .47253 Metetra
.651 .665 .85 r
.48161 .47253 .50459 .50855 .54638 .50028 .52365 .45908 Metetra
.646 .637 .827 r
.52365 .45908 .54638 .50028 .58898 .49184 .56637 .4454 Metetra
.642 .613 .806 r
.56637 .4454 .58898 .49184 .63238 .48273 .6098 .43149 Metetra
.637 .595 .79 r
.6098 .43149 .63238 .48273 .67658 .47255 .65395 .41736 Metetra
.634 .581 .778 r
.65395 .41736 .67658 .47255 .72155 .4611 .69884 .40299 Metetra
.632 .573 .77 r
.69884 .40299 .72155 .4611 .76726 .44841 .74449 .38837 Metetra
.631 .568 .766 r
.74449 .38837 .76726 .44841 .81372 .43466 .79092 .37351 Metetra
.631 .567 .764 r
.79092 .37351 .81372 .43466 .86093 .42021 .83815 .35839 Metetra
.657 .752 .92 r
.21687 .5262 .24293 .54895 .28117 .5367 .25546 .51352 Metetra
.661 .752 .918 r
.25546 .51352 .28117 .5367 .32001 .52427 .2947 .50021 Metetra
.669 .75 .911 r
.2947 .50021 .32001 .52427 .35946 .51164 .3346 .48591 Metetra
.677 .741 .899 r
.3346 .48591 .35946 .51164 .39953 .49881 .37515 .47038 Metetra
.683 .726 .882 r
.37515 .47038 .39953 .49881 .44024 .48578 .41633 .4536 Metetra
.686 .703 .861 r
.41633 .4536 .44024 .48578 .48161 .47253 .45811 .43571 Metetra
.683 .677 .838 r
.45811 .43571 .48161 .47253 .52365 .45908 .50047 .41707 Metetra
.675 .65 .817 r
.50047 .41707 .52365 .45908 .56637 .4454 .54339 .39818 Metetra
.666 .625 .799 r
.54339 .39818 .56637 .4454 .6098 .43149 .5869 .37954 Metetra
.656 .604 .785 r
.5869 .37954 .6098 .43149 .65395 .41736 .63105 .36152 Metetra
.646 .588 .775 r
.63105 .36152 .65395 .41736 .69884 .40299 .6759 .34427 Metetra
.639 .576 .768 r
.6759 .34427 .69884 .40299 .74449 .38837 .7215 .32776 Metetra
.634 .57 .765 r
.7215 .32776 .74449 .38837 .79092 .37351 .76791 .31179 Metetra
.631 .567 .764 r
.76791 .31179 .79092 .37351 .83815 .35839 .81516 .29599 Metetra
.657 .752 .92 r
.19004 .50278 .21687 .5262 .25546 .51352 .22899 .48967 Metetra
.665 .753 .916 r
.22899 .48967 .25546 .51352 .2947 .50021 .26864 .47553 Metetra
.679 .753 .907 r
.26864 .47553 .2947 .50021 .3346 .48591 .309 .45972 Metetra
.694 .748 .893 r
.309 .45972 .3346 .48591 .37515 .47038 .35006 .44178 Metetra
.707 .737 .874 r
.35006 .44178 .37515 .47038 .41633 .4536 .39178 .42142 Metetra
.716 .718 .851 r
.39178 .42142 .41633 .4536 .45811 .43571 .43406 .39868 Metetra
.715 .692 .827 r
.43406 .39868 .45811 .43571 .50047 .41707 .47683 .37424 Metetra
.704 .662 .806 r
.47683 .37424 .50047 .41707 .54339 .39818 .52003 .34956 Metetra
.687 .633 .789 r
.52003 .34956 .54339 .39818 .5869 .37954 .56367 .32607 Metetra
.67 .608 .777 r
.56367 .32607 .5869 .37954 .63105 .36152 .60786 .30443 Metetra
.655 .591 .77 r
.60786 .30443 .63105 .36152 .6759 .34427 .6527 .28466 Metetra
.644 .578 .766 r
.6527 .28466 .6759 .34427 .7215 .32776 .69829 .26649 Metetra
0 0 .497 r
.69829 .26649 .7215 .32776 .76791 .31179 .75377 .36883 Metetra
.367 0 .192 r
.75377 .36883 .76791 .31179 .81516 .29599 .80307 .35274 Metetra
.658 .752 .919 r
.16241 .47867 .19004 .50278 .22899 .48967 .20174 .46512 Metetra
.668 .754 .915 r
.20174 .46512 .22899 .48967 .26864 .47553 .24179 .45029 Metetra
.685 .756 .905 r
.24179 .45029 .26864 .47553 .309 .45972 .28261 .43337 Metetra
.704 .755 .891 r
.28261 .43337 .309 .45972 .35006 .44178 .32419 .4137 Metetra
.726 .75 .872 r
.32419 .4137 .35006 .44178 .39178 .42142 .36647 .39048 Metetra
.746 .739 .846 r
.36647 .39048 .39178 .42142 .43406 .39868 .40938 .36266 Metetra
.755 .715 .815 r
.40938 .36266 .43406 .39868 .47683 .37424 .45273 .33056 Metetra
.737 .675 .79 r
.45273 .33056 .47683 .37424 .52003 .34956 .4963 .29829 Metetra
0 0 .354 r
.4963 .29829 .52003 .34956 .56367 .32607 .54078 .38717 Metetra
.287 0 .16 r
.54078 .38717 .56367 .32607 .60786 .30443 .58683 .3624 Metetra
.306 0 .157 r
.58683 .3624 .60786 .30443 .6527 .28466 .63354 .34082 Metetra
.321 0 .156 r
.63354 .34082 .6527 .28466 .69829 .26649 .68103 .32154 Metetra
.334 0 .157 r
.68103 .32154 .69829 .26649 .75377 .36883 .72941 .30391 Metetra
.627 .566 .767 r
.72941 .30391 .75377 .36883 .80307 .35274 .77872 .28711 Metetra
.658 .752 .919 r
.13396 .45384 .16241 .47867 .20174 .46512 .17365 .43987 Metetra
.669 .754 .914 r
.17365 .43987 .20174 .46512 .24179 .45029 .2141 .42453 Metetra
.686 .758 .906 r
.2141 .42453 .24179 .45029 .28261 .43337 .25536 .40709 Metetra
.705 .762 .896 r
.25536 .40709 .28261 .43337 .32419 .4137 .29739 .387 Metetra
.73 .767 .883 r
.29739 .387 .32419 .4137 .36647 .39048 .34019 .36317 Metetra
.771 .774 .855 r
.34019 .36317 .36647 .39048 .40938 .36266 .3838 .33192 Metetra
.766 .309 0 r
.3838 .33192 .40938 .36266 .45273 .33056 .42429 .40439 Metetra
.106 0 .106 r
.42429 .40439 .45273 .33056 .4963 .29829 .47025 .35657 Metetra
.172 0 .079 r
.47025 .35657 .4963 .29829 .54078 .38717 .51599 .32406 Metetra
.67 .59 .757 r
.51599 .32406 .54078 .38717 .58683 .3624 .56212 .29871 Metetra
.653 .581 .761 r
.56212 .29871 .58683 .3624 .63354 .34082 .60889 .27663 Metetra
.642 .575 .764 r
.60889 .27663 .63354 .34082 .68103 .32154 .65641 .25668 Metetra
.633 .57 .766 r
.65641 .25668 .68103 .32154 .72941 .30391 .70481 .23833 Metetra
.627 .566 .766 r
.70481 .23833 .72941 .30391 .77872 .28711 .75414 .22083 Metetra
.658 .752 .919 r
.10464 .42825 .13396 .45384 .17365 .43987 .1447 .41387 Metetra
.667 .754 .915 r
.1447 .41387 .17365 .43987 .2141 .42453 .18552 .39828 Metetra
.68 .759 .911 r
.18552 .39828 .2141 .42453 .25536 .40709 .22715 .38103 Metetra
.692 .767 .909 r
.22715 .38103 .25536 .40709 .29739 .387 .26952 .36226 Metetra
.905 .492 .148 r
.26952 .36226 .29739 .387 .34019 .36317 .30392 .46521 Metetra
.381 .05 .274 r
.30392 .46521 .34019 .36317 .3838 .33192 .3493 .44532 Metetra
0 0 .118 r
.3493 .44532 .3838 .33192 .42429 .40439 .39814 .35832 Metetra
.861 .715 .699 r
.39814 .35832 .42429 .40439 .47025 .35657 .4456 .27379 Metetra
.626 .521 .714 r
.4456 .27379 .47025 .35657 .51599 .32406 .49105 .25294 Metetra
.64 .554 .742 r
.49105 .25294 .51599 .32406 .56212 .29871 .53716 .23162 Metetra
.642 .566 .755 r
.53716 .23162 .56212 .29871 .60889 .27663 .58397 .21079 Metetra
.638 .569 .761 r
.58397 .21079 .60889 .27663 .65641 .25668 .63154 .1909 Metetra
.632 .568 .765 r
.63154 .1909 .65641 .25668 .70481 .23833 .67997 .17207 Metetra
.627 .566 .766 r
.67997 .17207 .70481 .23833 .75414 .22083 .72931 .15391 Metetra
.657 .752 .92 r
.07442 .40187 .10464 .42825 .1447 .41387 .11483 .38711 Metetra
.663 .754 .918 r
.11483 .38711 .1447 .41387 .18552 .39828 .156 .37152 Metetra
.669 .759 .918 r
.156 .37152 .18552 .39828 .22715 .38103 .19793 .35504 Metetra
.668 .768 .925 r
.19793 .35504 .22715 .38103 .26952 .36226 .24054 .33843 Metetra
.648 .785 .947 r
.24054 .33843 .26952 .36226 .30392 .46521 .2837 .32338 Metetra
.554 .407 .636 r
.2837 .32338 .30392 .46521 .3493 .44532 .32731 .31326 Metetra
.528 .397 .646 r
.32731 .31326 .3493 .44532 .39814 .35832 .37143 .31128 Metetra
.521 .583 .858 r
.37143 .31128 .39814 .35832 .4456 .27379 .4168 .30924 Metetra
.242 0 0 r
.4168 .30924 .4456 .27379 .49105 .25294 .46362 .29856 Metetra
.914 .884 .461 r
.46362 .29856 .49105 .25294 .53716 .23162 .51202 .16231 Metetra
.627 .554 .753 r
.51202 .16231 .53716 .23162 .58397 .21079 .55882 .14346 Metetra
.631 .563 .76 r
.55882 .14346 .58397 .21079 .63154 .1909 .60642 .12416 Metetra
0 0 .467 r
.60642 .12416 .63154 .1909 .67997 .17207 .66062 .22581 Metetra
.28 0 .077 r
.66062 .22581 .67997 .17207 .72931 .15391 .71221 .20734 Metetra
.656 .751 .92 r
.04324 .37466 .07442 .40187 .11483 .38711 .08401 .35956 Metetra
.656 .752 .921 r
.08401 .35956 .11483 .38711 .156 .37152 .12549 .3442 Metetra
.656 .758 .925 r
.12549 .3442 .156 .37152 .19793 .35504 .16769 .32857 Metetra
.656 .768 .932 r
.16769 .32857 .19793 .35504 .24054 .33843 .21064 .31266 Metetra
.656 .778 .938 r
.21064 .31266 .24054 .33843 .2837 .32338 .25435 .29647 Metetra
.656 .773 .935 r
.25435 .29647 .2837 .32338 .32731 .31326 .29885 .27999 Metetra
.654 .729 .904 r
.29885 .27999 .32731 .31326 .37143 .31128 .34415 .26321 Metetra
.641 .641 .834 r
.34415 .26321 .37143 .31128 .4168 .30924 .39028 .24613 Metetra
.624 .576 .78 r
.39028 .24613 .4168 .30924 .46362 .29856 .43726 .22873 Metetra
.618 .555 .761 r
.43726 .22873 .46362 .29856 .51202 .16231 .48512 .211 Metetra
.228 0 .004 r
.48512 .211 .51202 .16231 .55882 .14346 .53388 .19295 Metetra
.234 0 .014 r
.53388 .19295 .55882 .14346 .60642 .12416 .58356 .17455 Metetra
.241 0 .025 r
.58356 .17455 .60642 .12416 .66062 .22581 .6342 .15579 Metetra
.621 .564 .769 r
.6342 .15579 .66062 .22581 .71221 .20734 .68581 .13668 Metetra
P
p
.002 w
.67932 .02494 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.67932 .02494 m
.06024 .26735 L
s
P
p
p
.002 w
.06024 .26735 m
.67932 .02494 L
s
P
p
.002 w
.06024 .26735 m
.0648 .2716 L
s
P
[(0)] .05113 .25884 1 .93395 Mshowa
p
.002 w
.24126 .19647 m
.24553 .20101 L
s
P
[(2)] .23273 .18737 .938 1 Mshowa
p
.002 w
.43658 .11999 m
.44049 .12484 L
s
P
[(4)] .42876 .11027 .80527 1 Mshowa
p
.002 w
.64798 .03721 m
.65146 .04238 L
s
P
[(6)] .64102 .02686 .67254 1 Mshowa
p
.001 w
.09538 .25359 m
.09808 .25618 L
s
P
p
.001 w
.13104 .23963 m
.1337 .24225 L
s
P
p
.001 w
.16723 .22546 m
.16986 .22811 L
s
P
p
.001 w
.20396 .21107 m
.20656 .21376 L
s
P
p
.001 w
.27913 .18164 m
.28165 .1844 L
s
P
p
.001 w
.31758 .16658 m
.32006 .16938 L
s
P
p
.001 w
.35663 .15129 m
.35907 .15413 L
s
P
p
.001 w
.39629 .13576 m
.39869 .13864 L
s
P
p
.001 w
.47752 .10396 m
.47981 .10691 L
s
P
p
.001 w
.5191 .08767 m
.52135 .09066 L
s
P
p
.001 w
.56137 .07112 m
.56356 .07415 L
s
P
p
.001 w
.60432 .05431 m
.60646 .05737 L
s
P
[(xi)] .30204 .09689 .86223 1 Mshowa
P
% End of Graphics
MathPictureEnd
:[font = subsection; inactive; ]
Example 2
:[font = input; nowordwrap; ]

disp1[5, -.5, .5, sch1]

:[font = subsection; inactive; ]
Example 3
:[font = input; nowordwrap; ]

disp1[5, -1.0, 1.0, sch2]

:[font = subsection; inactive; ]
Example 4
:[font = input; nowordwrap; ]

disp1[5, -.5, .5, sch2]

:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]

The following data are printed out in the process of the work of the program:

1. The symbolic expression for the wave frequency omega corresponding to
     the original PDE;

2. The exact phase shift Phi0 during the time dt (see equation (3.8.6)) comp-
     uted from the original PDE;

3. The difference scheme under consideration;

4. The symbolic expression for the amplification factor lambda for a given
     difference scheme;

5. The real part rel = Re(lambda) and iml = Im(lambda) of the amplification
     factor lambda;

6. The expression for the phase error  (3.8.9) of a given difference scheme;

7. The expression for the dispersion error E(kappa, xi) obtained by the Tay-
     lor expansion around the point xi = 0;

8. The surface E = E(kappa, xi).   

^*)