(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
Finite Element Method
:[font = name; inactive; nohscroll; ]

                                     Victor G.Ganzha and Evgenii V.Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

  This Mathematica-Notebook is part of the book entitled

                                 V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The  program fem1.ma which follows below solves numerically the Poisson
equation  u_{xx} + u_{yy} - 2 = 0 by the finite element method in the rectan-
gular region   -Pi/2 < x,y < Pi/2.  The algebraic system arising in the result
of finite element discretization is solved with the aid of the SOR method.

:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]

Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

          ClearAll[uex, fem1];
:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input data by entering them in the line (see also Section
"Examples of Input Data")
:[font = input; nowordwrap; ]

fem1[15, 15, 1.5, 10^(-5), 1.3, -2.4, 2.0]
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line, press Shift + Enter and wait for the result of numerical
computation.The meaning of the input parameters is explained in Section
"Parameters Used in Program fem1.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; bold; fontName = "Courier New"; fontSize = 12; ]
 
ClearAll[uex, fem1];
 uex[x_, y_] :=
(* --- The function to compute the exact solution
       of the Poisson equation ---------------- *)
( z1 = zpi + x*x; z0 = -1.0; z2 = 0.0;
  Do[ z0 = -z0; k1 = 2*k - 1;
      zk = N[Cosh[k1*y]*Cos[k1*x]/Cosh[k1*Pi/2]];
  zk = z0*zk/(k1^3); z2 = z2 + zk, {k, nt}];
  z1 = z1 + zk1*z2; z1 )

fem1[M1_, M2_, sor_, TOL_, xview_, yview_, zview_]:=
(
(* -- Computation of the mesh steps h1 and h2 -- *)
  m1m = M1 - 1; m2m = M2 - 1; n = 0;
  dr = N[Pi]; h1 = dr/m1m; h2 = dr/m2m;
(* -- Specification of the initial iteration 
    u^{(0)}(x, y)-- *)
     v = Table[0.0, {i, M1}, {j, M2}];
                vp = Table[0.0, {i, M1}, {j, M2}];
cel = h1/h2; c1 = 1/(2*(1 + cel^2)); cel2 = cel^2;
        h12 = 2*h1^2;  h1q = h1^2; h2q = h2^2;
  xl = -dr/2; mm3 = (M1 - 2)*(M2 - 2);
(*  Computation of the necessary constants for 
    the exact solution of the Poisson equation *)
 eps = 10^(-7); z = N[0.5*(1 + (1/eps)^(1/3))];
 nt = Floor[z]; zpi = -N[(0.5*Pi)^2]; zk1 = N[8/Pi];
(* ------------------------------------------ *)
Print["M1 = ", M1, ", M2 = ", M2, ", sor = ",
       sor, ", TOL = ", TOL, ", nt = ", nt];
Print["h1 = ", h1, ", h2 = ", h2];
a0 = uex[0.0, 0.0]; Print ["u(0,0) = ", a0];
(* ------- Begin of the SOR iterations ------- *)
 Label[iter];
(* ------ Do-loop over the (i,j) nodes ------- *)
 Do[
     Do[ vs = c1*(vp[[i-1, j]] + v[[i+1, j]]
       + cel2*(vp[[i, j-1]] + v[[i, j+1]]) - h12);
  vp[[i, j]] = sor*vs + (1-sor)*v[[i, j]],
	         		   {i, 2, m1m}],
		   {j, 2, m2m}];
(* --------- Exchange of the lists ----------- *)
		v = vp; Rhnorm = 0;
(* ----- Computation of the RMS residual ----- *)
 Do[
 Do[ Rh = (v[[i+1,j]]-2*v[[i,j]]+v[[i-1,j]])/h1q
 + (v[[i,j+1]] - 2*v[[i,j]] + v[[i, j-1]])/h2q - 2;
  Rhnorm = Rhnorm + Rh^2, {i, 2, m1m}],
		   {j, 2, m2m}];
            Rhnorm = Sqrt[Rhnorm/mm3];
 n = n + 1;
Print["n = ",n,", Norm of Rh = ", Rhnorm];
       If[n > 300, Goto[endt]];
  If[Rhnorm > TOL, Goto[iter]];
(* --------- End of the SOR iterations -------- *)
Label[endt];
(* --- Plotting the numerical solution surface 
   v = v(x,y)---------------------------------- *)
 gr3 = ListPlot3D[v,
               ViewPoint -> {xview, yview, zview},
	       AxesLabel -> {"y", "x", "v"}];
Display["fig4_40", gr3];
                   gr4 = ListContourPlot[v];
Display["fig4_41", gr4];
(* ----- The numerical computation of the exact
         solution in the grid nodes ----------- *)
Print["Computing the exact solution in the grid", 
       " nodes"];
  Do[ yj = xl + (j - 1)*h2;
 Do[ xi = xl + (i - 1)*h1; vp[[i, j]] = uex[xi, yj];
	  zij = vp[[i, j]];
 Print["i = ", i, ", j = ", j, ", u(xi, yj) = ",
       zij],
				{i, 2, m1m}],
		  {j, 2, m2m}];
(* - The computation of a mean-square error 
     of the numerical solution ---------------- *)
	 rmser = 0;
Do[
   Do[ du = (vp[[i, j]] - v[[i, j]])^2;
                        rmser = rmser + du,
				      {i, 2, m1m}],
		         {j, 2, m2m}];
 rmser = Sqrt[rmser/mm3];
Print["The mean-square error of the numerical",
      " solution = ", rmser];
 gr5 = ListPlot3D[vp,
                ViewPoint -> {xview, yview, zview},
	        AxesLabel -> {"y", "x", "u"}];
(* --------- End of the rogram fem1.m --------- *)
 )

:[font = section; inactive; ]
Parameters Used in Program fem1.ma
:[font = special4; inactive; nowordwrap; nohscroll; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; plain; fontName = "Arial"; fontSize = 12; ]

_______________________________________________________
 Parameter                              Description
_______________________________________________________
M1                    the number of the grid nodes on the x-axis, M1 > 2;
M2                    the number of the grid nodes on the y-axis, M2 > 2;
sor                    the relaxation parameter entering the successive
                         over-relaxation method, 0 < sor < 2;
TOL                  the user-specified tolerance entering the criterion 
                         for the termination of the SOR iterations, TOL > 0;
xview                the coordinates of the viewpoint for the surface
yview                u = u(x, y). At least one of the coordinates
zview                xview, yview, zview should be greater than 1 in
                         modulus. 
_______________________________________________________

:[font = section; inactive; ]
Examples of Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]

fem1[11, 11, 1.5, 10^(-3), 1.3, -2.4, 2.0]

:[font = subsection; inactive; ]
Example 2
:[font = input; nowordwrap; ]

fem1[15, 15, 1.5, 10^(-5), 1.3, -2.4, 2.0]

:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]

The following data are printed out in the process of the work of the
program:

1.  The current values of n, the iteration number, and the residual 
      norm.

2.  The numerical values of the exact solution in the grid nodes.

3.  The mean-square error of the numerical solution.

4.  The numerical solution surface u = u(x,y).

5.  The contour plot of the computed FEM solution.

6.  The exact solution surface u = u(x,y).
^*)