(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
Finite Element Method
:[font = name; inactive; nohscroll; ]

                                     Victor G.Ganzha and Evgenii V.Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

  This Mathematica-Notebook is part of the book entitled

                                 V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The  program fem2.ma which follows below solves numerically the Poisson
equation  u_{xx} + u_{yy} - 2 = 0 by the finite element method in the rectan-
gular region   -Pi/2 < x,y < Pi/2.  The algebraic system arising in the result
of finite element discretization is solved with the aid of the SOR method.

:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]

Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

          ClearAll[uex, fem1];
:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input data by entering them in the line (see also Section
"Examples of Input Data")
:[font = input; nowordwrap; ]

fem2[11, 11, 1.5, 10^(-3), 0, 1.3, -2.4, 2.0,
     0.65, 100]
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line, press Shift + Enter and wait for the result of numerical
computation.The meaning of the input parameters is explained in Section
"Parameters Used in Program fem2.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; bold; fontName = "Courier New"; fontSize = 12; ]
 
ClearAll[uex, fem2];
 uex[x_, y_] :=
(* --- The function to compute the exact solution
       of the Poisson equation ---------------- *)
( z1 = zpi + x*x; z0 = -1.0; z2 = 0.0;
  Do[ z0 = -z0; k1 = 2*k - 1;
      zk = N[Cosh[k1*y]*Cos[k1*x]/Cosh[k1*Pi/2]];
  zk = z0*zk/(k1^3); z2 = z2 + zk, {k, nt}];
  z1 = z1 + zk1*z2; z1 )

fem2[M1_, M2_, sor_, TOL_, exct_, 
     xview_, yview_, zview_, h0_, mfine_]:=
(
(* -- Computation of the mesh steps h1 and h2 -- *)
  m1m = M1 - 1; m2m = M2 - 1; n = 0;
  dr = N[Pi]; h1 = dr/m1m; h2 = dr/m2m;
(* -- Specification of the initial iteration 
    u^{(0)}(x, y)-- *)
     v = Table[0.0, {i, M1}, {j, M2}];
                vp = Table[0.0, {i, M1}, {j, M2}];
cel = h1/h2; c1 = 1/(2*(1 + cel^2)); cel2 = cel^2;
        h12 = 2*h1^2;  h1q = h1^2; h2q = h2^2;
  xl = -dr/2; mm3 = (M1 - 2)*(M2 - 2);
(*  Computation of the necessary constants for 
    the exact solution of the Poisson equation *)
 eps = 10^(-7); z = N[0.5*(1 + (1/eps)^(1/3))];
 nt = Floor[z]; zpi = -N[(0.5*Pi)^2]; zk1 = N[8/Pi];
(* ------------------------------------------ *)
Print["M1 = ", M1, ", M2 = ", M2, ", sor = ",
       sor, ", TOL = ", TOL, ", nt = ", nt];
Print["h1 = ", h1, ", h2 = ", h2];
a0 = uex[0.0, 0.0]; Print ["u(0,0) = ", a0];
(* ------- Begin of the SOR iterations ------- *)
 Label[iter];
(* ------ Do-loop over the (i,j) nodes ------- *)
 Do[
     Do[ vs = c1*(vp[[i-1, j]] + v[[i+1, j]]
       + cel2*(vp[[i, j-1]] + v[[i, j+1]]) - h12);
  vp[[i, j]] = sor*vs + (1-sor)*v[[i, j]],
	         		   {i, 2, m1m}],
		   {j, 2, m2m}];
(* --------- Exchange of the lists ----------- *)
		v = vp; Rhnorm = 0;
(* ----- Computation of the RMS residual ----- *)
 Do[
 Do[ Rh = (v[[i+1,j]]-2*v[[i,j]]+v[[i-1,j]])/h1q
 + (v[[i,j+1]] - 2*v[[i,j]] + v[[i, j-1]])/h2q - 2;
  Rhnorm = Rhnorm + Rh^2, {i, 2, m1m}],
		   {j, 2, m2m}];
            Rhnorm = Sqrt[Rhnorm/mm3];
 n = n + 1;
Print["n = ",n,", Norm of Rh = ", Rhnorm];
       If[n > 300, Goto[endt]];
  If[Rhnorm > TOL, Goto[iter]];
(* --------- End of the SOR iterations -------- *)
Label[endt];
(* --- Plotting the numerical solution surface 
   v = v(x,y)---------------------------------- *)
 gr3 = ListPlot3D[v,
               ViewPoint -> {xview, yview, zview},
	       AxesLabel -> {"y", "x", "v"}];
Display["fig4_40", gr3];
                   gr4 = ListContourPlot[v];
Display["fig4_41", gr4];
(* ----- The numerical computation of the exact
         solution in the grid nodes ----------- *)
If[exct != 0,
Print["Computing the exact solution in the grid", 
       " nodes"];
  Do[ yj = xl + (j - 1)*h2;
 Do[ xi = xl + (i - 1)*h1; vp[[i, j]] = uex[xi, yj];
	  zij = vp[[i, j]];
 Print["i = ", i, ", j = ", j, ", u(xi, yj) = ",
       zij],
				{i, 2, m1m}],
		  {j, 2, m2m}];
(* - The computation of a mean-square error 
     of the numerical solution ---------------- *)
	 rmser = 0;
Do[
   Do[ du = (vp[[i, j]] - v[[i, j]])^2;
                        rmser = rmser + du,
				      {i, 2, m1m}],
		         {j, 2, m2m}];
 rmser = Sqrt[rmser/mm3];
Print["The mean-square error of the numerical",
      " solution = ", rmser];
 gr5 = ListPlot3D[vp,
                ViewPoint -> {xview, yview, zview},
	        AxesLabel -> {"y", "x", "u"}] ];

(* -- Producing the density graphics with the aid 
      of the interpolation -------------------- *)
     gr1 = DensityGraphics[v];
  cl1[f_]:= Hue[h0*(1 - f)];

gr2 = Show[gr1, ColorFunction -> (cl1[#]&), 
                Mesh -> False];

(* ---- Interpolation on a finer mesh ---- *)
tab = {};
	 Do[ yj = xl + (j - 1)*h2;
	     Do[ xi = xl + (i - 1)*h1;
AppendTo[tab, {xi, yj, v[[i,j]]}], {i, M1}],
				 {j, M2}];
Print["Calculation of the interpolating function."];
vint = Interpolation[tab, InterpolationOrder -> 1];

If[M1>M2, m1int=mfine; m2int = Floor[mfine*M2/M1],
      m2int = mfine; m1int = Floor[mfine*M1/M2] ];
h1n = dr/(m1int - 1); h2n = dr/(m2int - 1);
Print["m1int = ", m1int, ", m2int = ", m2int,
", h1n = ", h1n, ", h2n = ", h2n];
vn = Table[0.0, {i, m1int}, {j, m2int}];
Print["Calculation of the values of v(x,y) in the", 
" nodes of a fine mesh."];
   Do[ yj = xl + (j - 1)*h2n;
       Do[ xi = xl + (i - 1)*h1n;
vn[[i, j]] = vint[xi, yj], {i, m1int}], {j, m2int}];
vmin = 10^6;  vmax = -vmin;
   Do[
       Do[z = vn[[i, j]]; vmin = Min[vmin, z];
                          vmax = Max[vmax, z],
                                    {i, m1int}],
				{j, m2int}];
Print["vmin = ", vmin, ", vmax = ", vmax];
Print["Plotting the density graph on a fine mesh."];
     gr3 = DensityGraphics[vn];
gr4 = Show[gr3, ColorFunction -> (cl1[#]&), 
                Mesh -> False];
Display["fig4_5", gr4];
(* --------- End of the rogram fem1.m --------- *)
 )

:[font = section; inactive; ]
Parameters Used in Program fem2.ma
:[font = special4; inactive; nowordwrap; nohscroll; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; plain; fontName = "Arial"; fontSize = 12; ]

_______________________________________________________
 Parameter                              Description
_______________________________________________________
M1                    the number of the grid nodes on the x-axis, M1 > 2;
M2                    the number of the grid nodes on the y-axis, M2 > 2;
sor                    the relaxation parameter entering the successive
                         over-relaxation method, 0 < sor < 2;
TOL                  the user-specified tolerance entering the criterion 
                         for the termination of the SOR iterations, TOL > 0;
exct                  if exct = 0, then the exact solution is not calculated;
                         if exct >= 1, then it is calculated;
xview                the coordinates of the viewpoint for the surface
yview                u = u(x, y). At least one of the coordinates
zview                xview, yview, zview should be greater than 1 in
                         modulus;
h0                     the number in the interval 0 < h0 < 1 to specify
                         the color corresponding to the minimum value of
                         the function u(x, y) in the spatial region under
                         consideration;
mfine                the number of cells of a fine mesh in the interval
                         -Pi/2 <= x,y <= Pi/2; mfine >= min(ix, jy).
_______________________________________________________

:[font = section; inactive; ]
Examples of Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]
fem2[11, 11, 1.5, 10^(-3), 0, 1.3, -2.4, 2.0,
     0.65, 100]

:[font = print; inactive; formatted; output; nowordwrap; ]
No Input Form Generated




;[o]
                                    1
M1 = 11, M2 = 11, sor = 1.5, TOL = ----, nt = 108
                                   1000
h1 = 0.314159, h2 = 0.314159
u(0,0) = -1.45421
n = 1, Norm of Rh = 1.63616
n = 2, Norm of Rh = 1.25372
n = 3, Norm of Rh = 0.975418
n = 4, Norm of Rh = 0.762285
n = 5, Norm of Rh = 0.594168
n = 6, Norm of Rh = 0.45942
n = 7, Norm of Rh = 0.35045
n = 8, Norm of Rh = 0.261855
n = 9, Norm of Rh = 0.189545
n = 10, Norm of Rh = 0.131988
n = 11, Norm of Rh = 0.0885478
n = 12, Norm of Rh = 0.0574441
n = 13, Norm of Rh = 0.0362251
n = 14, Norm of Rh = 0.02251
n = 15, Norm of Rh = 0.014163
n = 16, Norm of Rh = 0.00927199
n = 17, Norm of Rh = 0.00628573
n = 18, Norm of Rh = 0.00423198
n = 19, Norm of Rh = 0.00259893
n = 20, Norm of Rh = 0.00171741
n = 21, Norm of Rh = 0.00111017
n = 22, Norm of Rh = 0.000720673
Calculation of the interpolating function.
m1int = 100, m2int = 100, h1n = 0.0317333, h2n = 
 
 0.0317333
Calculation of the values of v(x,y) in the
 
  nodes of a fine mesh.
vmin = -1.43765, vmax = 0.
Plotting the density graph on a fine mesh.
:[font = postscript; inactive; output; BITMAP; PostScript; pictureLeft = 100; pictureTop = 0; pictureWidth = 300; pictureHeight = 246; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: .82055 
MathPictureStart
%% SurfaceGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0249355 0.99742 -0.0396341 0.99742 [
[(2)] .10672 .23696 1 .97179 Msboxa
[(4)] .22191 .19163 .94563 1 Msboxa
[(6)] .34275 .1441 .86223 1 Msboxa
[(8)] .46967 .09419 .77884 1 Msboxa
[(10)] .60315 .04174 .69544 1 Msboxa
[(y)] .30204 .09689 .86223 1 Msboxa
[(2)] .72326 .06989 -1 .38011 Msboxa
[(4)] .78358 .16225 -1 .3591 Msboxa
[(6)] .83872 .24668 -1 .34028 Msboxa
[(8)] .88932 .32418 -1 .32334 Msboxa
[(10)] .93593 .39556 -1 .30801 Msboxa
[(x)] .89773 .2266 -1 .34028 Msboxa
[(-1)] .03798 .33868 1 -0.37836 Msboxa
[(-0.5)] .02631 .41178 1 -0.36383 Msboxa
[(0)] .01407 .48855 1 -0.3485 Msboxa
[(v)] -0.02691 .40064 1 -0.37036 Msboxa
[ 0 0 0 0 ]
[ 1 .82055 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06024 .26735 m
.67932 .02494 L
s
P
p
.002 w
.11567 .24565 m
.12014 .24999 L
s
P
[(2)] .10672 .23696 1 .97179 Mshowa
p
.002 w
.23048 .20069 m
.23476 .20522 L
s
P
[(4)] .22191 .19163 .94563 1 Mshowa
p
.002 w
.35089 .15354 m
.35496 .15826 L
s
P
[(6)] .34275 .1441 .86223 1 Mshowa
p
.002 w
.47733 .10403 m
.48116 .10895 L
s
P
[(8)] .46967 .09419 .77884 1 Mshowa
p
.002 w
.61027 .05198 m
.61382 .05709 L
s
P
[(10)] .60315 .04174 .69544 1 Mshowa
p
.001 w
.1382 .23682 m
.14086 .23945 L
s
P
p
.001 w
.16094 .22792 m
.16358 .23057 L
s
P
p
.001 w
.1839 .21893 m
.18652 .2216 L
s
P
p
.001 w
.20708 .20985 m
.20967 .21255 L
s
P
p
.001 w
.2541 .19144 m
.25664 .19418 L
s
P
p
.001 w
.27795 .1821 m
.28047 .18487 L
s
P
p
.001 w
.30203 .17267 m
.30452 .17546 L
s
P
p
.001 w
.32634 .16315 m
.32881 .16596 L
s
P
p
.001 w
.37568 .14383 m
.3781 .14669 L
s
P
p
.001 w
.40072 .13403 m
.40311 .13691 L
s
P
p
.001 w
.426 .12413 m
.42836 .12703 L
s
P
p
.001 w
.45154 .11413 m
.45387 .11706 L
s
P
p
.001 w
.50338 .09383 m
.50565 .0968 L
s
P
p
.001 w
.5297 .08352 m
.53194 .08652 L
s
P
p
.001 w
.55628 .07311 m
.55849 .07614 L
s
P
p
.001 w
.58314 .0626 m
.58531 .06565 L
s
P
p
.001 w
.09334 .25439 m
.09605 .25697 L
s
P
p
.001 w
.07122 .26305 m
.07395 .26561 L
s
P
p
.001 w
.63768 .04124 m
.63978 .04434 L
s
P
p
.001 w
.66537 .0304 m
.66743 .03352 L
s
P
[(y)] .30204 .09689 .86223 1 Mshowa
P
p
p
.002 w
.67932 .02494 m
.94594 .43277 L
s
P
p
.002 w
.71161 .07432 m
.70578 .07654 L
s
P
[(2)] .72326 .06989 -1 .38011 Mshowa
p
.002 w
.77184 .16646 m
.76598 .16857 L
s
P
[(4)] .78358 .16225 -1 .3591 Mshowa
p
.002 w
.82692 .2507 m
.82101 .25271 L
s
P
[(6)] .83872 .24668 -1 .34028 Mshowa
p
.002 w
.87746 .32802 m
.87153 .32993 L
s
P
[(8)] .88932 .32418 -1 .32334 Mshowa
p
.002 w
.92402 .39923 m
.91806 .40106 L
s
P
[(10)] .93593 .39556 -1 .30801 Mshowa
p
.001 w
.7241 .09343 m
.7206 .09475 L
s
P
p
.001 w
.73637 .11219 m
.73286 .1135 L
s
P
p
.001 w
.74841 .13061 m
.7449 .1319 L
s
P
p
.001 w
.76023 .1487 m
.75672 .14997 L
s
P
p
.001 w
.78325 .18391 m
.77972 .18516 L
s
P
p
.001 w
.79445 .20104 m
.79093 .20228 L
s
P
p
.001 w
.80546 .21788 m
.80193 .21911 L
s
P
p
.001 w
.81628 .23443 m
.81275 .23565 L
s
P
p
.001 w
.83737 .26669 m
.83382 .26788 L
s
P
p
.001 w
.84764 .28241 m
.8441 .28359 L
s
P
p
.001 w
.85775 .29786 m
.8542 .29904 L
s
P
p
.001 w
.86769 .31307 m
.86413 .31423 L
s
P
p
.001 w
.88707 .34272 m
.88351 .34386 L
s
P
p
.001 w
.89653 .35719 m
.89297 .35832 L
s
P
p
.001 w
.90584 .37143 m
.90227 .37255 L
s
P
p
.001 w
.915 .38544 m
.91143 .38655 L
s
P
p
.001 w
.69888 .05485 m
.69539 .05619 L
s
P
p
.001 w
.6859 .035 m
.68242 .03636 L
s
P
p
.001 w
.93289 .4128 m
.92931 .41389 L
s
P
p
.001 w
.94162 .42616 m
.93804 .42725 L
s
P
[(x)] .89773 .2266 -1 .34028 Mshowa
P
p
p
.002 w
.06024 .26735 m
.02494 .49015 L
s
P
p
.002 w
.04964 .33427 m
.05547 .33206 L
s
P
[(-1)] .03798 .33868 1 -0.37836 Mshowa
p
.002 w
.03803 .40752 m
.04389 .40539 L
s
P
[(-0.5)] .02631 .41178 1 -0.36383 Mshowa
p
.002 w
.02584 .48445 m
.03173 .4824 L
s
P
[(0)] .01407 .48855 1 -0.3485 Mshowa
p
.001 w
.05853 .27814 m
.06202 .27678 L
s
P
p
.001 w
.05634 .29198 m
.05983 .29063 L
s
P
p
.001 w
.05413 .30594 m
.05762 .3046 L
s
P
p
.001 w
.05189 .32004 m
.05539 .3187 L
s
P
p
.001 w
.04736 .34864 m
.05086 .34732 L
s
P
p
.001 w
.04506 .36314 m
.04857 .36184 L
s
P
p
.001 w
.04274 .37779 m
.04625 .3765 L
s
P
p
.001 w
.0404 .39258 m
.04391 .3913 L
s
P
p
.001 w
.03564 .4226 m
.03916 .42133 L
s
P
p
.001 w
.03323 .43783 m
.03675 .43657 L
s
P
p
.001 w
.03079 .45322 m
.03431 .45197 L
s
P
p
.001 w
.02833 .46875 m
.03185 .46751 L
s
P
[(v)] -0.02691 .40064 1 -0.37036 Mshowa
P
0 0 m
1 0 L
1 .82055 L
0 .82055 L
closepath
clip
newpath
p
.002 w
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.40296 .79562 L
s
.40296 .79562 m
.41001 .59401 L
s
.41001 .59401 m
.06024 .26735 L
s
.67932 .02494 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.67932 .02494 m
.06024 .26735 L
s
.41001 .59401 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.40296 .79562 L
s
.40296 .79562 m
.41001 .59401 L
s
P
p
.813 .778 .82 r
.0015 w
.37184 .76514 .40314 .79053 .45504 .77689 .42545 .71509 Metetra
.711 .626 .76 r
.42545 .71509 .45504 .77689 .50799 .76298 .47884 .67877 Metetra
.667 .564 .729 r
.47884 .67877 .50799 .76298 .56205 .74877 .53266 .6505 Metetra
.643 .533 .714 r
.53266 .6505 .56205 .74877 .61724 .73427 .5873 .62783 Metetra
.627 .516 .707 r
.5873 .62783 .61724 .73427 .6736 .71946 .64302 .60967 Metetra
.615 .506 .706 r
.64302 .60967 .6736 .71946 .73117 .70433 .7001 .59575 Metetra
.603 .501 .711 r
.7001 .59575 .73117 .70433 .78999 .68887 .75886 .58648 Metetra
.588 .5 .723 r
.75886 .58648 .78999 .68887 .85009 .67308 .81973 .58314 Metetra
.559 .502 .748 r
.81973 .58314 .85009 .67308 .91152 .65694 .88346 .58851 Metetra
.475 .5 .804 r
.88346 .58851 .91152 .65694 .97432 .64043 .95149 .60897 Metetra
.851 .77 .771 r
.33933 .73876 .37184 .76514 .42545 .71509 .39482 .66601 Metetra
.772 .684 .766 r
.39482 .66601 .42545 .71509 .47884 .67877 .44914 .61304 Metetra
.714 .622 .753 r
.44914 .61304 .47884 .67877 .53266 .6505 .50326 .5736 Metetra
.674 .581 .743 r
.50326 .5736 .53266 .6505 .5873 .62783 .55784 .54423 Metetra
.644 .555 .739 r
.55784 .54423 .5873 .62783 .64302 .60967 .61337 .52327 Metetra
.617 .536 .741 r
.61337 .52327 .64302 .60967 .7001 .59575 .67033 .51027 Metetra
.588 .523 .749 r
.67033 .51027 .7001 .59575 .75886 .58648 .72925 .50592 Metetra
.545 .509 .767 r
.72925 .50592 .75886 .58648 .81973 .58314 .79089 .51225 Metetra
.464 .487 .797 r
.79089 .51225 .81973 .58314 .88346 .58851 .85638 .53323 Metetra
.256 .416 .83 r
.85638 .53323 .88346 .58851 .95149 .60897 .92768 .57615 Metetra
.866 .765 .748 r
.30554 .71135 .33933 .73876 .39482 .66601 .363 .62409 Metetra
.809 .718 .764 r
.363 .62409 .39482 .66601 .44914 .61304 .41853 .55976 Metetra
.754 .671 .77 r
.41853 .55976 .44914 .61304 .50326 .5736 .47333 .51229 Metetra
.706 .632 .772 r
.47333 .51229 .50326 .5736 .55784 .54423 .52824 .47795 Metetra
.662 .601 .776 r
.52824 .47795 .55784 .54423 .61337 .52327 .58395 .45478 Metetra
.619 .575 .783 r
.58395 .45478 .61337 .52327 .67033 .51027 .64107 .44226 Metetra
.566 .551 .796 r
.64107 .44226 .67033 .51027 .72925 .50592 .70031 .44124 Metetra
.487 .519 .816 r
.70031 .44124 .72925 .50592 .79089 .51225 .76263 .45408 Metetra
.34 .459 .835 r
.76263 .45408 .79089 .51225 .85638 .53323 .82941 .48521 Metetra
.037 .31 .798 r
.82941 .48521 .85638 .53323 .92768 .57615 .90281 .54189 Metetra
.873 .762 .737 r
.27039 .68284 .30554 .71135 .363 .62409 .32982 .58689 Metetra
.831 .741 .764 r
.32982 .58689 .363 .62409 .41853 .55976 .38673 .51561 Metetra
.784 .713 .785 r
.38673 .51561 .41853 .55976 .47333 .51229 .44246 .46305 Metetra
.734 .684 .802 r
.44246 .46305 .47333 .51229 .52824 .47795 .49802 .4254 Metetra
.681 .654 .817 r
.49802 .4254 .52824 .47795 .58395 .45478 .5542 .40059 Metetra
.62 .624 .833 r
.5542 .40059 .58395 .45478 .64107 .44226 .61173 .38807 Metetra
.54 .588 .851 r
.61173 .38807 .64107 .44226 .70031 .44124 .67143 .38875 Metetra
.416 .531 .866 r
.67143 .38875 .70031 .44124 .76263 .45408 .73438 .40515 Metetra
.205 .424 .853 r
.73438 .40515 .76263 .45408 .82941 .48521 .80208 .44185 Metetra
0 .223 .744 r
.80208 .44185 .82941 .48521 .90281 .54189 .87683 .50609 Metetra
.874 .761 .734 r
.23381 .65316 .27039 .68284 .32982 .58689 .2951 .55335 Metetra
.845 .759 .768 r
.2951 .55335 .32982 .58689 .38673 .51561 .35343 .47896 Metetra
.806 .752 .802 r
.35343 .47896 .38673 .51561 .44246 .46305 .41028 .42402 Metetra
.758 .738 .835 r
.41028 .42402 .44246 .46305 .49802 .4254 .46673 .38465 Metetra
.698 .718 .865 r
.46673 .38465 .49802 .4254 .5542 .40059 .52365 .35874 Metetra
.619 .687 .892 r
.52365 .35874 .5542 .40059 .61173 .38807 .58183 .34572 Metetra
.506 .637 .912 r
.58183 .34572 .61173 .38807 .67143 .38875 .64215 .34652 Metetra
.335 .549 .911 r
.64215 .34652 .67143 .38875 .73438 .40515 .70572 .36373 Metetra
.081 .394 .852 r
.70572 .36373 .73438 .40515 .80208 .44185 .7741 .40199 Metetra
0 .172 .699 r
.7741 .40199 .80208 .44185 .87683 .50609 .84965 .46863 Metetra
.873 .762 .737 r
.19569 .62224 .23381 .65316 .2951 .55335 .25861 .52319 Metetra
.852 .778 .779 r
.25861 .52319 .2951 .55335 .35343 .47896 .31831 .44941 Metetra
.821 .793 .826 r
.31831 .44941 .35343 .47896 .41028 .42402 .37636 .39474 Metetra
.775 .8 .874 r
.37636 .39474 .41028 .42402 .46673 .38465 .4339 .35523 Metetra
.707 .794 .919 r
.4339 .35523 .46673 .38465 .52365 .35874 .49183 .32875 Metetra
.607 .766 .956 r
.49183 .32875 .52365 .35874 .58183 .34572 .55093 .31472 Metetra
.461 .701 .971 r
.55093 .31472 .58183 .34572 .64215 .34652 .61208 .31406 Metetra
.252 .577 .942 r
.61208 .31406 .64215 .34652 .70572 .36373 .67634 .32937 Metetra
0 .387 .843 r
.67634 .32937 .70572 .36373 .7741 .40199 .74526 .36532 Metetra
0 .162 .681 r
.74526 .36532 .7741 .40199 .84965 .46863 .82118 .42941 Metetra
.866 .765 .748 r
.15595 .59 .19569 .62224 .25861 .52319 .22003 .49683 Metetra
.853 .803 .801 r
.22003 .49683 .25861 .52319 .31831 .44941 .28089 .4277 Metetra
.827 .844 .86 r
.28089 .4277 .31831 .44941 .37636 .39474 .34016 .37612 Metetra
.776 .876 .921 r
.34016 .37612 .37636 .39474 .4339 .35523 .39898 .33811 Metetra
.689 .884 .97 r
.39898 .33811 .4339 .35523 .49183 .32875 .4582 .31161 Metetra
.559 .851 .998 r
.4582 .31161 .49183 .32875 .55093 .31472 .51854 .29605 Metetra
.384 .764 .991 r
.51854 .29605 .55093 .31472 .61208 .31406 .5808 .29228 Metetra
.171 .615 .938 r
.5808 .29228 .61208 .31406 .67634 .32937 .64594 .3028 Metetra
0 .417 .836 r
.64594 .3028 .67634 .32937 .74526 .36532 .71538 .33222 Metetra
0 .202 .698 r
.71538 .33222 .74526 .36532 .82118 .42941 .79135 .3883 Metetra
.851 .77 .771 r
.11447 .55635 .15595 .59 .22003 .49683 .1789 .47557 Metetra
.844 .84 .841 r
.1789 .47557 .22003 .49683 .28089 .4277 .2405 .41595 Metetra
.808 .914 .911 r
.2405 .41595 .28089 .4277 .34016 .37612 .30093 .37067 Metetra
.717 .953 .95 r
.30093 .37067 .34016 .37612 .39898 .33811 .36119 .33598 Metetra
.569 .928 .94 r
.36119 .33598 .39898 .33811 .4582 .31161 .42203 .31005 Metetra
.4 .851 .9 r
.42203 .31005 .4582 .31161 .51854 .29605 .48403 .29238 Metetra
.24 .752 .864 r
.48403 .29238 .51854 .29605 .5808 .29228 .54782 .28371 Metetra
.095 .638 .844 r
.54782 .28371 .5808 .29228 .64594 .3028 .61419 .28616 Metetra
0 .496 .823 r
.61419 .28616 .64594 .3028 .71538 .33222 .68428 .30402 Metetra
0 .313 .76 r
.68428 .30402 .71538 .33222 .79135 .3883 .76003 .34515 Metetra
.813 .778 .82 r
.07114 .5212 .11447 .55635 .1789 .47557 .13441 .46232 Metetra
.796 .904 .917 r
.13441 .46232 .1789 .47557 .2405 .41595 .19605 .41836 Metetra
.671 .967 .925 r
.19605 .41836 .2405 .41595 .30093 .37067 .25746 .38303 Metetra
.44 .873 .788 r
.25746 .38303 .30093 .37067 .36119 .33598 .31937 .35361 Metetra
.31937 .35361 .36119 .33598 .42203 .31005 .38225 .32889 Metetra
.38225 .32889 .42203 .31005 .48403 .29238 .44648 .30857 Metetra
.44648 .30857 .48403 .29238 .54782 .28371 .51245 .29308 Metetra
.51245 .29308 .54782 .28371 .61419 .28616 .58063 .28378 Metetra
.036 .606 .752 r
.58063 .28378 .61419 .28616 .68428 .30402 .65174 .28369 Metetra
.035 .545 .873 r
.65174 .28369 .68428 .30402 .76003 .34515 .72713 .29981 Metetra
.646 .762 .934 r
.02584 .48445 .07114 .5212 .13441 .46232 .085 .46383 Metetra
.463 .885 .913 r
.085 .46383 .13441 .46232 .19605 .41836 .14566 .44269 Metetra
.14566 .44269 .19605 .41836 .25746 .38303 .20787 .42101 Metetra
.03 0 0 r
.20787 .42101 .25746 .38303 .31937 .35361 .27171 .39876 Metetra
.096 0 0 r
.27171 .39876 .31937 .35361 .38225 .32889 .33722 .37593 Metetra
.115 0 0 r
.33722 .37593 .38225 .32889 .44648 .30857 .40448 .35249 Metetra
.096 0 0 r
.40448 .35249 .44648 .30857 .51245 .29308 .47357 .32841 Metetra
.03 0 0 r
.47357 .32841 .51245 .29308 .58063 .28378 .54455 .30368 Metetra
.54455 .30368 .58063 .28378 .65174 .28369 .6175 .27825 Metetra
.462 .885 .912 r
.6175 .27825 .65174 .28369 .72713 .29981 .69251 .25211 Metetra
P
p
.002 w
.67932 .02494 m
.94594 .43277 L
s
.94594 .43277 m
.97506 .64585 L
s
.97506 .64585 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.06024 .26735 m
.02494 .49015 L
s
.02494 .49015 m
.69286 .25814 L
s
.69286 .25814 m
.67932 .02494 L
s
.67932 .02494 m
.06024 .26735 L
s
P
p
p
.002 w
.06024 .26735 m
.67932 .02494 L
s
P
p
.002 w
.11567 .24565 m
.12014 .24999 L
s
P
[(2)] .10672 .23696 1 .97179 Mshowa
p
.002 w
.23048 .20069 m
.23476 .20522 L
s
P
[(4)] .22191 .19163 .94563 1 Mshowa
p
.002 w
.35089 .15354 m
.35496 .15826 L
s
P
[(6)] .34275 .1441 .86223 1 Mshowa
p
.002 w
.47733 .10403 m
.48116 .10895 L
s
P
[(8)] .46967 .09419 .77884 1 Mshowa
p
.002 w
.61027 .05198 m
.61382 .05709 L
s
P
[(10)] .60315 .04174 .69544 1 Mshowa
p
.001 w
.1382 .23682 m
.14086 .23945 L
s
P
p
.001 w
.16094 .22792 m
.16358 .23057 L
s
P
p
.001 w
.1839 .21893 m
.18652 .2216 L
s
P
p
.001 w
.20708 .20985 m
.20967 .21255 L
s
P
p
.001 w
.2541 .19144 m
.25664 .19418 L
s
P
p
.001 w
.27795 .1821 m
.28047 .18487 L
s
P
p
.001 w
.30203 .17267 m
.30452 .17546 L
s
P
p
.001 w
.32634 .16315 m
.32881 .16596 L
s
P
p
.001 w
.37568 .14383 m
.3781 .14669 L
s
P
p
.001 w
.40072 .13403 m
.40311 .13691 L
s
P
p
.001 w
.426 .12413 m
.42836 .12703 L
s
P
p
.001 w
.45154 .11413 m
.45387 .11706 L
s
P
p
.001 w
.50338 .09383 m
.50565 .0968 L
s
P
p
.001 w
.5297 .08352 m
.53194 .08652 L
s
P
p
.001 w
.55628 .07311 m
.55849 .07614 L
s
P
p
.001 w
.58314 .0626 m
.58531 .06565 L
s
P
p
.001 w
.09334 .25439 m
.09605 .25697 L
s
P
p
.001 w
.07122 .26305 m
.07395 .26561 L
s
P
p
.001 w
.63768 .04124 m
.63978 .04434 L
s
P
p
.001 w
.66537 .0304 m
.66743 .03352 L
s
P
[(y)] .30204 .09689 .86223 1 Mshowa
P
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; output; BITMAP; PostScript; pictureLeft = 127; pictureTop = 36; pictureWidth = 260; pictureHeight = 260; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% DensityGraphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0192308 0.00961538 0.0192308 0.00961538 [
[(0)] .01923 0 0 2 Msboxa
[(20)] .21154 0 0 2 Msboxa
[(40)] .40385 0 0 2 Msboxa
[(60)] .59615 0 0 2 Msboxa
[(80)] .78846 0 0 2 Msboxa
[(100)] .98077 0 0 2 Msboxa
[(0)] -0.0125 .01923 1 0 Msboxa
[(20)] -0.0125 .21154 1 0 Msboxa
[(40)] -0.0125 .40385 1 0 Msboxa
[(60)] -0.0125 .59615 1 0 Msboxa
[(80)] -0.0125 .78846 1 0 Msboxa
[(100)] -0.0125 .98077 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.01923 0 m
.01923 .00625 L
s
P
[(0)] .01923 0 0 2 Mshowa
p
.002 w
.21154 0 m
.21154 .00625 L
s
P
[(20)] .21154 0 0 2 Mshowa
p
.002 w
.40385 0 m
.40385 .00625 L
s
P
[(40)] .40385 0 0 2 Mshowa
p
.002 w
.59615 0 m
.59615 .00625 L
s
P
[(60)] .59615 0 0 2 Mshowa
p
.002 w
.78846 0 m
.78846 .00625 L
s
P
[(80)] .78846 0 0 2 Mshowa
p
.002 w
.98077 0 m
.98077 .00625 L
s
P
[(100)] .98077 0 0 2 Mshowa
p
.001 w
.05769 0 m
.05769 .00375 L
s
P
p
.001 w
.09615 0 m
.09615 .00375 L
s
P
p
.001 w
.13462 0 m
.13462 .00375 L
s
P
p
.001 w
.17308 0 m
.17308 .00375 L
s
P
p
.001 w
.25 0 m
.25 .00375 L
s
P
p
.001 w
.28846 0 m
.28846 .00375 L
s
P
p
.001 w
.32692 0 m
.32692 .00375 L
s
P
p
.001 w
.36538 0 m
.36538 .00375 L
s
P
p
.001 w
.44231 0 m
.44231 .00375 L
s
P
p
.001 w
.48077 0 m
.48077 .00375 L
s
P
p
.001 w
.51923 0 m
.51923 .00375 L
s
P
p
.001 w
.55769 0 m
.55769 .00375 L
s
P
p
.001 w
.63462 0 m
.63462 .00375 L
s
P
p
.001 w
.67308 0 m
.67308 .00375 L
s
P
p
.001 w
.71154 0 m
.71154 .00375 L
s
P
p
.001 w
.75 0 m
.75 .00375 L
s
P
p
.001 w
.82692 0 m
.82692 .00375 L
s
P
p
.001 w
.86538 0 m
.86538 .00375 L
s
P
p
.001 w
.90385 0 m
.90385 .00375 L
s
P
p
.001 w
.94231 0 m
.94231 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01923 m
.00625 .01923 L
s
P
[(0)] -0.0125 .01923 1 0 Mshowa
p
.002 w
0 .21154 m
.00625 .21154 L
s
P
[(20)] -0.0125 .21154 1 0 Mshowa
p
.002 w
0 .40385 m
.00625 .40385 L
s
P
[(40)] -0.0125 .40385 1 0 Mshowa
p
.002 w
0 .59615 m
.00625 .59615 L
s
P
[(60)] -0.0125 .59615 1 0 Mshowa
p
.002 w
0 .78846 m
.00625 .78846 L
s
P
[(80)] -0.0125 .78846 1 0 Mshowa
p
.002 w
0 .98077 m
.00625 .98077 L
s
P
[(100)] -0.0125 .98077 1 0 Mshowa
p
.001 w
0 .05769 m
.00375 .05769 L
s
P
p
.001 w
0 .09615 m
.00375 .09615 L
s
P
p
.001 w
0 .13462 m
.00375 .13462 L
s
P
p
.001 w
0 .17308 m
.00375 .17308 L
s
P
p
.001 w
0 .25 m
.00375 .25 L
s
P
p
.001 w
0 .28846 m
.00375 .28846 L
s
P
p
.001 w
0 .32692 m
.00375 .32692 L
s
P
p
.001 w
0 .36538 m
.00375 .36538 L
s
P
p
.001 w
0 .44231 m
.00375 .44231 L
s
P
p
.001 w
0 .48077 m
.00375 .48077 L
s
P
p
.001 w
0 .51923 m
.00375 .51923 L
s
P
p
.001 w
0 .55769 m
.00375 .55769 L
s
P
p
.001 w
0 .63462 m
.00375 .63462 L
s
P
p
.001 w
0 .67308 m
.00375 .67308 L
s
P
p
.001 w
0 .71154 m
.00375 .71154 L
s
P
p
.001 w
0 .75 m
.00375 .75 L
s
P
p
.001 w
0 .82692 m
.00375 .82692 L
s
P
p
.001 w
0 .86538 m
.00375 .86538 L
s
P
p
.001 w
0 .90385 m
.00375 .90385 L
s
P
p
.001 w
0 .94231 m
.00375 .94231 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
.01923 .99375 m
.01923 1 L
s
P
p
.002 w
.21154 .99375 m
.21154 1 L
s
P
p
.002 w
.40385 .99375 m
.40385 1 L
s
P
p
.002 w
.59615 .99375 m
.59615 1 L
s
P
p
.002 w
.78846 .99375 m
.78846 1 L
s
P
p
.002 w
.98077 .99375 m
.98077 1 L
s
P
p
.001 w
.05769 .99625 m
.05769 1 L
s
P
p
.001 w
.09615 .99625 m
.09615 1 L
s
P
p
.001 w
.13462 .99625 m
.13462 1 L
s
P
p
.001 w
.17308 .99625 m
.17308 1 L
s
P
p
.001 w
.25 .99625 m
.25 1 L
s
P
p
.001 w
.28846 .99625 m
.28846 1 L
s
P
p
.001 w
.32692 .99625 m
.32692 1 L
s
P
p
.001 w
.36538 .99625 m
.36538 1 L
s
P
p
.001 w
.44231 .99625 m
.44231 1 L
s
P
p
.001 w
.48077 .99625 m
.48077 1 L
s
P
p
.001 w
.51923 .99625 m
.51923 1 L
s
P
p
.001 w
.55769 .99625 m
.55769 1 L
s
P
p
.001 w
.63462 .99625 m
.63462 1 L
s
P
p
.001 w
.67308 .99625 m
.67308 1 L
s
P
p
.001 w
.71154 .99625 m
.71154 1 L
s
P
p
.001 w
.75 .99625 m
.75 1 L
s
P
p
.001 w
.82692 .99625 m
.82692 1 L
s
P
p
.001 w
.86538 .99625 m
.86538 1 L
s
P
p
.001 w
.90385 .99625 m
.90385 1 L
s
P
p
.001 w
.94231 .99625 m
.94231 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .01923 m
1 .01923 L
s
P
p
.002 w
.99375 .21154 m
1 .21154 L
s
P
p
.002 w
.99375 .40385 m
1 .40385 L
s
P
p
.002 w
.99375 .59615 m
1 .59615 L
s
P
p
.002 w
.99375 .78846 m
1 .78846 L
s
P
p
.002 w
.99375 .98077 m
1 .98077 L
s
P
p
.001 w
.99625 .05769 m
1 .05769 L
s
P
p
.001 w
.99625 .09615 m
1 .09615 L
s
P
p
.001 w
.99625 .13462 m
1 .13462 L
s
P
p
.001 w
.99625 .17308 m
1 .17308 L
s
P
p
.001 w
.99625 .25 m
1 .25 L
s
P
p
.001 w
.99625 .28846 m
1 .28846 L
s
P
p
.001 w
.99625 .32692 m
1 .32692 L
s
P
p
.001 w
.99625 .36538 m
1 .36538 L
s
P
p
.001 w
.99625 .44231 m
1 .44231 L
s
P
p
.001 w
.99625 .48077 m
1 .48077 L
s
P
p
.001 w
.99625 .51923 m
1 .51923 L
s
P
p
.001 w
.99625 .55769 m
1 .55769 L
s
P
p
.001 w
.99625 .63462 m
1 .63462 L
s
P
p
.001 w
.99625 .67308 m
1 .67308 L
s
P
p
.001 w
.99625 .71154 m
1 .71154 L
s
P
p
.001 w
.99625 .75 m
1 .75 L
s
P
p
.001 w
.99625 .82692 m
1 .82692 L
s
P
p
.001 w
.99625 .86538 m
1 .86538 L
s
P
p
.001 w
.99625 .90385 m
1 .90385 L
s
P
p
.001 w
.99625 .94231 m
1 .94231 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.01923 .01923 translate
.96154 .96154 scale
300 string
100 100 8 [100 0 0 100 0 0] {
	currentfile
	1 index
	readhexstring
	pop
}  false 3 Mcolorimage
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000
FF0000FF0100FF0300FF0500FF0700FF0800FF0A00FF0C00FF0E00FF1000FF1100FF1200FF1400FF1500FF1600FF1700FF1800FF1900FF1A00FF1B00FF1C00FF1D00FF1E00FF1E00
FF1F00FF2000FF2000FF2100FF2200FF2200FF2300FF2300FF2300FF2400FF2400FF2500FF2500FF2500FF2600FF2600FF2600FF2600FF2700FF2700FF2700FF2700FF2700FF2700
FF2700FF2700FF2700FF2700FF2700FF2700FF2700FF2700FF2700FF2700FF2600FF2600FF2600FF2600FF2500FF2500FF2500FF2400FF2400FF2300FF2300FF2300FF2200FF2200
FF2100FF2000FF2000FF1F00FF1E00FF1E00FF1D00FF1C00FF1B00FF1A00FF1900FF1800FF1700FF1600FF1500FF1400FF1200FF1100FF1000FF0E00FF0C00FF0A00FF0800FF0700
FF0500FF0300FF0100FF0000
FF0000FF0300FF0700FF0A00FF0E00FF1100FF1500FF1900FF1C00FF2000FF2300FF2500FF2800FF2A00FF2C00FF2E00FF3000FF3200FF3500FF3700FF3900FF3A00FF3C00FF3D00
FF3E00FF4000FF4100FF4200FF4400FF4500FF4600FF4700FF4700FF4800FF4900FF4A00FF4A00FF4B00FF4C00FF4D00FF4D00FF4D00FF4E00FF4E00FF4E00FF4E00FF4E00FF4F00
FF4F00FF4F00FF4F00FF4F00FF4F00FF4E00FF4E00FF4E00FF4E00FF4E00FF4D00FF4D00FF4D00FF4C00FF4B00FF4A00FF4A00FF4900FF4800FF4700FF4700FF4600FF4500FF4400
FF4200FF4100FF4000FF3E00FF3D00FF3C00FF3A00FF3900FF3700FF3500FF3200FF3000FF2E00FF2C00FF2A00FF2800FF2500FF2300FF2000FF1C00FF1900FF1500FF1100FF0E00
FF0A00FF0700FF0300FF0000
FF0000FF0500FF0A00FF1000FF1500FF1A00FF2000FF2500FF2A00FF3000FF3500FF3800FF3C00FF3F00FF4200FF4500FF4900FF4C00FF4F00FF5300FF5600FF5800FF5A00FF5C00
FF5E00FF6000FF6200FF6400FF6600FF6800FF6900FF6A00FF6B00FF6D00FF6E00FF6F00FF7000FF7100FF7200FF7300FF7400FF7400FF7500FF7500FF7500FF7600FF7600FF7600
FF7700FF7700FF7700FF7700FF7600FF7600FF7600FF7500FF7500FF7500FF7400FF7400FF7300FF7200FF7100FF7000FF6F00FF6E00FF6D00FF6B00FF6A00FF6900FF6800FF6600
FF6400FF6200FF6000FF5E00FF5C00FF5A00FF5800FF5600FF5300FF4F00FF4C00FF4900FF4500FF4200FF3F00FF3C00FF3800FF3500FF3000FF2B00FF2500FF2000FF1A00FF1500
FF1000FF0A00FF0500FF0000
FF0000FF0700FF0E00FF1500FF1C00FF2300FF2A00FF3200FF3900FF4000FF4700FF4B00FF5000FF5400FF5800FF5D00FF6100FF6500FF6A00FF6E00FF7200FF7500FF7800FF7A00
FF7D00FF8000FF8200FF8500FF8800FF8A00FF8D00FF8E00FF8F00FF9100FF9200FF9400FF9500FF9700FF9800FF9A00FF9B00FF9B00FF9C00FF9C00FF9D00FF9D00FF9D00FF9E00
FF9E00FF9F00FF9F00FF9E00FF9E00FF9D00FF9D00FF9D00FF9C00FF9C00FF9B00FF9B00FF9A00FF9800FF9700FF9500FF9400FF9200FF9100FF8F00FF8E00FF8D00FF8A00FF8800
FF8500FF8200FF8000FF7D00FF7A00FF7800FF7500FF7200FF6E00FF6A00FF6500FF6100FF5D00FF5800FF5400FF5000FF4B00FF4700FF4000FF3900FF3200FF2B00FF2300FF1C00
FF1500FF0E00FF0700FF0000
FF0000FF0800FF1100FF1A00FF2300FF2C00FF3500FF3E00FF4700FF5000FF5900FF5E00FF6400FF6900FF6F00FF7400FF7900FF7F00FF8400FF8A00FF8F00FF9200FF9600FF9900
FF9C00FFA000FFA300FFA600FFAA00FFAD00FFB000FFB200FFB300FFB500FFB700FFB900FFBB00FFBD00FFBE00FFC000FFC100FFC200FFC300FFC300FFC400FFC400FFC500FFC600
FFC600FFC700FFC700FFC600FFC600FFC500FFC400FFC400FFC300FFC300FFC200FFC200FFC000FFBE00FFBD00FFBB00FFB900FFB700FFB500FFB300FFB200FFB000FFAD00FFAA00
FFA600FFA300FFA000FF9C00FF9900FF9600FF9200FF8F00FF8A00FF8400FF7F00FF7A00FF7400FF6F00FF6900FF6400FF5E00FF5900FF5000FF4700FF3E00FF3500FF2C00FF2300
FF1A00FF1100FF0800FF0000
FF0000FF0A00FF1500FF2000FF2A00FF3500FF4000FF4B00FF5500FF6000FF6B00FF7100FF7800FF7E00FF8500FF8B00FF9200FF9800FF9F00FFA600FFAC00FFB000FFB400FFB800
FFBC00FFC000FFC400FFC800FFCC00FFD000FFD300FFD500FFD700FFDA00FFDC00FFDE00FFE000FFE200FFE500FFE700FFE800FFE900FFEA00FFEA00FFEB00FFEC00FFEC00FFED00
FFEE00FFEF00FFEF00FFEE00FFED00FFEC00FFEC00FFEB00FFEA00FFEA00FFE900FFE800FFE700FFE500FFE200FFE000FFDE00FFDC00FFDA00FFD700FFD500FFD300FFD000FFCC00
FFC800FFC400FFC000FFBC00FFB800FFB400FFB000FFAC00FFA600FF9F00FF9800FF9200FF8B00FF8500FF7E00FF7800FF7100FF6B00FF6000FF5600FF4B00FF4000FF3500FF2B00
FF2000FF1500FF0A00FF0000
FF0000FF0C00FF1900FF2500FF3200FF3E00FF4B00FF5700FF6400FF7000FF7C00FF8400FF8C00FF9300FF9B00FFA300FFAA00FFB200FFBA00FFC100FFC800FFCD00FFD200FFD600
FFDB00FFE000FFE400FFE900FFEE00FFF200FFF600FFF900FFFB00FFFE00FFFF00FCFF00F9FF00F7FF00F4FF00F2FF00F0FF00EFFF00EEFF00EDFF00EDFF00ECFF00EBFF00EAFF00
E9FF00E9FF00E9FF00E9FF00EAFF00EBFF00ECFF00EDFF00EDFF00EEFF00EFFF00F0FF00F2FF00F4FF00F7FF00F9FF00FCFF00FEFF00FFFE00FFFB00FFF900FFF600FFF200FFEE00
FFE900FFE400FFE000FFDB00FFD600FFD200FFCD00FFC800FFC100FFBA00FFB200FFAA00FFA300FF9B00FF9300FF8C00FF8400FF7C00FF7000FF6400FF5700FF4B00FF3E00FF3200
FF2500FF1900FF0C00FF0000
FF0000FF0E00FF1C00FF2A00FF3900FF4700FF5500FF6400FF7200FF8000FF8E00FF9700FFA000FFA800FFB100FFBA00FFC300FFCB00FFD400FFDD00FFE500FFEA00FFF000FFF500
FFFA00FFFF00FAFF00F5FF00EFFF00EAFF00E5FF00E3FF00E0FF00DDFF00DAFF00D7FF00D4FF00D1FF00CEFF00CBFF00C9FF00C8FF00C7FF00C6FF00C5FF00C4FF00C4FF00C3FF00
C2FF00C1FF00C1FF00C2FF00C3FF00C4FF00C4FF00C5FF00C6FF00C7FF00C8FF00C9FF00CBFF00CEFF00D1FF00D4FF00D7FF00DAFF00DDFF00E0FF00E2FF00E5FF00EAFF00EFFF00
F5FF00FAFF00FFFF00FFFA00FFF500FFF000FFEA00FFE500FFDD00FFD400FFCB00FFC300FFBA00FFB100FFA900FFA000FF9700FF8E00FF8100FF7200FF6400FF5600FF4700FF3900
FF2B00FF1C00FF0E00FF0000
FF0000FF1000FF2000FF3000FF4000FF5000FF6000FF7000FF8000FF9100FFA000FFAA00FFB400FFBE00FFC700FFD100FFDB00FFE500FFEF00FFF900FDFF00F7FF00F1FF00EBFF00
E5FF00DFFF00D9FF00D3FF00CDFF00C7FF00C2FF00BFFF00BCFF00B8FF00B5FF00B2FF00AFFF00ABFF00A8FF00A5FF00A2FF00A1FF00A0FF009FFF009EFF009DFF009CFF009BFF00
9AFF0099FF0099FF009AFF009BFF009CFF009DFF009EFF009FFF00A0FF00A1FF00A2FF00A5FF00A8FF00ABFF00AEFF00B2FF00B5FF00B8FF00BCFF00BFFF00C2FF00C7FF00CDFF00
D3FF00D9FF00DFFF00E5FF00EBFF00F1FF00F7FF00FDFF00FFF900FFEF00FFE500FFDB00FFD100FFC700FFBE00FFB400FFAA00FFA000FF9100FF8100FF7000FF6000FF5000FF4000
FF3000FF2000FF1000FF0000
FF0000FF1100FF2300FF3500FF4700FF5900FF6B00FF7C00FF8E00FFA000FFB100FFBC00FFC700FFD200FFDD00FFE800FFF300FFFD00F7FF00ECFF00E2FF00DBFF00D4FF00CEFF00
C7FF00C0FF00BAFF00B3FF00ACFF00A6FF00A0FF009CFF0099FF0095FF0091FF008EFF008AFF0087FF0083FF007FFF007DFF007BFF007AFF0079FF0078FF0077FF0076FF0075FF00
73FF0072FF0072FF0073FF0075FF0076FF0077FF0078FF0079FF007AFF007BFF007DFF007FFF0083FF0086FF008AFF008EFF0091FF0095FF0099FF009CFF00A0FF00A6FF00ACFF00
B3FF00BAFF00C0FF00C7FF00CEFF00D4FF00DBFF00E2FF00ECFF00F7FF00FFFE00FFF300FFE800FFDD00FFD200FFC700FFBC00FFB100FFA000FF8E00FF7C00FF6B00FF5900FF4700
FF3500FF2300FF1100FF0000
FF0000FF1200FF2500FF3800FF4B00FF5E00FF7100FF8400FF9700FFAA00FFBC00FFC800FFD400FFDF00FFEB00FFF700FDFF00F1FF00E5FF00D9FF00CFFF00C7FF00C0FF00B9FF00
B2FF00ABFF00A3FF009CFF0095FF008EFF0088FF0084FF0080FF007CFF0078FF0074FF0070FF006CFF0068FF0064FF0061FF0060FF005FFF005DFF005CFF005BFF005AFF0058FF00
57FF0056FF0056FF0057FF0058FF005AFF005BFF005CFF005DFF005FFF0060FF0061FF0064FF0068FF006CFF0070FF0074FF0078FF007CFF0080FF0084FF0087FF008EFF0095FF00
9CFF00A3FF00ABFF00B2FF00B9FF00C0FF00C7FF00CFFF00D9FF00E5FF00F1FF00FDFF00FFF700FFEB00FFDF00FFD400FFC800FFBC00FFAA00FF9700FF8400FF7100FF5E00FF4B00
FF3800FF2500FF1200FF0000
FF0000FF1400FF2800FF3C00FF5000FF6400FF7800FF8C00FFA000FFB400FFC700FFD400FFE000FFED00FFF900F9FF00EDFF00E0FF00D4FF00C7FF00BCFF00B4FF00ACFF00A4FF00
9DFF0095FF008DFF0085FF007EFF0076FF006FFF006BFF0067FF0062FF005EFF005AFF0056FF0051FF004DFF0049FF0046FF0044FF0043FF0042FF0040FF003FFF003EFF003CFF00
3BFF003AFF003AFF003BFF003CFF003EFF003FFF0040FF0042FF0043FF0044FF0046FF0049FF004DFF0051FF0056FF005AFF005EFF0062FF0067FF006BFF006FFF0076FF007EFF00
85FF008DFF0095FF009DFF00A4FF00ACFF00B4FF00BCFF00C7FF00D4FF00E0FF00EDFF00F9FF00FFF900FFED00FFE000FFD400FFC700FFB400FFA000FF8C00FF7800FF6400FF5000
FF3C00FF2800FF1400FF0000
FF0000FF1500FF2A00FF3F00FF5400FF6900FF7E00FF9300FFA800FFBE00FFD200FFDF00FFED00FFFA00F8FF00EAFF00DDFF00D0FF00C2FF00B5FF00A9FF00A0FF0098FF0090FF00
87FF007FFF0077FF006FFF0066FF005EFF0057FF0052FF004EFF0049FF0045FF0040FF003BFF0037FF0032FF002EFF002AFF0029FF0027FF0026FF0025FF0023FF0022FF0020FF00
1FFF001DFF001DFF001FFF0020FF0022FF0023FF0025FF0026FF0027FF0029FF002AFF002EFF0032FF0037FF003BFF0040FF0044FF0049FF004EFF0052FF0057FF005EFF0066FF00
6EFF0077FF007FFF0087FF0090FF0098FF00A0FF00A8FF00B5FF00C2FF00D0FF00DDFF00EAFF00F8FF00FFFA00FFED00FFDF00FFD200FFBE00FFA900FF9300FF7E00FF6900FF5400
FF3F00FF2A00FF1500FF0000
FF0000FF1600FF2C00FF4200FF5800FF6F00FF8500FF9B00FFB100FFC700FFDD00FFEB00FFF900F8FF00EAFF00DBFF00CDFF00BFFF00B1FF00A3FF0096FF008DFF0084FF007BFF00
72FF0069FF0061FF0058FF004FFF0046FF003EFF003AFF0035FF0030FF002BFF0026FF0021FF001CFF0017FF0013FF000FFF000DFF000CFF000AFF0009FF0007FF0006FF0004FF00
03FF0001FF0001FF0003FF0004FF0006FF0007FF0009FF000AFF000CFF000DFF000FFF0012FF0017FF001CFF0021FF0026FF002BFF0030FF0035FF0039FF003EFF0046FF004FFF00
58FF0060FF0069FF0072FF007BFF0084FF008DFF0095FF00A3FF00B1FF00BFFF00CDFF00DBFF00E9FF00F8FF00FFF900FFEB00FFDD00FFC700FFB100FF9B00FF8500FF6F00FF5800
FF4200FF2C00FF1600FF0000
FF0000FF1700FF2E00FF4500FF5D00FF7400FF8B00FFA300FFBA00FFD100FFE800FFF700F9FF00EAFF00DBFF00CCFF00BDFF00AEFF009FFF0090FF0083FF0079FF0070FF0066FF00
5DFF0054FF004AFF0041FF0037FF002EFF0026FF0021FF001CFF0016FF0011FF000CFF0007FF0002FF0000FF0200FF0800FF0B00FF0D00FF0F00FF1000FF1200FF1400FF1500FF17
00FF1900FF1A00FF1A00FF1900FF1700FF1500FF1400FF1200FF1000FF0F00FF0D00FF0B00FF0800FF0302FF0007FF000CFF0011FF0016FF001CFF0021FF0026FF002EFF0037FF00
41FF004AFF0053FF005DFF0066FF0070FF0079FF0082FF0090FF009FFF00AEFF00BDFF00CCFF00DBFF00EAFF00F9FF00FFF700FFE800FFD100FFBA00FFA300FF8B00FF7400FF5D00
FF4500FF2E00FF1700FF0000
FF0000FF1800FF3000FF4900FF6100FF7900FF9200FFAA00FFC300FFDB00FFF300FDFF00EDFF00DDFF00CDFF00BDFF00AEFF009EFF008EFF007EFF0070FF0066FF005CFF0052FF00
48FF003EFF0034FF002AFF0020FF0016FF000EFF0008FF0003FF0000FF0200FF0700FF0D00FF1200FF1800FF1D00FF2300FF2700FF2900FF2A00FF2C00FF2E00FF3000FF3100FF33
00FF3500FF3700FF3700FF3500FF3300FF3100FF3000FF2E00FF2C00FF2A00FF2900FF2700FF2300FF1D00FF1800FF1200FF0D00FF0700FF0202FF0008FF000DFF0016FF0020FF00
2AFF0034FF003EFF0048FF0052FF005CFF0065FF006FFF007EFF008EFF009EFF00ADFF00BDFF00CDFF00DDFF00EDFF00FCFF00FFF300FFDB00FFC300FFAA00FF9200FF7A00FF6100
FF4900FF3000FF1800FF0000
FF0000FF1900FF3200FF4C00FF6500FF7F00FF9800FFB200FFCB00FFE500FFFD00F1FF00E0FF00D0FF00BFFF00AEFF009EFF008DFF007DFF006CFF005DFF0052FF0048FF003DFF00
33FF0028FF001EFF0013FF0009FF0000FF0100FF0A00FF1000FF1500FF1B00FF2100FF2700FF2D00FF3200FF3800FF3E00FF4200FF4400FF4600FF4800FF4A00FF4C00FF4D00FF4F
00FF5100FF5300FF5300FF5100FF4F00FF4D00FF4C00FF4A00FF4800FF4600FF4400FF4200FF3E00FF3800FF3300FF2D00FF2700FF2100FF1B00FF1600FF1000FF0A00FF0109FF00
13FF001EFF0028FF0032FF003DFF0047FF0052FF005CFF006CFF007CFF008DFF009EFF00AEFF00BFFF00D0FF00E0FF00F1FF00FFFE00FFE500FFCB00FFB200FF9800FF7F00FF6500
FF4C00FF3200FF1900FF0000
FF0000FF1A00FF3500FF4F00FF6A00FF8400FF9F00FFBA00FFD400FFEF00F7FF00E5FF00D4FF00C2FF00B1FF009FFF008EFF007DFF006BFF005AFF0049FF003EFF0033FF0028FF00
1DFF0012FF0007FF0000FF0300FF0E00FF1900FF2200FF2800FF2E00FF3500FF3B00FF4100FF4700FF4D00FF5300FF5900FF5E00FF6000FF6200FF6400FF6500FF6700FF6900FF6B
00FF6D00FF6F00FF6F00FF6D00FF6B00FF6900FF6700FF6600FF6400FF6200FF6000FF5E00FF5900FF5300FF4D00FF4700FF4100FF3B00FF3500FF2F00FF2800FF2200FF1900FF0E
00FF0307FF0012FF001DFF0028FF0033FF003EFF0049FF0059FF006BFF007CFF008EFF009FFF00B1FF00C2FF00D4FF00E5FF00F7FF00FFEF00FFD400FFBA00FF9F00FF8400FF6A00
FF4F00FF3500FF1A00FF0000
FF0000FF1B00FF3700FF5300FF6E00FF8A00FFA600FFC100FFDD00FFF900ECFF00D9FF00C7FF00B5FF00A3FF0090FF007EFF006CFF005AFF0047FF0036FF002BFF001FFF0014FF00
08FF0000FF0200FF0E00FF1900FF2500FF3100FF3B00FF4100FF4700FF4E00FF5400FF5B00FF6100FF6800FF6E00FF7400FF7900FF7B00FF7D00FF7F00FF8100FF8300FF8500FF87
00FF8A00FF8C00FF8C00FF8A00FF8700FF8500FF8300FF8100FF7F00FF7D00FF7B00FF7900FF7400FF6E00FF6800FF6100FF5B00FF5400FF4E00FF4800FF4100FF3B00FF3100FF25
00FF1A00FF0E00FF0308FF0014FF001FFF002BFF0036FF0047FF0059FF006CFF007EFF0090FF00A3FF00B5FF00C7FF00D9FF00ECFF00FFF900FFDD00FFC100FFA600FF8A00FF6E00
FF5300FF3700FF1B00FF0000
FF0000FF1C00FF3900FF5600FF7200FF8F00FFAC00FFC800FFE500FDFF00E2FF00CFFF00BCFF00A9FF0096FF0083FF0070FF005DFF0049FF0036FF0025FF0019FF000DFF0001FF00
00FF0A00FF1700FF2300FF2F00FF3B00FF4700FF5100FF5800FF5F00FF6500FF6C00FF7300FF7A00FF8000FF8700FF8E00FF9300FF9500FF9700FF9900FF9B00FF9D00FFA000FFA2
00FFA400FFA600FFA600FFA400FFA200FFA000FF9D00FF9B00FF9900FF9700FF9500FF9300FF8E00FF8700FF8000FF7A00FF7300FF6C00FF6600FF5F00FF5800FF5200FF4700FF3B
00FF2F00FF2300FF1700FF0B00FF000CFF0019FF0025FF0036FF0049FF005CFF006FFF0082FF0095FF00A8FF00BBFF00CFFF00E2FF00FDFF00FFE500FFC800FFAC00FF8F00FF7200
FF5600FF3900FF1C00FF0000
FF0000FF1D00FF3A00FF5800FF7500FF9200FFB000FFCD00FFEA00F7FF00DBFF00C7FF00B4FF00A0FF008DFF0079FF0066FF0052FF003EFF002BFF0019FF000CFF0000FF0000FF0C
00FF1800FF2500FF3100FF3E00FF4A00FF5600FF6100FF6800FF6F00FF7600FF7D00FF8400FF8B00FF9200FF9900FFA000FFA500FFA700FFA900FFAB00FFAE00FFB000FFB200FFB4
00FFB600FFB900FFB900FFB700FFB400FFB200FFB000FFAE00FFAB00FFA900FFA700FFA500FFA000FF9900FF9200FF8B00FF8400FF7D00FF7600FF6F00FF6800FF6100FF5700FF4A
00FF3E00FF3100FF2500FF1800FF0C00FF000CFF0019FF002BFF003EFF0052FF0065FF0079FF008DFF00A0FF00B4FF00C7FF00DBFF00F7FF00FFEA00FFCD00FFB000FF9200FF7500
FF5800FF3A00FF1D00FF0000
FF0000FF1E00FF3C00FF5A00FF7800FF9600FFB400FFD200FFF000F1FF00D4FF00C0FF00ACFF0098FF0084FF0070FF005CFF0048FF0033FF001FFF000DFF0000FF0000FF0C00FF19
00FF2600FF3300FF3F00FF4C00FF5900FF6600FF7100FF7800FF7F00FF8700FF8E00FF9500FF9C00FFA300FFAA00FFB200FFB700FFB900FFBB00FFBE00FFC000FFC200FFC500FFC7
00FFC900FFCB00FFCB00FFC900FFC700FFC500FFC200FFC000FFBE00FFBB00FFB900FFB700FFB200FFAA00FFA300FF9C00FF9500FF8E00FF8700FF8000FF7800FF7100FF6600FF59
00FF4C00FF4000FF3300FF2600FF1900FF0C00FF000CFF001FFF0033FF0047FF005CFF0070FF0084FF0098FF00ACFF00C0FF00D4FF00F1FF00FFF000FFD200FFB400FF9600FF7800
FF5A00FF3C00FF1E00FF0000
FF0000FF1E00FF3D00FF5C00FF7A00FF9900FFB800FFD600FFF500EBFF00CEFF00B9FF00A4FF0090FF007BFF0066FF0052FF003DFF0028FF0014FF0001FF0000FF0C00FF1900FF26
00FF3300FF4100FF4E00FF5B00FF6800FF7600FF8100FF8800FF9000FF9700FF9F00FFA600FFAD00FFB500FFBC00FFC300FFC900FFCB00FFCE00FFD000FFD200FFD500FFD700FFD9
00FFDC00FFDE00FFDE00FFDC00FFD900FFD700FFD500FFD200FFD000FFCE00FFCB00FFC900FFC400FFBC00FFB500FFAD00FFA600FF9F00FF9700FF9000FF8900FF8100FF7600FF68
00FF5B00FF4E00FF4100FF3400FF2600FF1900FF0C00FF0014FF0028FF003DFF0052FF0066FF007BFF0090FF00A4FF00B9FF00CEFF00EBFF00FFF500FFD600FFB800FF9900FF7A00
FF5C00FF3D00FF1E00FF0000
FF0000FF1F00FF3E00FF5E00FF7D00FF9C00FFBC00FFDB00FFFA00E5FF00C7FF00B2FF009DFF0087FF0072FF005DFF0048FF0033FF001DFF0008FF0000FF0A00FF1800FF2600FF33
00FF4100FF4F00FF5C00FF6A00FF7700FF8500FF9100FF9800FFA000FFA800FFAF00FFB700FFBF00FFC600FFCE00FFD500FFDB00FFDD00FFE000FFE200FFE500FFE700FFEA00FFEC
00FFEF00FFF100FFF100FFEF00FFEC00FFEA00FFE700FFE500FFE200FFE000FFDD00FFDB00FFD500FFCE00FFC600FFBF00FFB700FFAF00FFA800FFA000FF9900FF9100FF8500FF78
00FF6A00FF5C00FF4F00FF4100FF3400FF2600FF1800FF0B08FF001DFF0032FF0048FF005DFF0072FF0087FF009CFF00B2FF00C7FF00E5FF00FFFA00FFDB00FFBC00FF9C00FF7D00
FF5E00FF3E00FF1F00FF0000
FF0000FF2000FF4000FF6000FF8000FFA000FFC000FFE000FFFF00DFFF00C0FF00ABFF0095FF007FFF0069FF0054FF003EFF0028FF0012FF0000FF0200FF1700FF2500FF3300FF41
00FF4F00FF5D00FF6B00FF7900FF8700FF9500FFA100FFA900FFB000FFB800FFC000FFC800FFD000FFD800FFDF00FFE700FFED00FFF000FFF200FFF500FFF700FFFA00FFFC00FFFF
00FEFF00FBFF00FBFF00FEFF00FFFF00FFFC00FFFA00FFF700FFF500FFF200FFF000FFED00FFE700FFE000FFD800FFD000FFC800FFC000FFB800FFB100FFA900FFA100FF9500FF87
00FF7900FF6B00FF5D00FF4F00FF4100FF3300FF2500FF1700FF0312FF0028FF003EFF0053FF0069FF007FFF0095FF00AAFF00C0FF00DFFF00FFFF00FFE000FFC000FFA000FF8000
FF6000FF4000FF2000FF0000
FF0000FF2000FF4100FF6200FF8200FFA300FFC400FFE400FAFF00D9FF00BAFF00A3FF008DFF0077FF0061FF004AFF0034FF001EFF0007FF0000FF0E00FF2300FF3100FF3F00FF4E
00FF5C00FF6B00FF7900FF8700FF9600FFA400FFB100FFB900FFC100FFC900FFD100FFD900FFE100FFE900FFF100FFF900FFFF00FDFF00FBFF00F8FF00F6FF00F3FF00F0FF00EEFF
00EBFF00E9FF00E9FF00EBFF00EEFF00F0FF00F3FF00F5FF00F8FF00FBFF00FDFF00FFFF00FFF900FFF100FFE900FFE100FFD900FFD100FFC900FFC100FFB900FFB100FFA400FF96
00FF8800FF7900FF6B00FF5C00FF4E00FF4000FF3100FF2300FF0E07FF001DFF0034FF004AFF0060FF0077FF008DFF00A3FF00BAFF00D9FF00FAFF00FFE400FFC400FFA300FF8200
FF6200FF4100FF2000FF0000
FF0000FF2100FF4200FF6400FF8500FFA600FFC800FFE900F5FF00D3FF00B3FF009CFF0085FF006FFF0058FF0041FF002AFF0013FF0000FF0300FF1900FF2F00FF3E00FF4C00FF5B
00FF6A00FF7900FF8700FF9600FFA500FFB400FFC100FFC900FFD100FFD900FFE200FFEA00FFF200FFFB00FCFF00F4FF00EEFF00EBFF00E8FF00E6FF00E3FF00E0FF00DEFF00DBFF
00D8FF00D6FF00D6FF00D8FF00DBFF00DEFF00E0FF00E3FF00E6FF00E8FF00EBFF00EEFF00F4FF00FCFF00FFFB00FFF200FFEA00FFE200FFDA00FFD100FFC900FFC100FFB400FFA5
00FF9600FF8800FF7900FF6A00FF5B00FF4C00FF3E00FF2F00FF1A00FF0313FF002AFF0041FF0058FF006EFF0085FF009CFF00B3FF00D3FF00F5FF00FFE900FFC800FFA600FF8500
FF6400FF4200FF2100FF0000
FF0000FF2200FF4400FF6600FF8800FFAA00FFCC00FFEE00EFFF00CDFF00ACFF0095FF007EFF0066FF004FFF0037FF0020FF0009FF0000FF0E00FF2500FF3B00FF4A00FF5900FF68
00FF7700FF8700FF9600FFA500FFB400FFC300FFD000FFD900FFE100FFEA00FFF200FFFB00FBFF00F3FF00EAFF00E2FF00DCFF00D9FF00D6FF00D4FF00D1FF00CEFF00CBFF00C9FF
00C6FF00C3FF00C3FF00C6FF00C8FF00CBFF00CEFF00D1FF00D3FF00D6FF00D9FF00DCFF00E2FF00EAFF00F3FF00FBFF00FFFB00FFF300FFEA00FFE200FFD900FFD100FFC300FFB4
00FFA500FF9600FF8700FF7800FF6800FF5900FF4A00FF3B00FF2500FF0E09FF0020FF0037FF004FFF0066FF007DFF0095FF00ACFF00CDFF00EFFF00FFEE00FFCC00FFAA00FF8800
FF6600FF4400FF2200FF0000
FF0000FF2200FF4500FF6800FF8A00FFAD00FFD000FFF200EAFF00C7FF00A6FF008EFF0076FF005EFF0046FF002EFF0016FF0000FF0100FF1900FF3100FF4700FF5600FF6600FF76
00FF8500FF9500FFA400FFB400FFC300FFD300FFE000FFE900FFF200FFFB00FCFF00F3FF00EAFF00E2FF00D9FF00D0FF00CAFF00C7FF00C4FF00C1FF00BEFF00BCFF00B9FF00B6FF
00B3FF00B0FF00B0FF00B3FF00B6FF00B9FF00BCFF00BEFF00C1FF00C4FF00C7FF00CAFF00D0FF00D9FF00E1FF00EAFF00F3FF00FCFF00FFFB00FFF200FFE900FFE000FFD300FFC3
00FFB400FFA400FF9500FF8500FF7600FF6600FF5700FF4700FF3100FF1900FF0116FF002EFF0046FF005EFF0076FF008EFF00A6FF00C7FF00EAFF00FFF200FFD000FFAD00FF8A00
FF6800FF4500FF2200FF0000
FF0000FF2300FF4600FF6900FF8D00FFB000FFD300FFF600E5FF00C2FF00A0FF0088FF006FFF0057FF003EFF0026FF000EFF0000FF0A00FF2200FF3B00FF5100FF6100FF7100FF81
00FF9100FFA100FFB100FFC100FFD000FFE000FFEE00FFF700FFFF00F6FF00EDFF00E4FF00DBFF00D2FF00C9FF00C0FF00BAFF00B7FF00B4FF00B1FF00AEFF00ABFF00A9FF00A6FF
00A3FF00A0FF00A0FF00A3FF00A6FF00A9FF00ABFF00AEFF00B1FF00B4FF00B7FF00BAFF00C0FF00C9FF00D2FF00DBFF00E4FF00EDFF00F6FF00FFFF00FFF700FFEE00FFE000FFD1
00FFC100FFB100FFA100FF9100FF8100FF7100FF6100FF5200FF3B00FF2200FF0A0DFF0026FF003EFF0057FF006FFF0087FF00A0FF00C2FF00E5FF00FFF600FFD300FFB000FF8D00
FF6900FF4600FF2300FF0000
FF0000FF2300FF4700FF6A00FF8E00FFB200FFD500FFF900E3FF00BFFF009CFF0084FF006BFF0052FF003AFF0021FF0008FF0000FF1000FF2800FF4100FF5800FF6800FF7800FF88
00FF9800FFA900FFB900FFC900FFD900FFE900FFF700FFFF00F6FF00EDFF00E4FF00DBFF00D2FF00C8FF00BFFF00B6FF00B0FF00ADFF00AAFF00A7FF00A4FF00A1FF009EFF009BFF
0098FF0095FF0095FF0098FF009BFF009EFF00A1FF00A4FF00A7FF00AAFF00ADFF00B0FF00B6FF00BFFF00C8FF00D1FF00DAFF00E4FF00EDFF00F6FF00FFFF00FFF700FFE900FFD9
00FFC900FFB900FFA900FF9900FF8900FF7800FF6800FF5800FF4100FF2900FF1008FF0021FF0039FF0052FF006BFF0084FF009CFF00BFFF00E2FF00FFF900FFD500FFB200FF8E00
FF6A00FF4700FF2300FF0000
FF0000FF2300FF4700FF6B00FF8F00FFB300FFD700FFFB00E0FF00BCFF0099FF0080FF0067FF004EFF0035FF001CFF0003FF0000FF1500FF2E00FF4700FF5F00FF6F00FF7F00FF90
00FFA000FFB000FFC100FFD100FFE100FFF200FFFF00F6FF00EDFF00E3FF00DAFF00D1FF00C8FF00BFFF00B5FF00ACFF00A5FF00A2FF009FFF009CFF009AFF0097FF0094FF0091FF
008EFF008BFF008BFF008EFF0091FF0094FF0096FF0099FF009CFF009FFF00A2FF00A5FF00ACFF00B5FF00BEFF00C8FF00D1FF00DAFF00E3FF00ECFF00F6FF00FFFF00FFF200FFE2
00FFD100FFC100FFB100FFA000FF9000FF8000FF6F00FF5F00FF4800FF2F00FF1602FF001BFF0034FF004EFF0067FF0080FF0099FF00BBFF00DFFF00FFFC00FFD800FFB400FF9000
FF6C00FF4800FF2400FF0000
FF0000FF2400FF4800FF6D00FF9100FFB500FFDA00FFFE00DDFF00B8FF0095FF007CFF0062FF0049FF0030FF0016FF0000FF0200FF1B00FF3500FF4E00FF6500FF7600FF8700FF97
00FFA800FFB800FFC900FFD900FFEA00FFFB00F6FF00EDFF00E3FF00DAFF00D1FF00C7FF00BEFF00B5FF00ABFF00A2FF009BFF0098FF0095FF0092FF008FFF008CFF0089FF0086FF
0083FF0080FF0080FF0083FF0086FF0089FF008CFF008FFF0092FF0095FF0098FF009BFF00A2FF00ABFF00B5FF00BEFF00C7FF00D1FF00DAFF00E3FF00EDFF00F6FF00FFFB00FFEA
00FFDA00FFC900FFB800FFA800FF9700FF8700FF7600FF6600FF4E00FF3500FF1B00FF0216FF0030FF0049FF0062FF007CFF0095FF00B8FF00DDFF00FFFE00FFDA00FFB500FF9100
FF6D00FF4800FF2400FF0000
FF0000FF2400FF4900FF6E00FF9200FFB700FFDC00FFFF00DAFF00B5FF0091FF0078FF005EFF0045FF002BFF0011FF0000FF0700FF2100FF3B00FF5400FF6C00FF7D00FF8E00FF9F
00FFAF00FFC000FFD100FFE200FFF200FCFF00EDFF00E4FF00DAFF00D1FF00C7FF00BEFF00B4FF00ABFF00A1FF0098FF0091FF008EFF008BFF0088FF0085FF0082FF007FFF007BFF
0078FF0075FF0075FF0078FF007BFF007EFF0082FF0085FF0088FF008BFF008EFF0091FF0098FF00A1FF00ABFF00B4FF00BEFF00C7FF00D1FF00DAFF00E3FF00EDFF00FCFF00FFF3
00FFE200FFD100FFC000FFB000FF9F00FF8E00FF7D00FF6C00FF5400FF3B00FF2100FF0811FF002BFF0044FF005EFF0078FF0091FF00B5FF00DAFF00FEFF00FFDC00FFB700FF9200
FF6E00FF4900FF2400FF0000
FF0000FF2500FF4A00FF6F00FF9400FFB900FFDE00FCFF00D7FF00B2FF008EFF0074FF005AFF0040FF0026FF000CFF0000FF0D00FF2700FF4100FF5B00FF7300FF8400FF9500FFA6
00FFB700FFC800FFD900FFEA00FFFB00F3FF00E4FF00DBFF00D1FF00C7FF00BEFF00B4FF00ABFF00A1FF0097FF008EFF0087FF0084FF0080FF007DFF007AFF0077FF0074FF0071FF
006EFF006BFF006BFF006EFF0071FF0074FF0077FF007AFF007DFF0080FF0083FF0087FF008EFF0097FF00A1FF00AAFF00B4FF00BEFF00C7FF00D1FF00DAFF00E4FF00F3FF00FFFB
00FFEA00FFD900FFC800FFB700FFA600FF9500FF8400FF7300FF5B00FF4100FF2700FF0D0CFF0026FF0040FF005AFF0074FF008EFF00B2FF00D7FF00FCFF00FFDE00FFB900FF9400
FF6F00FF4A00FF2500FF0000
FF0000FF2500FF4A00FF7000FF9500FFBB00FFE000F9FF00D4FF00AFFF008AFF0070FF0056FF003BFF0021FF0007FF0000FF1200FF2D00FF4700FF6100FF7A00FF8B00FF9C00FFAD
00FFBF00FFD000FFE100FFF200FBFF00EAFF00DBFF00D2FF00C8FF00BEFF00B4FF00ABFF00A1FF0097FF008DFF0084FF007CFF0079FF0076FF0073FF0070FF006DFF0069FF0066FF
0063FF0060FF0060FF0063FF0066FF0069FF006DFF0070FF0073FF0076FF0079FF007CFF0083FF008DFF0097FF00A1FF00AAFF00B4FF00BEFF00C8FF00D1FF00DBFF00EAFF00FBFF
00FFF200FFE100FFD000FFBF00FFAD00FF9C00FF8B00FF7A00FF6100FF4700FF2D00FF1307FF0021FF003BFF0056FF0070FF008AFF00AEFF00D4FF00F9FF00FFE000FFBB00FF9500
FF7000FF4A00FF2500FF0000
FF0000FF2500FF4B00FF7100FF9700FFBD00FFE200F7FF00D1FF00ABFF0087FF006CFF0051FF0037FF001CFF0002FF0000FF1800FF3200FF4D00FF6800FF8000FF9200FFA300FFB5
00FFC600FFD800FFE900FFFB00F3FF00E2FF00D2FF00C8FF00BFFF00B5FF00ABFF00A1FF0097FF008DFF0083FF0079FF0072FF006FFF006CFF0069FF0065FF0062FF005FFF005CFF
0059FF0055FF0055FF0059FF005CFF005FFF0062FF0065FF0068FF006CFF006FFF0072FF0079FF0083FF008DFF0097FF00A1FF00ABFF00B5FF00BEFF00C8FF00D2FF00E1FF00F3FF
00FFFB00FFE900FFD800FFC600FFB500FFA300FF9200FF8000FF6800FF4D00FF3300FF1802FF001CFF0037FF0051FF006CFF0086FF00ABFF00D1FF00F7FF00FFE200FFBD00FF9700
FF7100FF4B00FF2500FF0000
FF0000FF2600FF4C00FF7200FF9800FFBE00FFE500F4FF00CEFF00A8FF0083FF0068FF004DFF0032FF0017FF0000FF0200FF1D00FF3800FF5300FF6E00FF8700FF9900FFAA00FFBC
00FFCE00FFDF00FFF100FCFF00EAFF00D9FF00C9FF00BFFF00B5FF00ABFF00A1FF0097FF008DFF0083FF0079FF006FFF0068FF0065FF0061FF005EFF005BFF0058FF0054FF0051FF
004EFF004BFF004BFF004EFF0051FF0054FF0058FF005BFF005EFF0061FF0065FF0068FF006FFF0079FF0083FF008DFF0097FF00A1FF00ABFF00B5FF00BFFF00C9FF00D9FF00EAFF
00FCFF00FFF100FFE000FFCE00FFBC00FFAB00FF9900FF8700FF6E00FF5300FF3800FF1D00FF0317FF0032FF004DFF0068FF0083FF00A8FF00CEFF00F4FF00FFE500FFBE00FF9800
FF7200FF4C00FF2600FF0000
FF0000FF2600FF4D00FF7300FF9A00FFC000FFE700F2FF00CBFF00A5FF007FFF0064FF0049FF002EFF0013FF0000FF0800FF2300FF3E00FF5900FF7400FF8E00FFA000FFB200FFC3
00FFD500FFE700FFF900F4FF00E2FF00D0FF00C0FF00B6FF00ACFF00A2FF0098FF008EFF0084FF0079FF006FFF0065FF005EFF005AFF0057FF0054FF0050FF004DFF004AFF0047FF
0043FF0040FF0040FF0043FF0047FF004AFF004DFF0050FF0054FF0057FF005AFF005EFF0065FF006FFF0079FF0083FF008EFF0098FF00A2FF00ACFF00B6FF00C0FF00D0FF00E2FF
00F4FF00FFF900FFE700FFD600FFC400FFB200FFA000FF8E00FF7500FF5900FF3E00FF2300FF0812FF002EFF0049FF0064FF007FFF00A5FF00CBFF00F2FF00FFE700FFC000FF9A00
FF7300FF4D00FF2600FF0000
FF0000FF2600FF4D00FF7400FF9B00FFC100FFE800F0FF00C9FF00A2FF007DFF0061FF0046FF002AFF000FFF0000FF0B00FF2700FF4200FF5E00FF7900FF9300FFA500FFB700FFC9
00FFDB00FFED00FFFF00EEFF00DCFF00CAFF00BAFF00B0FF00A5FF009BFF0091FF0087FF007CFF0072FF0068FF005EFF0056FF0053FF004FFF004CFF0049FF0046FF0042FF003FFF
003CFF0038FF0038FF003CFF003FFF0042FF0045FF0049FF004CFF004FFF0053FF0056FF005EFF0068FF0072FF007CFF0087FF0091FF009BFF00A5FF00B0FF00BAFF00C9FF00DCFF
00EEFF00FFFF00FFED00FFDB00FFC900FFB700FFA500FF9300FF7900FF5E00FF4200FF2700FF0C0FFF002AFF0046FF0061FF007DFF00A2FF00C9FF00F0FF00FFE800FFC200FF9B00
FF7400FF4D00FF2600FF0000
FF0000FF2600FF4D00FF7400FF9B00FFC200FFE900EFFF00C8FF00A1FF007BFF0060FF0044FF0029FF000DFF0000FF0D00FF2900FF4400FF6000FF7B00FF9500FFA700FFB900FFCB
00FFDD00FFF000FDFF00EBFF00D9FF00C7FF00B7FF00ADFF00A2FF0098FF008EFF0084FF0079FF006FFF0065FF005AFF0053FF004FFF004CFF0049FF0045FF0042FF003FFF003BFF
0038FF0035FF0035FF0038FF003BFF003FFF0042FF0045FF0049FF004CFF004FFF0053FF005AFF0065FF006FFF0079FF0083FF008EFF0098FF00A2FF00ADFF00B7FF00C7FF00D9FF
00EBFF00FDFF00FFF000FFDE00FFCB00FFB900FFA700FF9500FF7B00FF6000FF4400FF2900FF0D0DFF0029FF0044FF0060FF007BFF00A1FF00C8FF00EFFF00FFE900FFC200FF9B00
FF7400FF4D00FF2600FF0000
FF0000FF2700FF4E00FF7500FF9C00FFC300FFEA00EEFF00C7FF00A0FF007AFF005FFF0043FF0027FF000CFF0000FF0F00FF2A00FF4600FF6200FF7D00FF9700FFA900FFBB00FFCE
00FFE000FFF200FBFF00E8FF00D6FF00C4FF00B4FF00AAFF009FFF0095FF008BFF0080FF0076FF006CFF0061FF0057FF004FFF004CFF0049FF0045FF0042FF003FFF003BFF0038FF
0035FF0031FF0031FF0035FF0038FF003BFF003FFF0042FF0045FF0049FF004CFF004FFF0057FF0061FF006CFF0076FF0080FF008BFF0095FF009FFF00AAFF00B4FF00C4FF00D6FF
00E8FF00FBFF00FFF200FFE000FFCE00FFBC00FFA900FF9700FF7D00FF6200FF4600FF2A00FF0F0CFF0027FF0043FF005FFF007AFF00A0FF00C7FF00EEFF00FFEA00FFC300FF9C00
FF7500FF4E00FF2700FF0000
FF0000FF2700FF4E00FF7500FF9C00FFC300FFEA00EDFF00C6FF009FFF0079FF005DFF0042FF0026FF000AFF0000FF1000FF2C00FF4800FF6400FF7F00FF9900FFAB00FFBE00FFD0
00FFE200FFF500F8FF00E6FF00D4FF00C1FF00B1FF00A7FF009CFF0092FF0088FF007DFF0073FF0069FF005EFF0054FF004CFF0049FF0045FF0042FF003FFF003BFF0038FF0035FF
0031FF002EFF002EFF0031FF0035FF0038FF003BFF003FFF0042FF0045FF0049FF004CFF0054FF005EFF0068FF0073FF007DFF0088FF0092FF009CFF00A7FF00B1FF00C1FF00D3FF
00E6FF00F8FF00FFF500FFE200FFD000FFBE00FFAC00FF9900FF7F00FF6400FF4800FF2C00FF110AFF0026FF0042FF005DFF0079FF009FFF00C6FF00EDFF00FFEA00FFC300FF9C00
FF7500FF4E00FF2700FF0000
FF0000FF2700FF4E00FF7500FF9D00FFC400FFEB00EDFF00C5FF009EFF0078FF005CFF0040FF0025FF0009FF0000FF1200FF2E00FF4A00FF6500FF8100FF9B00FFAE00FFC000FFD2
00FFE500FFF700F6FF00E3FF00D1FF00BEFF00AEFF00A4FF009AFF008FFF0085FF007AFF0070FF0065FF005BFF0050FF0049FF0045FF0042FF003FFF003BFF0038FF0035FF0031FF
002EFF002AFF002AFF002EFF0031FF0035FF0038FF003BFF003FFF0042FF0045FF0049FF0050FF005BFF0065FF0070FF007AFF0085FF008FFF0099FF00A4FF00AEFF00BEFF00D1FF
00E3FF00F5FF00FFF700FFE500FFD300FFC000FFAE00FF9B00FF8100FF6600FF4A00FF2E00FF1209FF0024FF0040FF005CFF0078FF009EFF00C5FF00EDFF00FFEB00FFC400FF9D00
FF7500FF4E00FF2700FF0000
FF0000FF2700FF4E00FF7600FF9D00FFC400FFEC00ECFF00C4FF009DFF0077FF005BFF003FFF0023FF0007FF0000FF1400FF3000FF4C00FF6700FF8300FF9D00FFB000FFC200FFD5
00FFE700FFFA00F3FF00E0FF00CEFF00BCFF00ABFF00A1FF0097FF008CFF0082FF0077FF006DFF0062FF0058FF004DFF0046FF0042FF003FFF003BFF0038FF0035FF0031FF002EFF
002AFF0027FF0027FF002AFF002EFF0031FF0034FF0038FF003BFF003FFF0042FF0045FF004DFF0058FF0062FF006DFF0077FF0081FF008CFF0096FF00A1FF00ABFF00BBFF00CEFF
00E0FF00F3FF00FFFA00FFE700FFD500FFC200FFB000FF9E00FF8400FF6800FF4C00FF3000FF1407FF0023FF003FFF005BFF0077FF009DFF00C4FF00ECFF00FFEC00FFC400FF9D00
FF7600FF4E00FF2700FF0000
FF0000FF2700FF4E00FF7600FF9D00FFC500FFEC00EBFF00C4FF009CFF0076FF005AFF003EFF0022FF0006FF0000FF1500FF3100FF4D00FF6900FF8500FFA000FFB200FFC500FFD7
00FFEA00FFFC00F0FF00DEFF00CBFF00B9FF00A9FF009EFF0094FF0089FF007FFF0074FF0069FF005FFF0054FF004AFF0042FF003FFF003BFF0038FF0035FF0031FF002EFF002AFF
0027FF0023FF0023FF0027FF002AFF002EFF0031FF0034FF0038FF003BFF003FFF0042FF004AFF0054FF005FFF0069FF0074FF007EFF0089FF0093FF009EFF00A8FF00B9FF00CBFF
00DEFF00F0FF00FFFC00FFEA00FFD700FFC500FFB200FFA000FF8600FF6A00FF4E00FF3200FF1606FF0022FF003EFF005AFF0076FF009CFF00C3FF00EBFF00FFED00FFC500FF9E00
FF7600FF4F00FF2700FF0000
FF0000FF2700FF4F00FF7600FF9E00FFC600FFED00EAFF00C3FF009BFF0075FF0058FF003CFF0020FF0004FF0000FF1700FF3300FF4F00FF6B00FF8700FFA200FFB400FFC700FFD9
00FFEC00FFFF00EEFF00DBFF00C9FF00B6FF00A6FF009BFF0091FF0086FF007BFF0071FF0066FF005CFF0051FF0047FF003FFF003BFF0038FF0035FF0031FF002EFF002AFF0027FF
0023FF0020FF0020FF0023FF0027FF002AFF002EFF0031FF0035FF0038FF003BFF003FFF0047FF0051FF005CFF0066FF0071FF007BFF0086FF0090FF009BFF00A6FF00B6FF00C8FF
00DBFF00EEFF00FFFF00FFEC00FFDA00FFC700FFB400FFA200FF8800FF6C00FF4F00FF3300FF1704FF0020FF003CFF0058FF0074FF009BFF00C2FF00EAFF00FFED00FFC600FF9E00
FF7600FF4F00FF2700FF0000
FF0000FF2700FF4F00FF7700FF9E00FFC600FFEE00E9FF00C2FF009AFF0073FF0057FF003BFF001FFF0003FF0000FF1900FF3500FF5100FF6D00FF8A00FFA400FFB600FFC900FFDC
00FFEF00FEFF00EBFF00D8FF00C6FF00B3FF00A3FF0098FF008EFF0083FF0078FF006EFF0063FF0059FF004EFF0043FF003CFF0038FF0035FF0031FF002EFF002AFF0027FF0023FF
0020FF001DFF001DFF0020FF0023FF0027FF002AFF002EFF0031FF0035FF0038FF003BFF0043FF004EFF0058FF0063FF006EFF0078FF0083FF008DFF0098FF00A3FF00B3FF00C6FF
00D8FF00EBFF00FEFF00FFEF00FFDC00FFC900FFB700FFA400FF8A00FF6D00FF5100FF3500FF1902FF001FFF003BFF0057FF0073FF009AFF00C2FF00E9FF00FFEE00FFC600FF9E00
FF7700FF4F00FF2700FF0000
FF0000FF2700FF4F00FF7700FF9F00FFC700FFEF00E9FF00C1FF0099FF0072FF0056FF003AFF001DFF0001FF0000FF1A00FF3700FF5300FF6F00FF8C00FFA600FFB900FFCB00FFDE
00FFF100FBFF00E9FF00D6FF00C3FF00B0FF00A0FF0095FF008BFF0080FF0075FF006BFF0060FF0055FF004BFF0040FF0038FF0035FF0031FF002EFF002AFF0027FF0023FF0020FF
001DFF0019FF0019FF001DFF0020FF0023FF0027FF002AFF002EFF0031FF0035FF0038FF0040FF004BFF0055FF0060FF006BFF0075FF0080FF008BFF0095FF00A0FF00B0FF00C3FF
00D6FF00E8FF00FBFF00FFF100FFDE00FFCC00FFB900FFA600FF8C00FF6F00FF5300FF3700FF1A01FF001DFF0039FF0056FF0072FF0099FF00C1FF00E9FF00FFEF00FFC700FF9F00
FF7700FF4F00FF2700FF0000
FF0000FF2700FF4F00FF7700FF9F00FFC700FFEF00E9FF00C1FF0099FF0072FF0056FF003AFF001DFF0001FF0000FF1A00FF3700FF5300FF6F00FF8C00FFA600FFB900FFCB00FFDE
00FFF100FBFF00E9FF00D6FF00C3FF00B0FF00A0FF0095FF008BFF0080FF0075FF006BFF0060FF0055FF004BFF0040FF0038FF0035FF0031FF002EFF002AFF0027FF0023FF0020FF
001DFF0019FF0019FF001DFF0020FF0023FF0027FF002AFF002EFF0031FF0035FF0038FF0040FF004BFF0055FF0060FF006BFF0075FF0080FF008AFF0095FF00A0FF00B0FF00C3FF
00D6FF00E8FF00FBFF00FFF100FFDE00FFCC00FFB900FFA600FF8C00FF6F00FF5300FF3700FF1A01FF001DFF0039FF0056FF0072FF0099FF00C1FF00E8FF00FFEF00FFC700FF9F00
FF7700FF4F00FF2700FF0000
FF0000FF2700FF4F00FF7700FF9E00FFC600FFEE00E9FF00C2FF009AFF0073FF0057FF003BFF001FFF0003FF0000FF1900FF3500FF5100FF6D00FF8A00FFA400FFB700FFC900FFDC
00FFEF00FEFF00EBFF00D8FF00C6FF00B3FF00A3FF0098FF008EFF0083FF0078FF006EFF0063FF0059FF004EFF0043FF003CFF0038FF0035FF0031FF002EFF002AFF0027FF0023FF
0020FF001DFF001DFF0020FF0023FF0027FF002AFF002EFF0031FF0035FF0038FF003BFF0043FF004EFF0058FF0063FF006EFF0078FF0083FF008DFF0098FF00A3FF00B3FF00C6FF
00D8FF00EBFF00FEFF00FFEF00FFDC00FFC900FFB700FFA400FF8A00FF6D00FF5100FF3500FF1902FF001FFF003BFF0057FF0073FF009AFF00C2FF00E9FF00FFEE00FFC600FF9E00
FF7700FF4F00FF2700FF0000
FF0000FF2700FF4F00FF7600FF9E00FFC600FFED00EAFF00C3FF009BFF0075FF0058FF003CFF0020FF0004FF0000FF1700FF3300FF4F00FF6B00FF8700FFA200FFB400FFC700FFD9
00FFEC00FFFF00EEFF00DBFF00C8FF00B6FF00A6FF009BFF0091FF0086FF007BFF0071FF0066FF005CFF0051FF0047FF003FFF003BFF0038FF0035FF0031FF002EFF002AFF0027FF
0023FF0020FF0020FF0023FF0027FF002AFF002EFF0031FF0035FF0038FF003BFF003FFF0046FF0051FF005CFF0066FF0071FF007BFF0086FF0090FF009BFF00A6FF00B6FF00C8FF
00DBFF00EEFF00FFFF00FFEC00FFDA00FFC700FFB400FFA200FF8800FF6C00FF4F00FF3300FF1704FF0020FF003CFF0058FF0074FF009BFF00C2FF00EAFF00FFED00FFC600FF9E00
FF7600FF4F00FF2700FF0000
FF0000FF2700FF4E00FF7600FF9D00FFC500FFEC00EBFF00C4FF009CFF0076FF005AFF003EFF0022FF0006FF0000FF1500FF3100FF4D00FF6900FF8500FFA000FFB200FFC500FFD7
00FFEA00FFFC00F0FF00DEFF00CBFF00B9FF00A9FF009EFF0094FF0089FF007EFF0074FF0069FF005FFF0054FF004AFF0042FF003FFF003BFF0038FF0035FF0031FF002EFF002AFF
0027FF0023FF0023FF0027FF002AFF002EFF0031FF0034FF0038FF003BFF003FFF0042FF004AFF0054FF005FFF0069FF0074FF007EFF0089FF0093FF009EFF00A8FF00B9FF00CBFF
00DEFF00F0FF00FFFC00FFEA00FFD700FFC500FFB200FFA000FF8600FF6A00FF4E00FF3200FF1605FF0022FF003EFF005AFF0076FF009CFF00C3FF00EBFF00FFED00FFC500FF9E00
FF7600FF4F00FF2700FF0000
FF0000FF2700FF4E00FF7600FF9D00FFC400FFEC00ECFF00C4FF009DFF0077FF005BFF003FFF0023FF0007FF0000FF1400FF3000FF4C00FF6700FF8300FF9D00FFB000FFC200FFD5
00FFE700FFFA00F3FF00E0FF00CEFF00BCFF00ABFF00A1FF0096FF008CFF0082FF0077FF006DFF0062FF0058FF004DFF0045FF0042FF003FFF003BFF0038FF0034FF0031FF002EFF
002AFF0027FF0027FF002AFF002EFF0031FF0034FF0038FF003BFF003FFF0042FF0045FF004DFF0058FF0062FF006CFF0077FF0081FF008CFF0096FF00A1FF00ABFF00BBFF00CEFF
00E0FF00F3FF00FFFA00FFE700FFD500FFC200FFB000FF9E00FF8400FF6800FF4C00FF3000FF1407FF0023FF003FFF005BFF0077FF009DFF00C4FF00ECFF00FFEC00FFC400FF9D00
FF7600FF4E00FF2700FF0000
FF0000FF2700FF4E00FF7500FF9D00FFC400FFEB00EDFF00C5FF009EFF0078FF005CFF0040FF0025FF0009FF0000FF1200FF2E00FF4A00FF6600FF8100FF9B00FFAE00FFC000FFD2
00FFE500FFF700F5FF00E3FF00D1FF00BEFF00AEFF00A4FF0099FF008FFF0085FF007AFF0070FF0065FF005BFF0050FF0049FF0045FF0042FF003FFF003BFF0038FF0034FF0031FF
002EFF002AFF002AFF002EFF0031FF0034FF0038FF003BFF003FFF0042FF0045FF0049FF0050FF005BFF0065FF0070FF007AFF0084FF008FFF0099FF00A4FF00AEFF00BEFF00D1FF
00E3FF00F5FF00FFF700FFE500FFD300FFC000FFAE00FF9B00FF8100FF6600FF4A00FF2E00FF1209FF0024FF0040FF005CFF0078FF009EFF00C5FF00EDFF00FFEB00FFC400FF9D00
FF7500FF4E00FF2700FF0000
FF0000FF2700FF4E00FF7500FF9C00FFC300FFEA00EDFF00C6FF009FFF0079FF005DFF0042FF0026FF000AFF0000FF1000FF2C00FF4800FF6400FF7F00FF9900FFAB00FFBE00FFD0
00FFE200FFF500F8FF00E6FF00D3FF00C1FF00B1FF00A7FF009CFF0092FF0088FF007DFF0073FF0068FF005EFF0054FF004CFF0049FF0045FF0042FF003FFF003BFF0038FF0035FF
0031FF002EFF002EFF0031FF0035FF0038FF003BFF003FFF0042FF0045FF0049FF004CFF0054FF005EFF0068FF0073FF007DFF0088FF0092FF009CFF00A7FF00B1FF00C1FF00D3FF
00E6FF00F8FF00FFF500FFE200FFD000FFBE00FFAC00FF9900FF7F00FF6400FF4800FF2C00FF110AFF0026FF0042FF005DFF0079FF009FFF00C6FF00EDFF00FFEA00FFC300FF9C00
FF7500FF4E00FF2700FF0000
FF0000FF2700FF4E00FF7500FF9C00FFC300FFEA00EEFF00C7FF00A0FF007AFF005FFF0043FF0027FF000CFF0000FF0F00FF2A00FF4600FF6200FF7D00FF9700FFA900FFBB00FFCE
00FFE000FFF200FBFF00E8FF00D6FF00C4FF00B4FF00AAFF009FFF0095FF008BFF0080FF0076FF006CFF0061FF0057FF004FFF004CFF0049FF0045FF0042FF003FFF003BFF0038FF
0035FF0031FF0031FF0035FF0038FF003BFF003FFF0042FF0045FF0049FF004CFF004FFF0057FF0061FF006CFF0076FF0080FF008BFF0095FF009FFF00AAFF00B4FF00C4FF00D6FF
00E8FF00FBFF00FFF200FFE000FFCE00FFBC00FFA900FF9700FF7D00FF6200FF4600FF2B00FF0F0CFF0027FF0043FF005FFF007AFF00A0FF00C7FF00EEFF00FFEA00FFC300FF9C00
FF7500FF4E00FF2700FF0000
FF0000FF2600FF4D00FF7400FF9B00FFC200FFE900EFFF00C8FF00A1FF007BFF0060FF0044FF0029FF000DFF0000FF0D00FF2900FF4400FF6000FF7B00FF9500FFA700FFB900FFCB
00FFDD00FFF000FDFF00EBFF00D9FF00C7FF00B7FF00ADFF00A2FF0098FF008EFF0083FF0079FF006FFF0065FF005AFF0053FF004FFF004CFF0049FF0045FF0042FF003FFF003BFF
0038FF0035FF0035FF0038FF003BFF003FFF0042FF0045FF0049FF004CFF004FFF0053FF005AFF0064FF006FFF0079FF0083FF008EFF0098FF00A2FF00ADFF00B7FF00C7FF00D9FF
00EBFF00FDFF00FFF000FFDE00FFCB00FFB900FFA700FF9500FF7B00FF6000FF4400FF2900FF0D0DFF0029FF0044FF0060FF007BFF00A1FF00C8FF00EFFF00FFE900FFC200FF9B00
FF7400FF4D00FF2600FF0000
FF0000FF2600FF4D00FF7400FF9B00FFC200FFE800F0FF00C9FF00A2FF007DFF0061FF0046FF002AFF000FFF0000FF0B00FF2700FF4200FF5E00FF7900FF9300FFA500FFB700FFC9
00FFDB00FFED00FFFF00EEFF00DCFF00CAFF00BAFF00B0FF00A5FF009BFF0091FF0087FF007CFF0072FF0068FF005EFF0056FF0053FF004FFF004CFF0049FF0045FF0042FF003FFF
003BFF0038FF0038FF003BFF003FFF0042FF0045FF0049FF004CFF004FFF0053FF0056FF005DFF0068FF0072FF007CFF0086FF0091FF009BFF00A5FF00AFFF00BAFF00C9FF00DCFF
00EEFF00FFFF00FFED00FFDB00FFC900FFB700FFA500FF9300FF7900FF5E00FF4200FF2700FF0C0FFF002AFF0046FF0061FF007CFF00A2FF00C9FF00F0FF00FFE800FFC200FF9B00
FF7400FF4D00FF2600FF0000
FF0000FF2600FF4D00FF7300FF9A00FFC000FFE700F2FF00CBFF00A5FF007FFF0064FF0049FF002EFF0012FF0000FF0800FF2300FF3E00FF5900FF7400FF8E00FFA000FFB200FFC4
00FFD500FFE700FFF900F4FF00E2FF00D0FF00C0FF00B6FF00ACFF00A2FF0098FF008EFF0083FF0079FF006FFF0065FF005EFF005AFF0057FF0054FF0050FF004DFF004AFF0047FF
0043FF0040FF0040FF0043FF0046FF004AFF004DFF0050FF0054FF0057FF005AFF005DFF0065FF006FFF0079FF0083FF008DFF0098FF00A2FF00ACFF00B6FF00C0FF00D0FF00E2FF
00F4FF00FFF900FFE800FFD600FFC400FFB200FFA000FF8E00FF7500FF5900FF3E00FF2300FF0812FF002EFF0049FF0064FF007FFF00A5FF00CBFF00F2FF00FFE700FFC000FF9A00
FF7300FF4D00FF2600FF0000
FF0000FF2600FF4C00FF7200FF9800FFBE00FFE500F4FF00CEFF00A8FF0083FF0068FF004DFF0032FF0017FF0000FF0300FF1D00FF3800FF5300FF6E00FF8700FF9900FFAA00FFBC
00FFCE00FFE000FFF100FCFF00EAFF00D9FF00C9FF00BFFF00B5FF00ABFF00A1FF0097FF008DFF0083FF0079FF006FFF0068FF0065FF0061FF005EFF005BFF0058FF0054FF0051FF
004EFF004BFF004BFF004EFF0051FF0054FF0058FF005BFF005EFF0061FF0064FF0068FF006FFF0079FF0083FF008DFF0097FF00A1FF00ABFF00B5FF00BFFF00C9FF00D9FF00EAFF
00FCFF00FFF100FFE000FFCE00FFBC00FFAB00FF9900FF8700FF6E00FF5300FF3800FF1E00FF0317FF0032FF004DFF0068FF0083FF00A8FF00CEFF00F4FF00FFE500FFBE00FF9800
FF7200FF4C00FF2600FF0000
FF0000FF2500FF4B00FF7100FF9700FFBD00FFE200F7FF00D1FF00ABFF0086FF006CFF0051FF0037FF001CFF0002FF0000FF1800FF3300FF4D00FF6800FF8000FF9200FFA300FFB5
00FFC600FFD800FFE900FFFB00F3FF00E1FF00D2FF00C8FF00BEFF00B5FF00ABFF00A1FF0097FF008DFF0083FF0079FF0072FF006FFF006CFF0068FF0065FF0062FF005FFF005CFF
0058FF0055FF0055FF0058FF005CFF005FFF0062FF0065FF0068FF006CFF006FFF0072FF0079FF0083FF008DFF0097FF00A1FF00ABFF00B4FF00BEFF00C8FF00D2FF00E1FF00F3FF
00FFFB00FFE900FFD800FFC600FFB500FFA300FF9200FF8100FF6800FF4D00FF3300FF1802FF001CFF0037FF0051FF006CFF0086FF00ABFF00D1FF00F7FF00FFE200FFBD00FF9700
FF7100FF4B00FF2500FF0000
FF0000FF2500FF4A00FF7000FF9500FFBB00FFE000F9FF00D4FF00AEFF008AFF0070FF0056FF003BFF0021FF0007FF0000FF1200FF2D00FF4700FF6100FF7A00FF8B00FF9C00FFAD
00FFBF00FFD000FFE100FFF200FBFF00EAFF00DBFF00D1FF00C8FF00BEFF00B4FF00AAFF00A1FF0097FF008DFF0083FF007CFF0079FF0076FF0073FF0070FF006DFF0069FF0066FF
0063FF0060FF0060FF0063FF0066FF0069FF006CFF0070FF0073FF0076FF0079FF007CFF0083FF008DFF0097FF00A1FF00AAFF00B4FF00BEFF00C8FF00D1FF00DBFF00EAFF00FBFF
00FFF200FFE100FFD000FFBF00FFAE00FF9C00FF8B00FF7A00FF6100FF4700FF2D00FF1307FF0021FF003BFF0056FF0070FF008AFF00AEFF00D4FF00F9FF00FFE000FFBB00FF9500
FF7000FF4A00FF2500FF0000
FF0000FF2500FF4A00FF6F00FF9400FFB900FFDE00FCFF00D7FF00B2FF008EFF0074FF005AFF0040FF0026FF000CFF0000FF0D00FF2700FF4100FF5B00FF7300FF8400FF9500FFA6
00FFB700FFC800FFD900FFEA00FFFB00F3FF00E4FF00DAFF00D1FF00C7FF00BEFF00B4FF00AAFF00A1FF0097FF008EFF0087FF0083FF0080FF007DFF007AFF0077FF0074FF0071FF
006EFF006BFF006BFF006EFF0071FF0074FF0077FF007AFF007DFF0080FF0083FF0086FF008DFF0097FF00A1FF00AAFF00B4FF00BEFF00C7FF00D1FF00DAFF00E4FF00F3FF00FFFB
00FFEA00FFD900FFC800FFB700FFA600FF9500FF8400FF7300FF5B00FF4100FF2700FF0D0CFF0026FF0040FF005AFF0074FF008EFF00B2FF00D7FF00FCFF00FFDE00FFB900FF9400
FF6F00FF4A00FF2500FF0000
FF0000FF2400FF4900FF6E00FF9200FFB700FFDC00FEFF00DAFF00B5FF0091FF0078FF005EFF0044FF002BFF0011FF0000FF0700FF2100FF3B00FF5400FF6C00FF7D00FF8E00FF9F
00FFAF00FFC000FFD100FFE200FFF300FCFF00EDFF00E4FF00DAFF00D1FF00C7FF00BEFF00B4FF00ABFF00A1FF0098FF0091FF008EFF008BFF0088FF0085FF0081FF007EFF007BFF
0078FF0075FF0075FF0078FF007BFF007EFF0081FF0084FF0088FF008BFF008EFF0091FF0098FF00A1FF00ABFF00B4FF00BEFF00C7FF00D0FF00DAFF00E3FF00EDFF00FCFF00FFF3
00FFE200FFD100FFC000FFB000FF9F00FF8E00FF7D00FF6C00FF5500FF3B00FF2100FF0811FF002BFF0044FF005EFF0078FF0091FF00B5FF00DAFF00FEFF00FFDC00FFB700FF9200
FF6E00FF4900FF2400FF0000
FF0000FF2400FF4800FF6D00FF9100FFB500FFDA00FFFE00DDFF00B8FF0095FF007CFF0062FF0049FF0030FF0016FF0000FF0200FF1B00FF3500FF4E00FF6600FF7600FF8700FF97
00FFA800FFB800FFC900FFDA00FFEA00FFFB00F6FF00EDFF00E3FF00DAFF00D1FF00C7FF00BEFF00B5FF00ABFF00A2FF009BFF0098FF0095FF0092FF008FFF008CFF0089FF0086FF
0083FF0080FF0080FF0083FF0086FF0089FF008CFF008FFF0092FF0095FF0098FF009BFF00A2FF00ABFF00B4FF00BEFF00C7FF00D0FF00DAFF00E3FF00EDFF00F6FF00FFFB00FFEA
00FFDA00FFC900FFB900FFA800FF9700FF8700FF7600FF6600FF4E00FF3500FF1B00FF0216FF0030FF0049FF0062FF007CFF0095FF00B8FF00DDFF00FFFE00FFDA00FFB500FF9100
FF6D00FF4800FF2400FF0000
FF0000FF2300FF4700FF6B00FF8F00FFB300FFD700FFFB00E0FF00BCFF0099FF0080FF0067FF004EFF0035FF001CFF0002FF0000FF1600FF2F00FF4800FF5F00FF6F00FF8000FF90
00FFA000FFB100FFC100FFD100FFE200FFF200FFFF00F6FF00ECFF00E3FF00DAFF00D1FF00C8FF00BEFF00B5FF00ACFF00A5FF00A2FF009FFF009CFF0099FF0096FF0093FF0090FF
008DFF008BFF008AFF008DFF0090FF0093FF0096FF0099FF009CFF009FFF00A2FF00A5FF00ACFF00B5FF00BEFF00C8FF00D1FF00DAFF00E3FF00ECFF00F6FF00FFFF00FFF200FFE2
00FFD100FFC100FFB100FFA000FF9000FF8000FF6F00FF5F00FF4800FF2F00FF1602FF001BFF0034FF004DFF0067FF0080FF0099FF00BBFF00DFFF00FFFC00FFD800FFB400FF9000
FF6C00FF4800FF2400FF0000
FF0000FF2300FF4700FF6A00FF8E00FFB200FFD500FFF900E2FF00BFFF009CFF0084FF006BFF0052FF0039FF0021FF0008FF0000FF1000FF2800FF4100FF5800FF6800FF7800FF89
00FF9900FFA900FFB900FFC900FFD900FFE900FFF700FFFF00F6FF00EDFF00E3FF00DAFF00D1FF00C8FF00BFFF00B6FF00B0FF00ADFF00AAFF00A7FF00A4FF00A1FF009EFF009BFF
0098FF0095FF0095FF0098FF009BFF009EFF00A1FF00A4FF00A7FF00AAFF00ADFF00AFFF00B6FF00BFFF00C8FF00D1FF00DAFF00E3FF00EDFF00F6FF00FFFF00FFF700FFE900FFD9
00FFC900FFB900FFA900FF9900FF8900FF7900FF6800FF5800FF4100FF2900FF1008FF0021FF0039FF0052FF006BFF0083FF009CFF00BFFF00E2FF00FFF900FFD500FFB200FF8E00
FF6A00FF4700FF2300FF0000
FF0000FF2300FF4600FF6900FF8D00FFB000FFD300FFF600E5FF00C2FF00A0FF0087FF006FFF0057FF003EFF0026FF000DFF0000FF0A00FF2200FF3B00FF5200FF6100FF7100FF81
00FF9100FFA100FFB100FFC100FFD100FFE000FFEE00FFF700FFFF00F6FF00EDFF00E4FF00DBFF00D2FF00C9FF00C0FF00BAFF00B7FF00B4FF00B1FF00AEFF00ABFF00A8FF00A6FF
00A3FF00A0FF00A0FF00A3FF00A6FF00A8FF00ABFF00AEFF00B1FF00B4FF00B7FF00BAFF00C0FF00C9FF00D2FF00DBFF00E4FF00EDFF00F6FF00FFFF00FFF700FFEE00FFE100FFD1
00FFC100FFB100FFA100FF9100FF8100FF7100FF6100FF5200FF3B00FF2200FF0A0DFF0026FF003EFF0057FF006FFF0087FF00A0FF00C2FF00E5FF00FFF600FFD300FFB000FF8D00
FF6900FF4600FF2300FF0000
FF0000FF2200FF4500FF6800FF8A00FFAD00FFD000FFF200EAFF00C7FF00A6FF008EFF0076FF005EFF0046FF002EFF0016FF0000FF0100FF1900FF3100FF4700FF5700FF6600FF76
00FF8500FF9500FFA400FFB400FFC300FFD300FFE000FFE900FFF200FFFB00FCFF00F3FF00EAFF00E1FF00D9FF00D0FF00C9FF00C7FF00C4FF00C1FF00BEFF00BBFF00B9FF00B6FF
00B3FF00B0FF00B0FF00B3FF00B6FF00B9FF00BBFF00BEFF00C1FF00C4FF00C7FF00C9FF00D0FF00D9FF00E1FF00EAFF00F3FF00FCFF00FFFB00FFF200FFE900FFE100FFD300FFC4
00FFB400FFA400FF9500FF8500FF7600FF6600FF5700FF4700FF3100FF1900FF0116FF002EFF0046FF005EFF0076FF008EFF00A6FF00C7FF00EAFF00FFF200FFD000FFAD00FF8A00
FF6800FF4500FF2200FF0000
FF0000FF2200FF4400FF6600FF8800FFAA00FFCC00FFEE00EFFF00CDFF00ACFF0095FF007EFF0066FF004FFF0037FF0020FF0009FF0000FF0E00FF2500FF3B00FF4A00FF5900FF68
00FF7800FF8700FF9600FFA500FFB400FFC300FFD100FFD900FFE200FFEA00FFF300FFFB00FBFF00F3FF00EAFF00E2FF00DCFF00D9FF00D6FF00D3FF00D1FF00CEFF00CBFF00C8FF
00C6FF00C3FF00C3FF00C6FF00C8FF00CBFF00CEFF00D1FF00D3FF00D6FF00D9FF00DCFF00E2FF00EAFF00F3FF00FBFF00FFFB00FFF300FFEA00FFE200FFD900FFD100FFC400FFB4
00FFA500FF9600FF8700FF7800FF6900FF5900FF4A00FF3B00FF2500FF0E08FF0020FF0037FF004FFF0066FF007DFF0095FF00ACFF00CDFF00EFFF00FFEE00FFCC00FFAA00FF8800
FF6600FF4400FF2200FF0000
FF0000FF2100FF4200FF6400FF8500FFA600FFC800FFE900F5FF00D3FF00B3FF009CFF0085FF006EFF0058FF0041FF002AFF0013FF0000FF0300FF1A00FF2F00FF3E00FF4C00FF5B
00FF6A00FF7900FF8800FF9600FFA500FFB400FFC100FFC900FFD100FFDA00FFE200FFEA00FFF200FFFB00FCFF00F4FF00EEFF00EBFF00E8FF00E6FF00E3FF00E0FF00DEFF00DBFF
00D8FF00D6FF00D6FF00D8FF00DBFF00DEFF00E0FF00E3FF00E6FF00E8FF00EBFF00EEFF00F4FF00FCFF00FFFB00FFF200FFEA00FFE200FFDA00FFD100FFC900FFC100FFB400FFA5
00FF9600FF8800FF7900FF6A00FF5B00FF4D00FF3E00FF2F00FF1A00FF0313FF002AFF0041FF0058FF006EFF0085FF009CFF00B3FF00D3FF00F5FF00FFE900FFC800FFA600FF8500
FF6400FF4200FF2100FF0000
FF0000FF2000FF4100FF6200FF8200FFA300FFC400FFE400FAFF00D9FF00BAFF00A3FF008DFF0077FF0060FF004AFF0034FF001EFF0007FF0000FF0E00FF2300FF3100FF4000FF4E
00FF5C00FF6B00FF7900FF8800FF9600FFA400FFB100FFB900FFC100FFC900FFD100FFD900FFE100FFE900FFF100FFF900FFFF00FDFF00FBFF00F8FF00F5FF00F3FF00F0FF00EEFF
00EBFF00E8FF00E8FF00EBFF00EEFF00F0FF00F3FF00F5FF00F8FF00FBFF00FDFF00FFFF00FFF900FFF100FFE900FFE100FFD900FFD100FFC900FFC100FFB900FFB100FFA400FF96
00FF8800FF7900FF6B00FF5C00FF4E00FF4000FF3100FF2300FF0E07FF001DFF0034FF004AFF0060FF0077FF008DFF00A3FF00BAFF00D9FF00FAFF00FFE400FFC400FFA300FF8200
FF6200FF4100FF2000FF0000
FF0000FF2000FF4000FF6000FF8000FFA000FFC000FFE000FFFF00DFFF00C0FF00ABFF0095FF007FFF0069FF0053FF003EFF0028FF0012FF0000FF0300FF1700FF2500FF3300FF41
00FF4F00FF5D00FF6B00FF7900FF8700FF9500FFA100FFA900FFB100FFB800FFC000FFC800FFD000FFD800FFE000FFE700FFED00FFF000FFF200FFF500FFF700FFFA00FFFC00FFFF
00FEFF00FBFF00FBFF00FEFF00FFFF00FFFC00FFFA00FFF700FFF500FFF200FFF000FFED00FFE800FFE000FFD800FFD000FFC800FFC000FFB900FFB100FFA900FFA100FF9500FF87
00FF7900FF6B00FF5D00FF4F00FF4100FF3300FF2500FF1700FF0312FF0028FF003EFF0053FF0069FF007FFF0095FF00AAFF00C0FF00DFFF00FFFF00FFE000FFC000FFA000FF8000
FF6000FF4000FF2000FF0000
FF0000FF1F00FF3E00FF5E00FF7D00FF9C00FFBC00FFDB00FFFA00E5FF00C7FF00B2FF009DFF0087FF0072FF005DFF0048FF0032FF001DFF0008FF0000FF0B00FF1800FF2600FF34
00FF4100FF4F00FF5C00FF6A00FF7800FF8500FF9100FF9900FFA000FFA800FFB000FFB700FFBF00FFC600FFCE00FFD600FFDB00FFDE00FFE000FFE200FFE500FFE700FFEA00FFEC
00FFEF00FFF100FFF100FFEF00FFEC00FFEA00FFE700FFE500FFE200FFE000FFDE00FFDB00FFD600FFCE00FFC600FFBF00FFB700FFB000FFA800FFA000FF9900FF9100FF8500FF78
00FF6A00FF5C00FF4F00FF4100FF3400FF2600FF1800FF0B08FF001DFF0032FF0048FF005DFF0072FF0087FF009CFF00B2FF00C7FF00E5FF00FFFA00FFDB00FFBC00FF9C00FF7D00
FF5E00FF3E00FF1F00FF0000
FF0000FF1E00FF3D00FF5C00FF7A00FF9900FFB800FFD600FFF500EBFF00CEFF00B9FF00A4FF0090FF007BFF0066FF0052FF003DFF0028FF0014FF0000FF0000FF0C00FF1900FF26
00FF3400FF4100FF4E00FF5B00FF6800FF7600FF8100FF8900FF9000FF9700FF9F00FFA600FFAD00FFB500FFBC00FFC400FFC900FFCB00FFCE00FFD000FFD300FFD500FFD700FFDA
00FFDC00FFDE00FFDE00FFDC00FFDA00FFD700FFD500FFD300FFD000FFCE00FFCB00FFC900FFC400FFBC00FFB500FFAE00FFA600FF9F00FF9700FF9000FF8900FF8100FF7600FF69
00FF5B00FF4E00FF4100FF3400FF2600FF1900FF0C00FF0014FF0028FF003DFF0052FF0066FF007BFF0090FF00A4FF00B9FF00CEFF00EBFF00FFF500FFD600FFB800FF9900FF7A00
FF5C00FF3D00FF1E00FF0000
FF0000FF1E00FF3C00FF5A00FF7800FF9600FFB400FFD200FFF000F1FF00D4FF00C0FF00ACFF0098FF0084FF0070FF005CFF0047FF0033FF001FFF000CFF0000FF0000FF0C00FF19
00FF2600FF3300FF4000FF4C00FF5900FF6600FF7100FF7800FF8000FF8700FF8E00FF9500FF9C00FFA300FFAB00FFB200FFB700FFB900FFBC00FFBE00FFC000FFC200FFC500FFC7
00FFC900FFCC00FFCC00FFC900FFC700FFC500FFC200FFC000FFBE00FFBC00FFB900FFB700FFB200FFAB00FFA300FF9C00FF9500FF8E00FF8700FF8000FF7900FF7100FF6600FF59
00FF4D00FF4000FF3300FF2600FF1900FF0C00FF000CFF001FFF0033FF0047FF005BFF0070FF0084FF0098FF00ACFF00C0FF00D4FF00F1FF00FFF000FFD200FFB400FF9600FF7800
FF5A00FF3C00FF1E00FF0000
FF0000FF1D00FF3A00FF5800FF7500FF9200FFB000FFCD00FFEA00F7FF00DBFF00C7FF00B4FF00A0FF008DFF0079FF0065FF0052FF003EFF002BFF0019FF000CFF0000FF0000FF0C
00FF1800FF2500FF3100FF3E00FF4A00FF5700FF6100FF6800FF6F00FF7600FF7D00FF8400FF8B00FF9200FF9900FFA000FFA500FFA700FFA900FFAC00FFAE00FFB000FFB200FFB4
00FFB700FFB900FFB900FFB700FFB400FFB200FFB000FFAE00FFAC00FFA900FFA700FFA500FFA000FF9900FF9200FF8B00FF8400FF7D00FF7600FF6F00FF6800FF6100FF5700FF4A
00FF3E00FF3100FF2500FF1800FF0C00FF000CFF0019FF002BFF003EFF0052FF0065FF0079FF008DFF00A0FF00B4FF00C7FF00DBFF00F7FF00FFEA00FFCD00FFB000FF9200FF7500
FF5800FF3A00FF1D00FF0000
FF0000FF1C00FF3900FF5600FF7200FF8F00FFAC00FFC800FFE500FDFF00E2FF00CFFF00BCFF00A8FF0095FF0082FF006FFF005CFF0049FF0036FF0025FF0019FF000CFF0000FF00
00FF0B00FF1700FF2300FF2F00FF3B00FF4700FF5200FF5800FF5F00FF6600FF6C00FF7300FF7A00FF8000FF8700FF8E00FF9300FF9500FF9700FF9900FF9B00FF9E00FFA000FFA2
00FFA400FFA600FFA600FFA400FFA200FFA000FF9E00FF9B00FF9900FF9700FF9500FF9300FF8E00FF8700FF8100FF7A00FF7300FF6C00FF6600FF5F00FF5800FF5200FF4700FF3B
00FF2F00FF2300FF1700FF0B00FF000CFF0019FF0025FF0036FF0049FF005CFF006FFF0082FF0095FF00A8FF00BBFF00CFFF00E2FF00FDFF00FFE500FFC800FFAC00FF8F00FF7200
FF5600FF3900FF1C00FF0000
FF0000FF1B00FF3700FF5300FF6E00FF8A00FFA600FFC100FFDD00FFF900ECFF00D9FF00C7FF00B5FF00A3FF0090FF007EFF006CFF0059FF0047FF0036FF002BFF001FFF0014FF00
08FF0000FF0300FF0E00FF1A00FF2500FF3100FF3B00FF4100FF4800FF4E00FF5400FF5B00FF6100FF6800FF6E00FF7500FF7900FF7B00FF7D00FF7F00FF8100FF8400FF8600FF88
00FF8A00FF8C00FF8C00FF8A00FF8800FF8600FF8400FF8100FF7F00FF7D00FF7B00FF7900FF7500FF6E00FF6800FF6100FF5B00FF5500FF4E00FF4800FF4100FF3B00FF3100FF25
00FF1A00FF0E00FF0308FF0014FF001FFF002BFF0036FF0047FF0059FF006CFF007EFF0090FF00A3FF00B5FF00C7FF00D9FF00ECFF00FFF900FFDD00FFC100FFA600FF8A00FF6E00
FF5300FF3700FF1B00FF0000
FF0000FF1A00FF3500FF4F00FF6A00FF8400FF9F00FFBA00FFD400FFEF00F7FF00E5FF00D4FF00C2FF00B1FF009FFF008EFF007CFF006BFF0059FF0049FF003EFF0033FF0028FF00
1DFF0012FF0007FF0000FF0300FF0E00FF1900FF2200FF2900FF2F00FF3500FF3B00FF4100FF4700FF4D00FF5300FF5900FF5E00FF6000FF6200FF6400FF6600FF6800FF6A00FF6C
00FF6D00FF6F00FF6F00FF6D00FF6C00FF6A00FF6800FF6600FF6400FF6200FF6000FF5E00FF5900FF5300FF4D00FF4700FF4100FF3B00FF3500FF2F00FF2900FF2200FF1900FF0E
00FF0307FF0012FF001DFF0028FF0033FF003EFF0049FF0059FF006BFF007CFF008EFF009FFF00B1FF00C2FF00D4FF00E5FF00F6FF00FFEF00FFD400FFBA00FF9F00FF8400FF6A00
FF4F00FF3500FF1A00FF0000
FF0000FF1900FF3200FF4C00FF6500FF7F00FF9800FFB200FFCB00FFE500FFFE00F1FF00E0FF00D0FF00BFFF00AEFF009EFF008DFF007CFF006CFF005CFF0052FF0047FF003DFF00
32FF0028FF001DFF0013FF0009FF0000FF0100FF0A00FF1000FF1600FF1B00FF2100FF2700FF2D00FF3300FF3800FF3E00FF4200FF4400FF4600FF4800FF4A00FF4C00FF4E00FF4F
00FF5100FF5300FF5300FF5100FF4F00FF4E00FF4C00FF4A00FF4800FF4600FF4400FF4200FF3E00FF3800FF3300FF2D00FF2700FF2100FF1B00FF1600FF1000FF0A00FF0108FF00
13FF001DFF0028FF0032FF003DFF0047FF0052FF005CFF006CFF007CFF008DFF009EFF00AEFF00BFFF00CFFF00E0FF00F1FF00FFFE00FFE500FFCC00FFB200FF9900FF7F00FF6600
FF4C00FF3300FF1900FF0000
FF0000FF1800FF3000FF4900FF6100FF7A00FF9200FFAA00FFC300FFDB00FFF300FDFF00EDFF00DDFF00CDFF00BDFF00ADFF009EFF008EFF007EFF006FFF0065FF005CFF0052FF00
48FF003EFF0034FF002AFF0020FF0016FF000DFF0008FF0002FF0000FF0200FF0800FF0D00FF1300FF1800FF1D00FF2300FF2700FF2900FF2A00FF2C00FF2E00FF3000FF3200FF33
00FF3500FF3700FF3700FF3500FF3300FF3200FF3000FF2E00FF2C00FF2B00FF2900FF2700FF2300FF1E00FF1800FF1300FF0D00FF0800FF0202FF0008FF000DFF0016FF0020FF00
2AFF0034FF003EFF0048FF0052FF005BFF0065FF006FFF007EFF008EFF009EFF00ADFF00BDFF00CDFF00DDFF00EDFF00FCFF00FFF300FFDB00FFC300FFAA00FF9200FF7A00FF6100
FF4900FF3000FF1800FF0000
FF0000FF1700FF2E00FF4500FF5D00FF7400FF8B00FFA300FFBA00FFD100FFE800FFF700F9FF00EAFF00DBFF00CCFF00BDFF00AEFF009FFF0090FF0082FF0079FF0070FF0066FF00
5DFF0053FF004AFF0041FF0037FF002EFF0026FF0021FF001BFF0016FF0011FF000CFF0007FF0002FF0000FF0300FF0800FF0C00FF0D00FF0F00FF1100FF1200FF1400FF1600FF17
00FF1900FF1A00FF1A00FF1900FF1700FF1600FF1400FF1200FF1100FF0F00FF0D00FF0C00FF0800FF0302FF0007FF000CFF0011FF0016FF001BFF0021FF0026FF002EFF0037FF00
41FF004AFF0053FF005DFF0066FF0070FF0079FF0082FF0090FF009FFF00AEFF00BDFF00CCFF00DBFF00EAFF00F9FF00FFF700FFE800FFD100FFBA00FFA300FF8B00FF7400FF5D00
FF4500FF2E00FF1700FF0000
FF0000FF1600FF2C00FF4200FF5800FF6F00FF8500FF9B00FFB100FFC700FFDD00FFEB00FFF900F8FF00E9FF00DBFF00CDFF00BFFF00B1FF00A3FF0095FF008DFF0084FF007BFF00
72FF0069FF0060FF0058FF004FFF0046FF003EFF0039FF0034FF0030FF002BFF0026FF0021FF001CFF0017FF0012FF000FFF000DFF000CFF000AFF0009FF0007FF0006FF0004FF00
02FF0001FF0001FF0002FF0004FF0005FF0007FF0009FF000AFF000CFF000DFF000FFF0012FF0017FF001CFF0021FF0026FF002BFF0030FF0034FF0039FF003EFF0046FF004FFF00
58FF0060FF0069FF0072FF007BFF0084FF008DFF0095FF00A3FF00B1FF00BFFF00CDFF00DBFF00E9FF00F8FF00FFF900FFEB00FFDD00FFC700FFB100FF9B00FF8500FF6F00FF5800
FF4200FF2C00FF1600FF0000
FF0000FF1500FF2A00FF3F00FF5400FF6900FF7E00FF9300FFA900FFBE00FFD200FFDF00FFED00FFFA00F8FF00EAFF00DDFF00D0FF00C2FF00B5FF00A8FF00A0FF0098FF0090FF00
87FF007FFF0077FF006EFF0066FF005EFF0057FF0052FF004EFF0049FF0044FF0040FF003BFF0037FF0032FF002EFF002AFF0029FF0027FF0026FF0024FF0023FF0022FF0020FF00
1FFF001DFF001DFF001FFF0020FF0022FF0023FF0024FF0026FF0027FF0029FF002AFF002EFF0032FF0037FF003BFF0040FF0044FF0049FF004DFF0052FF0057FF005EFF0066FF00
6EFF0077FF007FFF0087FF0090FF0098FF00A0FF00A8FF00B5FF00C2FF00CFFF00DDFF00EAFF00F8FF00FFFA00FFED00FFDF00FFD200FFBE00FFA900FF9300FF7E00FF6900FF5400
FF3F00FF2A00FF1500FF0000
FF0000FF1400FF2800FF3C00FF5000FF6400FF7800FF8C00FFA000FFB400FFC700FFD400FFE000FFED00FFF900F9FF00EDFF00E0FF00D4FF00C7FF00BBFF00B4FF00ACFF00A4FF00
9CFF0095FF008DFF0085FF007DFF0076FF006FFF006BFF0067FF0062FF005EFF005AFF0056FF0051FF004DFF0049FF0046FF0044FF0043FF0042FF0040FF003FFF003EFF003CFF00
3BFF0039FF0039FF003BFF003CFF003EFF003FFF0040FF0042FF0043FF0044FF0046FF0049FF004DFF0051FF0056FF005AFF005EFF0062FF0067FF006BFF006FFF0076FF007DFF00
85FF008DFF0095FF009CFF00A4FF00ACFF00B4FF00BBFF00C7FF00D4FF00E0FF00EDFF00F9FF00FFF900FFED00FFE000FFD400FFC700FFB400FFA000FF8C00FF7800FF6400FF5000
FF3C00FF2800FF1400FF0000
FF0000FF1200FF2500FF3800FF4B00FF5E00FF7100FF8400FF9700FFAA00FFBC00FFC800FFD400FFDF00FFEB00FFF700FCFF00F1FF00E5FF00D9FF00CFFF00C7FF00C0FF00B9FF00
B2FF00AAFF00A3FF009CFF0095FF008EFF0087FF0084FF0080FF007CFF0078FF0074FF0070FF006CFF0068FF0064FF0061FF0060FF005FFF005DFF005CFF005BFF005AFF0058FF00
57FF0056FF0056FF0057FF0058FF005AFF005BFF005CFF005DFF005FFF0060FF0061FF0064FF0068FF006CFF0070FF0074FF0078FF007CFF0080FF0083FF0087FF008EFF0095FF00
9CFF00A3FF00AAFF00B2FF00B9FF00C0FF00C7FF00CFFF00D9FF00E5FF00F1FF00FCFF00FFF700FFEB00FFDF00FFD400FFC800FFBC00FFAA00FF9700FF8400FF7100FF5E00FF4B00
FF3800FF2500FF1200FF0000
FF0000FF1100FF2300FF3500FF4700FF5900FF6B00FF7C00FF8E00FFA000FFB100FFBC00FFC700FFD200FFDD00FFE800FFF300FFFE00F7FF00ECFF00E2FF00DBFF00D4FF00CEFF00
C7FF00C0FF00BAFF00B3FF00ACFF00A6FF00A0FF009CFF0099FF0095FF0091FF008EFF008AFF0086FF0083FF007FFF007DFF007BFF007AFF0079FF0078FF0077FF0076FF0074FF00
73FF0072FF0072FF0073FF0074FF0076FF0077FF0078FF0079FF007AFF007BFF007CFF007FFF0083FF0086FF008AFF008EFF0091FF0095FF0099FF009CFF00A0FF00A6FF00ACFF00
B3FF00BAFF00C0FF00C7FF00CEFF00D4FF00DBFF00E2FF00ECFF00F6FF00FFFE00FFF300FFE800FFDD00FFD200FFC700FFBC00FFB100FFA000FF8E00FF7C00FF6B00FF5900FF4700
FF3500FF2300FF1100FF0000
FF0000FF1000FF2000FF3000FF4000FF5000FF6000FF7000FF8100FF9100FFA000FFAA00FFB400FFBE00FFC700FFD100FFDB00FFE500FFEF00FFF900FDFF00F7FF00F1FF00EBFF00
E5FF00DFFF00D9FF00D3FF00CDFF00C7FF00C2FF00BFFF00BBFF00B8FF00B5FF00B2FF00AEFF00ABFF00A8FF00A5FF00A2FF00A1FF00A0FF009FFF009EFF009DFF009CFF009BFF00
9AFF0099FF0099FF009AFF009BFF009CFF009DFF009EFF009FFF00A0FF00A1FF00A2FF00A5FF00A8FF00ABFF00AEFF00B2FF00B5FF00B8FF00BBFF00BFFF00C2FF00C7FF00CDFF00
D3FF00D9FF00DFFF00E5FF00EBFF00F1FF00F7FF00FDFF00FFF900FFEF00FFE500FFDB00FFD100FFC700FFBE00FFB400FFAA00FFA000FF9100FF8100FF7000FF6000FF5000FF4000
FF3000FF2000FF1000FF0000
FF0000FF0E00FF1C00FF2B00FF3900FF4700FF5600FF6400FF7200FF8100FF8E00FF9700FFA000FFA900FFB100FFBA00FFC300FFCB00FFD400FFDD00FFE500FFEA00FFF000FFF500
FFFA00FFFF00FAFF00F5FF00EFFF00EAFF00E5FF00E2FF00DFFF00DDFF00DAFF00D7FF00D4FF00D1FF00CEFF00CBFF00C9FF00C8FF00C7FF00C6FF00C5FF00C4FF00C3FF00C2FF00
C2FF00C1FF00C1FF00C2FF00C2FF00C3FF00C4FF00C5FF00C6FF00C7FF00C8FF00C9FF00CBFF00CEFF00D1FF00D4FF00D7FF00DAFF00DDFF00DFFF00E2FF00E5FF00EAFF00EFFF00
F5FF00FAFF00FFFF00FFFA00FFF500FFF000FFEA00FFE500FFDD00FFD400FFCC00FFC300FFBA00FFB100FFA900FFA000FF9700FF8E00FF8100FF7200FF6400FF5600FF4700FF3900
FF2B00FF1C00FF0E00FF0000
FF0000FF0C00FF1900FF2500FF3200FF3E00FF4B00FF5700FF6400FF7000FF7C00FF8400FF8C00FF9300FF9B00FFA300FFAA00FFB200FFBA00FFC100FFC800FFCD00FFD200FFD600
FFDB00FFE000FFE400FFE900FFEE00FFF200FFF600FFF900FFFC00FFFE00FEFF00FCFF00F9FF00F7FF00F4FF00F2FF00F0FF00EFFF00EEFF00EDFF00EDFF00ECFF00EBFF00EAFF00
E9FF00E9FF00E8FF00E9FF00EAFF00EBFF00ECFF00EDFF00EDFF00EEFF00EFFF00F0FF00F2FF00F4FF00F7FF00F9FF00FCFF00FEFF00FFFE00FFFC00FFF900FFF600FFF200FFEE00
FFE900FFE400FFE000FFDB00FFD600FFD200FFCD00FFC800FFC100FFBA00FFB200FFAA00FFA300FF9B00FF9300FF8C00FF8400FF7C00FF7000FF6400FF5700FF4B00FF3E00FF3200
FF2500FF1900FF0C00FF0000
FF0000FF0A00FF1500FF2000FF2B00FF3500FF4000FF4B00FF5600FF6000FF6B00FF7100FF7800FF7E00FF8500FF8B00FF9200FF9800FF9F00FFA600FFAC00FFB000FFB400FFB800
FFBC00FFC000FFC400FFC800FFCC00FFD000FFD300FFD500FFD800FFDA00FFDC00FFDE00FFE000FFE200FFE500FFE700FFE800FFE900FFEA00FFEA00FFEB00FFEC00FFED00FFED00
FFEE00FFEF00FFEF00FFEE00FFED00FFED00FFEC00FFEB00FFEA00FFEA00FFE900FFE800FFE700FFE500FFE200FFE000FFDE00FFDC00FFDA00FFD800FFD500FFD300FFD000FFCC00
FFC800FFC400FFC000FFBC00FFB800FFB400FFB000FFAC00FFA600FF9F00FF9900FF9200FF8B00FF8500FF7E00FF7800FF7100FF6B00FF6000FF5600FF4B00FF4000FF3500FF2B00
FF2000FF1500FF0A00FF0000
FF0000FF0800FF1100FF1A00FF2300FF2C00FF3500FF3E00FF4700FF5000FF5900FF5E00FF6400FF6900FF6F00FF7400FF7A00FF7F00FF8400FF8A00FF8F00FF9200FF9600FF9900
FF9C00FFA000FFA300FFA600FFAA00FFAD00FFB000FFB200FFB400FFB500FFB700FFB900FFBB00FFBD00FFBE00FFC000FFC200FFC200FFC300FFC300FFC400FFC400FFC500FFC600
FFC600FFC700FFC700FFC600FFC600FFC500FFC400FFC400FFC300FFC300FFC200FFC200FFC000FFBE00FFBD00FFBB00FFB900FFB700FFB500FFB400FFB200FFB000FFAD00FFAA00
FFA600FFA300FFA000FF9C00FF9900FF9600FF9200FF8F00FF8A00FF8400FF7F00FF7A00FF7400FF6F00FF6900FF6400FF5E00FF5900FF5000FF4700FF3E00FF3500FF2C00FF2300
FF1A00FF1100FF0800FF0000
FF0000FF0700FF0E00FF1500FF1C00FF2300FF2B00FF3200FF3900FF4000FF4700FF4B00FF5000FF5400FF5800FF5D00FF6100FF6500FF6A00FF6E00FF7200FF7500FF7800FF7A00
FF7D00FF8000FF8200FF8500FF8800FF8A00FF8D00FF8E00FF9000FF9100FF9200FF9400FF9500FF9700FF9800FF9A00FF9B00FF9B00FF9C00FF9C00FF9D00FF9D00FF9E00FF9E00
FF9E00FF9F00FF9F00FF9E00FF9E00FF9E00FF9D00FF9D00FF9C00FF9C00FF9B00FF9B00FF9A00FF9800FF9700FF9500FF9400FF9200FF9100FF9000FF8E00FF8D00FF8A00FF8800
FF8500FF8200FF8000FF7D00FF7A00FF7800FF7500FF7200FF6E00FF6A00FF6600FF6100FF5D00FF5800FF5400FF5000FF4B00FF4700FF4000FF3900FF3200FF2B00FF2300FF1C00
FF1500FF0E00FF0700FF0000
FF0000FF0500FF0A00FF1000FF1500FF1A00FF2000FF2500FF2B00FF3000FF3500FF3800FF3C00FF3F00FF4200FF4500FF4900FF4C00FF4F00FF5300FF5600FF5800FF5A00FF5C00
FF5E00FF6000FF6200FF6400FF6600FF6800FF6900FF6A00FF6C00FF6D00FF6E00FF6F00FF7000FF7100FF7200FF7300FF7400FF7400FF7500FF7500FF7500FF7600FF7600FF7600
FF7700FF7700FF7700FF7700FF7600FF7600FF7600FF7500FF7500FF7500FF7400FF7400FF7300FF7200FF7100FF7000FF6F00FF6E00FF6D00FF6C00FF6A00FF6900FF6800FF6600
FF6400FF6200FF6000FF5E00FF5C00FF5A00FF5800FF5600FF5300FF4F00FF4C00FF4900FF4500FF4200FF3F00FF3C00FF3800FF3500FF3000FF2B00FF2500FF2000FF1A00FF1500
FF1000FF0A00FF0500FF0000
FF0000FF0300FF0700FF0A00FF0E00FF1100FF1500FF1900FF1C00FF2000FF2300FF2500FF2800FF2A00FF2C00FF2E00FF3000FF3200FF3500FF3700FF3900FF3A00FF3C00FF3D00
FF3E00FF4000FF4100FF4200FF4400FF4500FF4600FF4700FF4800FF4800FF4900FF4A00FF4A00FF4B00FF4C00FF4D00FF4D00FF4D00FF4E00FF4E00FF4E00FF4E00FF4F00FF4F00
FF4F00FF4F00FF4F00FF4F00FF4F00FF4F00FF4E00FF4E00FF4E00FF4E00FF4D00FF4D00FF4D00FF4C00FF4B00FF4A00FF4A00FF4900FF4800FF4800FF4700FF4600FF4500FF4400
FF4200FF4100FF4000FF3E00FF3D00FF3C00FF3A00FF3900FF3700FF3500FF3300FF3000FF2E00FF2C00FF2A00FF2800FF2500FF2300FF2000FF1C00FF1900FF1500FF1100FF0E00
FF0A00FF0700FF0300FF0000
FF0000FF0100FF0300FF0500FF0700FF0800FF0A00FF0C00FF0E00FF1000FF1100FF1200FF1400FF1500FF1600FF1700FF1800FF1900FF1A00FF1B00FF1C00FF1D00FF1E00FF1E00
FF1F00FF2000FF2000FF2100FF2200FF2200FF2300FF2300FF2400FF2400FF2400FF2500FF2500FF2500FF2600FF2600FF2600FF2600FF2700FF2700FF2700FF2700FF2700FF2700
FF2700FF2700FF2700FF2700FF2700FF2700FF2700FF2700FF2700FF2700FF2600FF2600FF2600FF2600FF2500FF2500FF2500FF2400FF2400FF2400FF2300FF2300FF2200FF2200
FF2100FF2000FF2000FF1F00FF1E00FF1E00FF1D00FF1C00FF1B00FF1A00FF1900FF1800FF1700FF1600FF1500FF1400FF1200FF1100FF1000FF0E00FF0C00FF0A00FF0800FF0700
FF0500FF0300FF0100FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000FF0000
FF0000FF0000FF0000FF0000
pop
P
% End of image
% End of Graphics
MathPictureEnd
:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]

The following data are printed out in the process of the work of the
program:

1.  The current values of n, the iteration number, and the residual 
      norm.

2.  The numerical values of the exact solution in the grid nodes.

3.  The mean-square error of the numerical solution.

4.  The numerical solution surface u = u(x,y).

5.  The contour plot of the computed FEM solution.

6.  The exact solution surface u = u(x,y).

7. The color map of the numerical solution u = u(x,y); the  blue color
     corresponds to the lowest value(s) of the numerical solution.
^*)