(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = graphics, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = special1, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = special2, "System", 10, L0, center, nowordwrap, nohscroll, bold;
	fontset = special3, "System", 10, L0, right, nowordwrap, nohscroll, bold;
	fontset = special4, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = special5, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = leftheader, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = leftfooter, "System", 10, L0, nowordwrap, nohscroll, bold;
	fontset = reserved1, "System", 10, L0, nowordwrap, nohscroll, bold;]
:[font = title; inactive; nohscroll; center; ]
Numerical Grid Generation
:[font = name; inactive; nohscroll; ]

                                    Victor G.Ganzha and Evgenii V.Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled

                                 V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program gridttm.ma which follows below generates a curvilinear 
grid in the given axisymmetric Laval nozzle with the aid of the elliptic
grid generator. The corresponding PDEs (due to Thompson, Thames,
and Mastin) are solved numerically with the aid of the ADI method.

:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]
Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

           ClearAll[fw, grid2];
:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

 Specify the input data by entering them in the line (see also Section
"Examples of Input Data")
:[font = input; nowordwrap; ]

grid2[0.5, 3.125, 1.0, 0.625, 2.805, 4.005,
      Pi/4, Pi/12, 21, 7, 40.0, 0.0003]
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line, press Shift + Enter and wait for the result of numerical
computation.The meaning of the input parameters is explained in Section
"Parameters Used in Program gridttm.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; bold; fontName = "System"; fontSize = 10; ]

ClearAll[fw, grid2];
fw[x_] := ( f1 = If[0 <= x && x <= x1,
         y0 - R0 + Sqrt[(R0 - x)*(R0 + x)], 0];
f2 = If[x1 <= x && x <= x2, y1 - ct1*(x - x1), f1];
f3 = If[x2 <= x && x <= x3,
    hc1 + R - Sqrt[(R - x + x0)*(R + x - x0)], f2];
f4 = If[x3 <= x && x <= x4, y3 + ct2*(x - x3), f3]; f4 )

grid2[hc_, cy0_, cR0_, cR_, cx0_, cx4_, thet1_,
      thet2_, ix_, jy_, Saf_, eps_] :=
(
(* -- Specification of the nozzle geometry -- *)
R0 = cR0*hc; y0 = cy0*hc; x0 = cx0*hc; R = cR*hc;
     hc1 = hc;
x1 = R0*N[Sin[thet1]]; ct1 = N[Tan[thet1]];
                 ct2 = N[Tan[thet2]];
x2 = x0-R*N[Sin[thet1]]; x3 = x0+R*N[Sin[thet2]];
x4 = cx4*hc; y1 = y0 - R0*(1 - N[Cos[thet1]]);
	    y3 = hc + R*(1 - N[Cos[thet2]]);
Print["The values of the nozzle geometry",
      " parameters"];
Print["hc = ",hc, ", R0 = ", R0, ", R = ", R,
        ", x0 = ",x0];
Print["thet1 = ", thet1, ", thet2 = ", thet2,
        ", nozzle length = ", x4];

(* -- yw is the list for the ordinates of the 
   nozzle wall ----------------------------- *)
    yw = {};  xorg = 0.0;
  Do[ xi = (i - 1)*x4/(ix - 1); yi = fw[xi];
      AppendTo[yw, yi], {i, ix}];
(* -- x, y are the lists for the abscissas x[[i]]
      and the ordinates y[[i, j]] of the nodes of
      the curvilinear spatial grid ----------- *)
   x = Table[N[(i - 1)*x4/(ix - 1)], {i, ix}];
y = Table[N[yw[[i]]*(j-1)/(jy-1)], {i,ix}, {j,jy}];
(* - The graphical output of the initial grid - *)
Print["The initial grid"];
(* -------- The lines eta = const ------------ *)
   mt = {}; xtab = {};
 Do[xi = (i - 1)*x4/(ix - 1); 
        AppendTo[xtab, xi], {i, ix}];
 Do[ytab = {};
  Do[yi = y[[i,j]]; AppendTo[ytab, yi], {i, ix}];
   xytab = Table[{xtab[[i]], ytab[[i]]}, {i, ix}];
   mt1 = ListPlot[xytab,
	     AxesLabel  -> {"x", "y"},
             AxesOrigin -> {xorg, 0},
	     PlotJoined -> True,
	     PlotRange  -> {{0, x4}, {0, y0}},
             DisplayFunction -> Identity];
             AppendTo[mt, mt1],
                                 {j, jy}];
(* -- mt3 = Show[mt, 
      DisplayFunction -> $DisplayFunction]; -- *)
(* --------- The lines xi = const ------------ *)
   Do[ xtab = {}; ytab = {};
    xi = (i - 1)*x4/(ix - 1); AppendTo[xtab, xi];
   AppendTo[ytab, 0.0];
 yi = yw[[i]]; AppendTo[xtab, xi]; 
               AppendTo[ytab, yi];
 xytab = Table[{xtab[[j]], ytab[[j]]}, {j, 2}];
      mt1 = ListPlot[xytab,
                     PlotJoined -> True,
                     DisplayFunction -> Identity];
        AppendTo[mt, mt1],
                           {i, ix}];
mt3=Show[mt,DisplayFunction -> $DisplayFunction];
         Display["fig4_6a", mt3];

 (*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %%                                           %%
 %%           Elliptic Grid Generator         %%
 %%                                           %%
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*)

(* - Specification of the initial guess xx, yy - *)
yy = y; xx = y; dt = Saf*x4/(ix - 1); dt2 = 0.5*dt;
ix1 = ix - 1;  jy1 = jy - 1; ifix = Floor[ix/2];
Do[ xi = x[[i]];
	 Do[ xx[[i, j]] = xi, {j, jy}], {i, ix}];
(* - The ADI solver in the form of a function - *)
ADI[nxy_] :=
( xg = x; yg = x; xn1 = xx; xn2 = xn1;
(* - The first half-step
     passage from t = n*dt to t = (n+0.5)*dt) - *)
xg[[1]] = 0.0;
   Do[ yg[[1]] = 0.0;
     If[nxy != 1, yg[[1]] = yw[[1]]*(j-1)/(jy-1)];
     xn1[[1, j]] = yg[[1]]; xn2[[1, j]] = yg[[1]];
Print["nxy = ", nxy,
   ", yy[[",ifix,", ", j, "]] = ", yy[[ifix,j]] ];
(* ---- The scalar sweeps along the lines 
     eta = const ----------------------------- *)
       Do[ xet = (xx[[i, j+1]] - xx[[i, j-1]])/2;
           yet = (yy[[i, j+1]] - yy[[i, j-1]])/2;
   xks = (xx[[i+1,j]] - xx[[i-1,j]])/2;
   yks = (yy[[i+1,j]] - yy[[i-1,j]])/2;
If[nxy == 1,
fkset = xx[[i+1, j+1]] - xx[[i+1, j-1]] -
	xx[[i-1, j+1]] + xx[[i-1, j-1]],
        fkset = yy[[i+1, j+1]] - yy[[i+1, j-1]] -
        yy[[i-1, j+1]] + yy[[i-1, j-1]] ];
a1 = xet*xet + yet*yet;  b1 = xks*xks + yks*yks;
If[nxy == 1,
 fet = xx[[i, j+1]] - 2*xx[[i,j]] + xx[[i, j-1]],
 fet = yy[[i, j+1]] - 2*yy[[i,j]] + yy[[i, j-1]] ];
g1 = b1*fet - (1/2)*(xks*xet + yks*yet)*fkset;
a2 = dt2*a1;   b2 = -1 - dt*a1;
If[nxy == 1, fcij=xx[[i, j]], fcij = yy[[i, j]] ];
f2 = -fcij - dt2*g1;  den = b2 + a2*xg[[i - 1]];
xg[[i]]=-a2/den; yg[[i]]=(f2-a2*yg[[i - 1]])/den,
				    {i, 2, ix1}];
If[nxy == 1, xn1[[ix, j]] = x4,
   xn1[[ix, j]] = yw[[ix]]*(j - 1)/jy1];
   xn2[[ix,j]] = xn1[[ix, j]];
  Do[ i1 = ix - i + 1;
xn1[[i1, j]] = xg[[i1]]*xn1[[i1+1, j]] + yg[[i1]],
			 {i, 2, ix1}],
       	   {j, 2, jy1}];
(* - The second half-step(passage from 
     t = (n + 0.5)*dt to t = (n + 1)*dt) ----- *)
If[nxy == 1, xn2[[1, jy]] = 0; xn2[[ix, jy]] = x4;
             xn2[[ix, 1]] = x4,
       xn2[[1, jy]] = yw[[1]]; xn2[[ix, 1]] = 0;
       xn2[[ix, jy]] = yw[[ix]] ];

Do[ xg[[1]] = 0;
    If[nxy == 1, yg[[1]] = x[[i]], yg[[1]] = 0];
       xn2[[i,1]] = yg[[1]];
(* The scalar sweeps along the lines xi = const *)
       Do[ xet = (xx[[i, j+1]] - xx[[i, j-1]])/2;
           yet = (yy[[i, j+1]] - yy[[i, j-1]])/2;
   xks = (xx[[i+1,j]] - xx[[i-1,j]])/2;
   yks = (yy[[i+1,j]] - yy[[i-1,j]])/2;
fkset = xn1[[i+1, j+1]] - xn1[[i+1, j-1]] -
	xn1[[i-1, j+1]] + xn1[[i-1, j-1]];
a1 = xet*xet + yet*yet;  b1 = xks*xks + yks*yks;
g1=a1*(xn1[[i+1,j]] - 2*xn1[[i,j]] + xn1[[i-1,j]]);
g1 = g1 - (1/2)*(xks*xet + yks*yet)*fkset;
a2 = dt2*b1;   b2 = -1 - dt*b1;
f2 = -xn1[[i,j]] -dt2*g1; den = b2 + a2*xg[[j-1]];
xg[[j]] =-a2/den; yg[[j]]=(f2 - a2*yg[[j-1]])/den,
				  {j, 2, jy1}];
xn2[[i, jy]] = x[[i]];
If[nxy != 1, xn2[[i, jy]] = yw[[i]] ];
  Do[ j1 = jy - j + 1;
xn2[[i, j1]] = xg[[j1]]*xn2[[i, j1+1]] + yg[[j1]],
			      {j, 2, jy1}],
		{i, 2, ix1}];
  Return[xn2] );
(* - The check-up of the convergence criterion - *)
nit = 0;
Print["The start of the ADI iterations, eps = " ,
       eps];
Label[iter];
nit = nit + 1;
xn2 = ADI[1];
dxmax = 0.0;  dymax = 0.0;
  Do[
      Do[ dxij = Abs[xn2[[i, j]] - xx[[i, j]] ];
dxmax=Max[dxmax, dxij], {i, 2, ix1}], {j, 2, jy1}];
(* ---- Exchange of the lists ---- *)
xx = xn2;  xn2 = ADI[2];
Do[
    Do[ dyij = Abs[xn2[[i,j]] - yy[[i, j]] ];
dymax=Max[dymax, dyij], {i, 2, ix1}], {j, 2, jy1}];
(* ---- Exchange of the lists ---- *)
yy = xn2;
Print["n = ", nit,",dxmax = ",dxmax,",dymax = ",
       dymax];
If[dxmax > eps || dymax > eps, Goto[iter] ];
(* --- End of the elliptic grid generator --- *)

(* ---- The graphical output of the grid ---- *)
(* --------- The lines eta = const ---------- *)
   mt = {}; xtab = {};
(* Do[xi = (i - 1)*x4/(ix - 1);
          AppendTo[xtab,xi], {i, ix}]; *)
   Do[xtab = {}; ytab = {};
      Do[ xi = xx[[i,j]]; AppendTo[xtab, xi];
   yi = yy[[i,j]]; AppendTo[ytab, yi], {i, ix}];
   xytab = Table[{xtab[[i]], ytab[[i]]}, {i, ix}];
   mt1 = ListPlot[xytab,
	     AxesLabel  -> {"x", "y"},
             AxesOrigin -> {xorg, 0},
	     PlotJoined -> True,
	     PlotRange  -> {{0, x4}, {0, y0}},
             DisplayFunction -> Identity];
             AppendTo[mt, mt1],
                                 {j, jy}];
mt3 = Show[mt,DisplayFunction -> $DisplayFunction];
(* -------- The lines xi = const ------------- *)
   Do[xtab = {}; ytab = {};
      Do[ xj = xx[[i,j]]; AppendTo[xtab, xj];
     yj = yy[[i,j]]; AppendTo[ytab, yj], {j, jy}];
   xytab = Table[{xtab[[j]], ytab[[j]]}, {j, jy}];
        mt1 = ListPlot[xytab,
                     PlotJoined -> True,
                     DisplayFunction -> Identity];
        AppendTo[mt, mt1],
                           {i, ix}];
mt3 = Show[mt,DisplayFunction -> $DisplayFunction];
         Display["fig4_62", mt3];
(* ------- End of the procedure grid2 --------- *)
)

:[font = section; inactive; ]
Parameters Used in Program gridttm.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]
____________________________________________________
 Parameter                        Description
____________________________________________________
hc                    the nozzle wall height in the critical section of 
                        the nozzle, hc > 0;
cy0                  the ordinate of the nozzle wall in the inlet section
                        x = 0 related to hc;
cR0                 the radius of the curvature of the nozzle wall in
                        its subsonic part related to hc;
cR                   the nozzle wall radius of the curvature in the
                        critical section related to hc;
cx0                  the abscissa of the critical nozzle section
                        related to hc;
cx4                  the nozzle length related to hc, cx4 > cx0;
thet1                the inclination angle of the nozzle wall in the
                        subsonic part of the nozzle; the angle is speci-
                        fied in radians;
thet2                the inclination angle of the nozzle wall in the
                        supersonic part of the nozzle; the angle is spe-
                        cified in radians;
ix                      the number of grid points on the xi-axis, ix > 1;
jy                      the number of grid points on the eta-axis, jy > 1;
Saf                  the safety factor in the formula for the comput-
                        ation of the pseudo time step dt; Saf > 0;
eps                 a small positive number entering the criterion
                        for the termination of the iterations by the
                       ADI method.
_____________________________________________________

:[font = section; inactive; ]
Examples of Input Data
:[font = subsection; inactive; ]
Example 1 (eps = 0.001)
:[font = input; nowordwrap; ]

grid2[0.5, 3.125, 1.0, 0.625, 2.805, 4.005,
      Pi/4, Pi/12, 21, 7, 40.0, 0.001]

:[font = subsection; inactive; ]
Example 2 (eps = 0.0003)
:[font = input; nowordwrap; ]

grid2[0.5, 3.125, 1.0, 0.625, 2.805, 4.005,
      Pi/4, Pi/12, 21, 7, 40.0, 0.0003]

:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]
The following data are printed out in the process of the work of the
program:

1. The initial grid obtained by the interpolation method of Section 2.14.

2. The number n of the ADI iteratins, max_{i,j}|x_{i,j}^n+1} - x_{i,j}^n|,
max_{i,j}|y_{i,j}^n+1} - y_{i,j}^n|.

3. The values of the ordinates y_{i,j}  in a section x = const. The grid 
     equations are solved for x-coordinates of the curvilinear grid nodes
     at nxy = 1, and for y-coordinates at nxy = 2.

4. The final curvilinear grid obtained after the satisfaction of the ADI
     iteration convergence criterion.

^*)