(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
The 1D Lax-Wendroff Scheme
:[font = subtitle; inactive; nohscroll; center; ]
(Square Wave Test)
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled
                                     V.G.Ganzha and E.V.Vorozhtsov
   Numerical Solutions For Partial Differential Equations: Problem Solving
   Using Mathematica.   CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]

Numerical Solutions For Partial Differential Equations: Problem Solving
Using Mathematica.   CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]
The program lw1.ma which follows below implements the computation by 
the Lax-Wendroff difference scheme  under the initial condition of the form 
(2.2.6) (the square wave test). A more detailed description of the scheme
can be found in Section 2.4 of the above book.

:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]

Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

Clear[advbc,uinit];
:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input data by entering them in the line
:[font = input; nowordwrap; ]

advbc[1.0, 0.0, 2.0, 20, 0.5, 1.0, 300, 0.8, 4]
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line, press Shift+Enter and wait for the result of
numerical computation. The meaning of the input parameters is
explained in Section "Parameters Used in Program lw1.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; ]
Clear[advbc, uinit];
uinit[x_,ul_,ur_,jf0_,h_]:=
( xc0 = jf0*h; y1 = (x - xc0)/(15*h);
z=If[Abs[x-xc0]<=15*h,ul+ur*Sqrt[1-y1*y1],ul]; z );

advbc[a_,a1_,b1_,jf0_,ul_,ur_,M_, cap_, Npic_]:=
(
 (* -- uj = the difference solution at time level n,
      up = the difference solution at time level n + 1 -- *)
     M1 = M + 1; h = (b1 - a1)/M1;  M2 = M - 1;
       dt = cap*h/a;   xf0 = a1 + jf0*h;
	  Tmax = (b1 - 5.0*h - xf0)/a;
uj = Table[ul, {j,0,M}];  up = uj;  
ug = Table[ur, {j, 1, M1}];
          tnt = Table[Tmax, {j, Npic}];
(* - Tmax is the right end of the time interval - *)
         Nt = Max[Floor[Tmax/dt],1];
      nplot = Max[Floor[Nt/Npic], 1]; 
(* - The solution graphs u(x, tk) will be given at 
     tk = (k-1)*nplot*dt, k = 1,...,Npic  ------- *)
      um = ul + ur;
      Print["um = ",um, ", Nmax = ", Nt];
 t= 0.0;  n2 = nplot;  nt = 1;  tnt[[1]] = 0.0;
(* -- Computation of the initial values u(xj,0) at
      grid points -- *)
         Do[ xj = a1 + (j + 0.5)*h;
   uj[[j]] = uinit[xj, ul, ur, jf0, h], {j, 0, M}];
(* - Generation of the two-dimensional table ut - *)
      ut = Table[ur, {k, 1, Npic}, {j, 1, M1}];
(* - Storing the initial profile u(x,0) in 
     ut[[j, 1]] ----------------------------- *)
       Do[ ut[[1,j + 1]] = uj[[j]], {j, 0, M}];
(* -- Begin of the Do-loop for time steps ----- *)
        Do[ t = t + dt;
            Print["n = ", n, ", t = ", t];
(* -- Do-loop over grid nodes on the x-axis --- *)
fxr=0.5*((uj[[0]]+uj[[1]])-cap*(uj[[1]]-uj[[0]]));
            Do[ fxl = fxr;
(* - The Lax-Wendroff scheme (2.4.3) for equation 
 ------------------- (2.1.1) ------------------ *)
fxr=0.5*((uj[[j]]+uj[[j+1]])-cap*(uj[[j+1]]-uj[[j]]));
        up[[j]] = uj[[j]] - cap*(fxr - fxl),
          {j, 1, M2 }];
(* -- The boundary condition on the left 
      boundary x = a1 ------------------------- *)
                    up[[0]] = ul;
(* -- The boundary condition on the right 
      boundary x= b1 -------------------------- *)
up[[M]]=((uj[[M]]+uj[[M-1]]-up[[M-1]]) +
cap*(uj[[M-1]] +up[[M - 1]] - uj[[M]]))/(1 + cap);
(* ------- Exchange of the lists -------------- *)
                   uj = up;

(* ------- Find Max[Abs[u(j,n+1) - um] -------- *)
                 umax = 0.0;
Do[ y=Abs[uj[[j]]-um]; umax=If[y>umax, y, umax],
        {j, 0, M, 1}];
     If[n == n2, Goto[store]];
     If[umax > 2.*um, Goto [endsteps], Goto [endn]];
Label[endsteps]; Tmax = t;
Label[store]; n2 = n2 + nplot;
      nt = nt + 1;
                   If[nt <= Npic,
      tnt[[nt]] = t;
(* - Storing the solution u(x,t) in ut[[nt,j]] - *)
     Do[ ut[[nt, j + 1]] = uj[[j]], {j, 0, M}]];
      If[umax > 2.0*um||nt == Npic, Break[]];
 Label[endn],
(* --------- End of the Do-loop in n ----------- *)
              {n, 0, Nt, 1}];
(* -- Plotting the solution graphs for several 
      moments of time -------------------------- *)
(* -- Determining min(ut) and max(ut) ---------- *)
        umin = 10^6;  umax = -umin;
       nt = If[nt > Npic, Npic, nt];
      Do[ y = ut[[k, j]];
            umin = If[y < umin, y, umin];
              umax = If[y > umax, y, umax],
         {k, nt}, {j, M1}];
 Print["umin = ", umin, ", umax = ", umax];
(* -- Storing the pictures in the elements 
      mt[[j]], j = 1,...,Npic ------------------ *)
     umin = If[umin > 0, 0.0, umin];
     umax = If[umax < 0, 0.0, umax]; mt = {};
     Do[ ug = ut[[j]];
         t  = tnt[[j]];
     Print["The solution graph at t = ", t];
     mt1 = ListPlot[ug,
                 PlotStyle -> {RGBColor[0,0,1]},
                 AxesLabel -> {"x", "u"},
                 PlotJoined -> True,
                 AxesOrigin -> {0, 0},
                 PlotRange -> {{0, M1}, {0, umax}},
                 DisplayFunction -> Identity];
(* - Plotting the curves of the exact solution - *)
              uex = { };
     Do[xj = a1 + (j2 - 0.5)*h;
zj = xj - a*t; uj2 = uinit[zj, ul, ur, jf0, h];
                    AppendTo[uex, uj2],
        {j2, M1}];
    mt2 = ListPlot[uex,
             AxesOrigin -> {0, 0},
             PlotRange -> {{0, M1}, {0, umax}},
             PlotJoined -> True,
             PlotStyle -> {Dashing[{0.04}]},
             DisplayFunction -> Identity];
mt3=Show[mt1,mt2,DisplayFunction->$DisplayFunction];
     AppendTo[mt, mt3],
                       {j, nt}];
If[nt == 2,
 gr = Show[GraphicsArray[{mt[[1]], mt[[2]]}]]  ];
If[nt == 3,
 gr = Show[GraphicsArray[{{mt[[1]], mt[[2]]}, 
                          {mt[[3]]}}]]  ];
If[nt == 4,
gr = Show[GraphicsArray[{{mt[[1]], mt[[2]]}, 
                         {mt[[3]], mt[[4]]}}]] ];
If[nt == 5,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]]},
     {mt[[4]], mt[[5]]}}]] ];
If[nt == 6,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]]},
     {mt[[4]], mt[[5]], mt[[6]]}}]] ];
If[nt == 7,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]], mt[[4]]},
     {mt[[5]], mt[[6]], mt[[7]]}}]] ];
If[nt >= 8,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]], mt[[4]]},
     {mt[[5]], mt[[6]], mt[[7]], mt[[8]]}}]] ];
      Display["fig2_10", gr];
(* ----------- End of the program  ------------- *)
          );

:[font = section; inactive; ]
Parameters Used in Program lw1.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]
____________________________________________________
 Parameter                             Description
____________________________________________________
a                    the advection speed in eqn (2.1.1), a > 0.
a1                  the abscissa of the left end of the interval on the x-axis;
b1                  the abscissa of the right end of the above interval, 
                      a1 < b1;
jf0                  the number of the grid node, 0 < jf0 < M, such that 
                      at x = jf0*h there  takes place the maximum of the initial 
                      semi-ellipse pulse;
ul  and ur      are the constants entering the initial condition, the value 
                      ul corresponds to the constant background, and ul + ur 
                      is the extremal value of the initial function u(x, 0);
M                  the number of the cell whose right boundary coincides 
                     with the right  boundary x = b1 of the spatial integration 
                     interval;
cap              the Courant number, cap = a*dt/h, where dt is the time 
                    step of the difference scheme, and h is the step of the 
                    uniform grid in the interval a1 <=x <= b1;
Npic            the number of the pictures of the difference solution 
                    graphs for Npic moments of time, Npic > 1.
___________________________________________________

:[font = section; inactive; ]
Examples of Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]

advbc[1.0, 0.0, 2.0, 20, 0.5, 1.0, 300, 0.8, 4]

:[font = subsection; inactive; ]
Example 2
:[font = input; nowordwrap; ]

advbc[1.0, 0.0, 2.0, 20, 0.5, 1.0, 80, 0.8, 4]

:[font = section; inactive; ]
The structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]

The following data are printed out in the process of the work of the
program:

1. um = ul + ur;

2. The maximum number of time steps to be computed (the actual
     number of the executed time steps can be smaller);

3. The current values of n, the time step number, and the time t;
                                                           n      n
4. The numerical solution graphs u   = u  (x) for Npic fixed moments
    of time; the values of these times are printed out in the message
    like
                      The solution graph at t = 0.

    To resize an individual picture obtained by Mathematica, please

(i) Click anywhere inside the cell, but not the cell bracket itself. A bo-
     unding  box with small handles appears around the graphic image.

(ii) Drag one of the handles to adjust the size and shape of the bound-
     ing box. In this way it is possible to resize the height and width of
     the graphic image.


^*)