(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
The 2D Square Wave Test
:[font = name; inactive; nohscroll; ]

                                  Victor G.Ganzha and Evgenii V. Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

  This Mathematica-Notebook is part of the book entitled

                                     V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program mc2d.ma which follows below computes the plane parallel
convection of the substance property u(x,y,t)  in the (x, y) plane by the
MacCormack scheme   of 1969.  The initial condition has a square
wave form.

:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]

Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]
          ClearAll[uex, mc2d];

:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; plain; fontName = "Arial"; fontSize = 12; ]

Specify the input data by entering them in the line

:[font = input; nowordwrap; ]
mc2d[1.0, Pi/6, 0.2, 2.0, 0.5, 40, 10, 0.8, 2,
             1.3, -2.4, 2.0]
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line press Shift + Enter and wait for the result of numerical
computation.The meaning of the input parameters is explained in Section
"Parameters Used in Program mc2d.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; bold; fontName = "Courier New"; fontSize = 12; ]
 
ClearAll[uex, mc2d];
uex[x_, y_, t_] :=
(* -- The function to compute the exact solution
      of the problem on a plane parallel convection
      of the substance property u(x, y, t) ----- *)
( xfn = xf1 - (y - yf1)*ckf + U1*t/cphi;
  z = If[x < xfn, ul1, ur1]; z )

mc2d[U_, phi_, xf0_, ul_, ur_, xa_, yb_, ix_, jy_,
          Saf_, Npic_, xview_, yview_, zview_] :=
(
(* -- Computation of the mesh steps hx,hy,dt -- *)
      cphi = N[Cos[phi]]; sphi = N[Sin[phi]];
A = U*cphi; B = U*sphi; ckf = sphi/cphi;
              yf0 = yb; hx = xa/ix; hy = yb/jy;
 dt = Saf/(Abs[A/hx] + Abs[B/hy]);
Tmax = ((xa - 4*hx)*cphi - xf0*cphi - yf0*sphi)/U;
(*  Tmax is the right end of the time interval  *)
 t1 = Tmax/2;   cp1 = A*dt/hx;   cp2 = B*dt/hy;
Nt = Floor[Tmax/dt]; Nt = Max[1, Nt];
n1 = Floor[Nt/Npic]; n1 = Max[1, n1];
 xf1 = xf0; yf1 = yf0;  ul1 = ul; ur1 = ur; U1 = U;
Print["A = ", A, ", B = ", B, ", n1 = ", n1,
      ", Tmax = ", Tmax];
Print["Nt = ", Nt, ", kappa1 = ", cp1,
      ", kappa2 = ", cp2];
(* --- Specification of the initial function
     u(x, y, 0) ---------------------------- *)
     u = Table[ul, {i, ix}, {j, jy}];
               up = Table[ul, {i, ix}, {j, jy}];
  Do[ y1 = (j - 0.5)*hy;
        Do[ x1 = (i - 0.5)*hx;
            u[[i, j]] = uex[x1, y1, 0.0],
	    {i, ix}],    {j, jy}];
 Print[u[[1,1]],",",u[[2,1]],",", u[[3,1]],",",
       u[[4,1]] ];
(* Plotting the initial surface u = u(x, y, 0) *)
Print["The initial surface u = u(x, y, 0)"];
 gr1 = ListPlot3D[u,
              ViewPoint -> {xview, yview, zview},
	      AxesLabel -> {"y", "x", "u"}];
 Display["fig2_26", gr1];
(* gr2 = ListDensityPlot[u];  *)
gr3 = ListContourPlot[u];
  tn = 0; n3 = n1;
		um = Max[Abs[ul], Abs[ur]];
  Print["umax = ", um];
(* --- Begin of the Do-loop for time steps --- *)
      Do[

(* --- Computation of the fluxes across the
       lower boundary y = 0 ------------------ *)
 fb = Table[ul, {i, ix}]; y1 = 0.0;
 Do[  fb[[i]] = u[[i,1]], {i, ix}];
(* -- The computation of the predictor values
    up[[i, j]] ------------------------------- *)
(* ------ Do-loop over the (i, j) nodes ------ *)
   Do[ fr = u[[1, j]];
       Do[ fl = fr; uz = u[[i, j]];
	   fr = If[i == ix, uz, u[[i + 1, j]] ];
If[j == jy, x1 = (i - 0.5)*hx; y1 = (jy + 0.5)*hy;
   gt = uex[x1, y1, tn], gt = u[[i, j + 1]] ];
	   gb = fb[[i]]; fb[[i]] = gt;
 up[[i, j]] = uz - cp1*(fr - fl) - cp2*(gt - gb),
                                  {i, ix}],
		         {j, jy}];

(*  Computation of the corrector values u[[i, j]] *)
 tn = tn + dt; umax = 0.0; umax1 = 0.0; y1= -0.5*hy;
  Do[ x1 = (i - 0.5)*hx; fb[[i]] = uex[x1, y1, tn],
                                           {i, ix}];
  Do[ x1 = -0.5*hx; y1 = (j - 0.5)*hy;
  fr = uex[x1, y1, tn];
      Do[ fl = fr; uz = up[[i, j]];
      fr = uz; gt = uz; gb = fb[[i]];  fb[[i]] = gt;
 u[[i, j]] = 0.5*(u[[i, j]] + uz - cp1*(fr - fl)
            - cp2*(gt - gb));
 y1 = Abs[u[[i,j]] ]; umax1 = Max[y1, umax1];
 y = Abs[u[[i, j]] - um]; umax = Max[y, umax],
                  {i, ix}], {j, jy}];
Print["n = ",n,", t = ", tn, ", max[u] = ", umax1];
  If[n == n3, Goto[graph]];
       If[umax > 2.*um, Goto[endsteps], Goto[endn]];
    If[n != n3, Goto[endn]];
     If[n == Nt, Goto[endsteps] ];
Label[endsteps]; Tmax = tn;
  Label[graph]; n3 = n3 + n1;
(* --- Plotting the numerical solution surface
              u = u(x,y,t) ------------------- *)
Print["The numerical solution surface",
      " u = u(x,y,t) at t =", tn];
 gr3 = ListPlot3D[u,
                 ViewPoint -> {xview, yview, zview},
	         AxesLabel -> {"y", "x", "u"}];
If[n == n1, Display["fig2_28a", gr3],
                         Display["fig2_28b", gr3] ];

 gr4 = ListContourPlot[u];
If[umax > 2.*um, Break[]];
Label[endn],
(* ---------- End of the Do-loop in n ----------- *)
                          {n, Nt}];
(* --------- End of the rogram mc2d.m ----------- *)
)

:[font = section; inactive; ]
Parameters Used in Program mc2d.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]
_______________________________________________________
 Parameter                                 Description
_______________________________________________________

U                      the modulus of the convection speed,
                        U = Sqrt[A^2 + B^2], A and B are the constant comp-
                        onents of the convection velocity along the x- and
                        y-axes, respectively; U > 0;
phi                   the angle between the convection velocity vector
                        and the positive direction of the x-axis,
                        0 <= phi <= Pi/2;
xf0                   the abscissa of a point at the disconti-
                        nuity front at t = 0 on the upper boundary y = yb,
                        xf0 >= 0;
ul                     the value of u(x, y, 0) behind the discontinuity
                        front;
ur                     the value of u(x, y, 0) ahead of the discontinuity
                        front;
xa                    the size of the rectangular spatial computational
                        domain along the x-axis, xa > 0;
yb                    the size of the rectangular spatial domain along
                        the y-axis, yb > 0;
ix                     the number of cells of an uniform rectangular
                       spatial grid along the x-axis, ix > 1;
jy                     the number of cells of an uniform rectangular
                       spatial grid along the y-axis, jy > 1;
Saf                  the safety factor in the formula for the computat-
                       ion of the time step dt; 0 < Saf <= 1 to ensure a
                       stable computation;
Npic                the number of the pictures of the difference sol-
                       ution surfaces u = u(x,y,t) for Npic moments of
                       time, Npic > 1;
xview              the coordinates of the viewpoint for the surface
yview              u = u(x, y, t). At least one of the coordinates
zview              xview, yview, zview should be greater than 1 in
                       modulus.
_____________________________________________

:[font = section; inactive; ]
Examples of Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]

mc2d[1.0, Pi/6, 0.2, 1.0, 0.2, 2.0, 0.5, 40, 10,
     0.8, 2, 1.3, -2.4, 2.0]

:[font = subsection; inactive; ]
Example 2 (Stable Computation, Saf = 0.8)
:[font = input; nowordwrap; ]

mc2d[1.0, Pi/6, 0.2, 1.0, 0.2, 2.0, 0.5, 40, 10,
                     0.8, 2, 2, 2, 2]

:[font = subsection; inactive; ]
Example 3
:[font = input; nowordwrap; ]

mc2d[1.0, Pi/6, 0.2, 1.0, 0.2, 2.0, 0.5, 40, 10,
     1.1, 2, 2, 2, 2]

:[font = section; inactive; ]
The Structure of the Output

:[font = special4; inactive; nowordwrap; nohscroll; ]
The following data are printed out in the process of the work of the
program:

1.  The current values of n, the time step number, the time t, and
      maximum of |u(x,y,t)|.

2.  The numerical solution surfaces u = u(x,y,t) for Npic fixed moments of
      time; the values of these times are printed out in the message like

            The numerical solution surface at t =1.11272

3.  The contour plots of u = u(x,y,t) at the same moments of time as the
    numerical solution surfaces.
^*)