(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
Planar Stability Regions
:[font = name; inactive; nohscroll; ]

                                   Victor G.Ganzha and Evgenii V.Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled
                                  V.G.Ganzha and E.V.Vorozhtsov
  Numerical Solutions For Partial Differential Equations: Problem Solving
  Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]
Numerical Solutions For Partial Differential Equations: Problem Solving
Using Mathematica.  CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
Initialisation
:[font = special4; inactive; nowordwrap; nohscroll; ]
Needs[Algebra`ReIm`, Algebra`Trigonometry`]

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program st2.ma which follows below enables one to obtain the
stability region of an explicit or implicit scalar difference scheme in-
volving  one  or  two  spatial  variables  and approximating a scalar 
PDE of  hyperbolic or parabolic type. The underlying method of the 
stability  analysis  is  the  Fourier  method  (see Section 2.10 of the 
above book). It is assumed that the stability region is described  in 
terms of two nondimensional parameters kappa1 and kappa2. The 
boundaries of the (generally multiply connected) stability region are 
determined in  the (kappa1, kappa2) plane with the aid of the modi-
fied  Pavlidis'  algorithm  from  the digital pattern recognition theory. 
The description of the algorithm can be found in Section 2.13 of the 
above book.


:[font = section; inactive; ]
User's Guide
:[font = subsection; inactive; ]
Step 1
:[font = special4; inactive; nowordwrap; nohscroll; ]
Load and compile the program file beginning with the line

:[font = input; nowordwrap; ]

ClearAll[fbis1, fbis2, binfun, bingen, inds, atan3,
         tracer, bisec, stab2];
:[font = subsection; inactive; ]
Step 2
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the form of a difference scheme by modifying the body of the
function sch1, see below Section "Examples of Difference Schemes".
:[font = subsection; inactive; ]
Step 3
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the form of the nondimensional variables kappa1 and kappa2
in terms of which the stability region is to be determined. The corresp-
onding transformation rule should follow the expression for the differ-
ence scheme (see examples below) and should be in the same cell as
the difference scheme itself. Load and compile the difference scheme
together with the transformation rule.
:[font = subsection; inactive; ]
Step 4
:[font = special4; inactive; nowordwrap; nohscroll; ]

Specify the input data by entering them in the line (see Section 
"Examples of the Input Data"):
:[font = input; nowordwrap; ]

stab2[-1.2, 1.2, -1.2, 1.2, 10, 10, 2, 0.005, Allen]
:[font = special4; inactive; nowordwrap; nohscroll; ]

Then click in this line and wait for the result of symbolic/numerical computation.
The meaning of the input parameters is explained in the Section
"Parameters Used in Program st2all.ma".

:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; backColorRed = 65280; backColorGreen = 65280; backColorBlue = 65280; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; bold; fontName = "Courier New"; fontSize = 12; ]

ClearAll[fbis1, fbis2, binfun, bingen, inds, atan3,
         tracer, bisec, stab2];

fbis1[x_, y_, ss1_List, cc1_List, nspg_] :=
( bin1 = 1; deps=N[1.0+1.0/(10^8)];
  jb1 = 1; msp = nspg;
Label[loop]; vals = {sa -> ss1[[jb1]],
ca -> cc1[[jb1]], cp1 -> x, cp2 -> y};
rlj = N[rel /. vals]; imj = N[iml /. vals];
rr = rlj*rlj + imj*imj;
 If[rr[[1]] > deps, msp = jb1];
  jb1 = jb1 + 1; If[jb1 <= msp, Goto[loop]];
  If[msp < nspg, bin1 = 0]; Return[bin1] );

fbis2[x_, y_, ss1_List, cc1_List, nspg_] :=
( bn2d = 1; deps = N[1.0 + 1.0/(10^8)];
  kb2 = 1; nspg2 = nspg;
 Label[lpk2]; jb2 = 1; msp = nspg;
Label[lpj]; vals = {sa -> ss1[[jb2]],
ca -> cc1[[jb2]], sb -> ss1[[kb2]], 
     cb -> cc1[[kb2]], cp1 -> x, cp2 -> y};
reljk = N[rel /. vals]; imljk = N[iml /. vals];
      rjk = reljk*reljk + imljk*imljk;
  If[rjk[[1]] > deps, msp = jb2];
     jb2 = jb2 + 1; If[jb2 <= msp, Goto[lpj]];
  If[msp < nspg, Return[0]];
  kb2 = kb2 + 1; If[kb2 <= nspg2, Goto[lpk2]];
      If[nspg2 < nspg, bn2d = 0]; bn2d );

binfun[x_, y_, ss1_List, cc1_List, nspg_] :=
(
If[nsptr == 1, fbs3 = fbis1[x, y, ss1, cc1, nspg];
   Return[fbs3]];
fbs3 =fbis2[x, y, ss1, cc1, nspg]; Return[fbs3] );

bingen:=
(* --- Generation of the bilevel image fbin --- *)
( fbin = Table[0, {i, ixt}, {j, jyt}];
jsum = 0; hx = (xrt - xlt)/ixt; hy = (ytt-ybt)/jyt;
Print["Bilevel picture generation"];
 Do[x = xlt + (i - 0.5)*hx; binlist = {};
    Do[y = ybt + (j -0.5)*hy;
    fbin[[i, j]] = binfun[x, y, ss1, cc1, nspg];
    AppendTo[binlist, fbin[[i, j]] ];
       jsum = jsum + fbin[[i, j]], {j, jyt}];
       Print[binlist], {i, ixt}];
		                {jsum, fbin} );

inds[is_, i_, j_]:=
(* - This procedure determines the indices (i1,j1)
     of the next cell along the contour basing on 
     the indices (i,j) of a given cell and the 
     given search direction "is", 1<= is<= 8 - *)
( jb = 0; is2 = is; If[is2 > 8, is2 = is - 8];
  If[is2 == 1, i1 = i + 1; j1 = j;
 If[i1 < 1||i1 > ixt||j1 < 1 || j1 > jyt, jb = 1];
 Return[{i1, j1, jb}]];
   If[is2 == 2, i1 = i + 1; j1 = j + 1;
   If[i1 < 1||i1 > ixt||j1 < 1||j1 > jyt, jb = 1];
   Return[{i1, j1, jb}]];
     If[is2 == 3, i1 = i; j1 = j + 1;
     If[i1 < 1||i1 > ixt||j1<1||j1 > jyt, jb = 1];
     Return[{i1, j1, jb}]];
       If[is2 == 4, i1 = i - 1; j1 = j + 1;
 If[i1 < 1||i1 > ixt||j1 < 1 || j1 > jyt, jb = 1];
       Return[{i1, j1, jb}]];
         If[is2 == 5, i1 = i - 1; j1 = j;
 If[i1 < 1||i1 > ixt||j1 < 1 || j1 > jyt, jb = 1];
         Return[{i1, j1, jb}]];
          If[is2 == 6, i1 = i - 1; j1 = j - 1;
 If[i1 < 1||i1 > ixt||j1 < 1 || j1 > jyt, jb = 1];
          Return[{i1, j1, jb}]];
        If[is2 == 7, i1 = i; j1 = j - 1;
 If[i1 < 1||i1 > ixt||j1 < 1 || j1 > jyt, jb = 1];
        Return[{i1, j1, jb}]];
      If[is2 == 8, i1 = i + 1; j1 = j - 1;
 If[i1 < 1||i1 > ixt||j1 < 1 || j1 > jyt, jb = 1];
      Return[{i1, j1, jb}]]);

tracer[nsg_, i0_, j0_]:=
(* ------------ Tracing a contour ------------ *)
( i = i0;   j = j0;   is = 0;
fbin[[i, j]] = fbin[[i, j]] + 1;
is = is + 1; jc[[is, nsg]] = 9; iser = 7; ifir = 1;
     xs[[is, nsg]] = xlt + (i - 0.5)*hx;
     ys[[is, nsg]] = ybt + (j - 0.5)*hy;
Label[m8]; icnt = 0; idect = 0;
Label[m13]; is1 = iser - 1; If[is1 == 0, is1 = 8];
	   {i1, j1, jb} = inds[is1, i, j];
 If[jb == 1|| fbin[[i1, j1]] == 0, Goto[m9]];
  iser = iser - 2; If[iser <= 0, iser = iser + 8];
Label[m11]; is = is + 1; i=i1; j=j1;
            fbin[[i, j]] = fbin[[i, j]] + 1;
xs[[is, nsg]] = xlt + (i - 0.5)*hx;
ys[[is, nsg]] = ybt + (j - 0.5)*hy;
jc[[is, nsg]] = is1; idect = 1;
        If[i!= i0 || j != j0, Goto[m8], Goto[m7]];
Label[m9]; {i1, j1, jb} = inds[iser, i, j];
       If[jb == 1||fbin[[i1, j1]] == 0, Goto[m10]];
is1 = iser; Goto[m11];
Label[m10]; is1=iser+1; If[is1 > 8, is1 = is1 - 8];
{i1, j1, jb} = inds[is1, i, j];
If[jb==1||fbin[[i1,j1]]==0, Goto[m12]]; Goto[m11];
Label[m12]; iser=iser+2; If[iser>8,iser=iser - 8];
            ifir = 0;
If[idect == 1, Goto[m7]]; icnt = icnt + 1;
                         If[icnt < 3, Goto[m13]];
Label[m7]; kss[[nsg]] = is );

remv[istar_, ifin_, k_] :=
( istar2 = istar; If[istar<=ifin,ic=jc[[istar,k]];
istar2 = istar2 + 1; Return[{ic, istar2}]];
ic = -1; {ic, istar2} );

 atan3[zy_, zx_] :=
( rof = 0.000000001;
If[Abs[zx]>rof,Goto[m2]]; If[Abs[zy]<rof,Goto[m3]];
a = N[Pi/2.0]; If[zy < 0.0, a = N[a + Pi]]; 
    Return[a];
Label[m3]; a = 0.0; Return[a];
Label[m2]; If[Abs[zy] < rof, a = 0.0;
           If[zx < 0.0, a = N[Pi]]; Return[a]];
a = ArcTan[zx,zy]; If[zx>0.0&&zy>0.0, Return[a]];
If[zx > 0.0&& zy < 0.0, a = N[a + 2*Pi]; Return[a]];
     If[zx < 0.0, a = N[a + Pi]]; Return[a]  );

bisec[x_,y_,ik_,k_,mk_,adir_List]:=
(* The refinement of the (x,y) coordinates of the
   ik th point of the k th contour; mk is the 
   length of th kth contour -------------------- *)
( i = Floor[1.0 + (x - xlt)*hx1];
                     j = Floor[1.0 + (y -ybt)*hy1];
i1 = ik + 1; i2 = ik - 1;
    If[ik == mk, i1 = i1 - 1; i2 = i2 - 1];
       If[ik == 1, i2 = 1];
(* -- Determining the number k2 of the principal 
      direction corresponding to the direction of 
      a normal to the contour at (i, j) point. - *)
(* x1 = xs[[i1, k]]; y1 = ys[[i1, k]];
           x2 = xs[[i2, k]]; y2 = ys[[i2, k]];  *)
   x1 = xxxx[[i1]]; y1 = ytab[[i1]];
                 x2 = xxxx[[i2]]; y2 = ytab[[i2]];
     dx = x2 - x1; dy = y1 - y2;
anrm = atan3[dx, dy];   zm = 1000.0; il = -2;
Do[ zk = Abs[adir[[ja]] - anrm];
                     If[zk < zm, zm = zk;k2 = ja],
     {ja, 9}];
               If[k2 == 9, k2 = 1];
(* -- Determining the indices (il, jl) of a cell 
      lying on a normal to the contour -------- *)
If[k2 == 1, il = i + 1; jl = j; ir = i - 1; jr = j];
  If[il > -2, Goto[refin]];
If[k2 == 2, il=i+1; jl=j+1; ir = i - 1; jr= j - 1];
     If[il > -2, Goto[refin]];
If[k2 == 3, il = i; jl = j+ 1; ir = i; jr = j - 1];
        If[il > -2, Goto[refin]];
If[k2 == 4, il = i - 1; jl=j+1; ir=i+1;jr = j - 1];
           If[il > -2, Goto[refin]];
If[k2 == 5, il = i - 1; jl = j; ir = i + 1; jr= j];
           If[il > -2, Goto[refin]];
If[k2 == 6, il = i-1; jl=j-1; ir=i + 1;jr = j + 1];
        If[il > -2, Goto[refin]];
If[k2 == 7, il = i; jl = j - 1; ir = i; jr= j + 1];
    If[il > -2, Goto[refin]];
If[k2 == 8, il= i + 1; jl = j-1; ir=i-1; jr=j + 1];
Label[refin];
x1n = xlt + (il - 0.5)*hx; y1n = ybt+(jl - 0.5)*hy;
x2n = xlt + (ir - 0.5)*hx; y2n = ybt+(jr - 0.5)*hy;
tl = 0.0; tr = 1.0; a1 = x2n - x1n; a2 = y2n - y1n;
	 isl = binfun[x1n, y1n, ss1, cc1, nspg];
isr = binfun[x2n,y2n,ss1,cc1,nspg]; x3 = x; y3 = y;
     If[isl != isr, Goto[bisproc]];
                       If[isl== 0, Goto[recalc]];
If[il == 0||ir == 0, x3 = xlt];
       If[il == ixt + 1||ir == ixt + 1, x3 = xrt];
If[jl == 0||jr == 0,y3 = ybt];
       If[jl == jyt + 1||jr == jyt + 1, y3 = ytt];
Return[{x3, y3}];
Label[recalc]; ir=i;jr=j; x2n=x; y2n= y; isr = 1;
                  a1 = x2n - x1n; a2 = y2n - y1n;
Label[bisproc];
t = N[(tl+tr)*0.5]; xc=a1*t+x1n; yc = a2*t + y1n;
         nc = binfun[xc, yc, ss1, cc1, nspg];
	If[nc == isr, tr = t, tl = t];
  If[N[Abs[a1*(tl - tr)]] > epst, Goto[bisproc]];
  If[N[Abs[a2*(tl - tr)]] > epst, Goto[bisproc]];
  x3 = a1*t + x1n; y3 = a2*t + y1n;
			 Return[{x3, y3}]  );

 stab2[xl_,xr_,yb_,yt_,ix_,jy_,nsptr_,eps_,sc_] :=
 (
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Part 1. Symbolic computations with the pur- %%%%
%%% pose of obtaining the expressions for the   %%%%
%%% coefficients of the characteristic equation %%%%
%%% of difference scheme                        %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*)
<< Algebra`ReIm`;
Print["The package Algebra`ReIm` is loaded"];
(* The variables xi, xi1, xi2, cp1, cp2 are declared
                                            to be real *)
xi/: Im[xi] = 0;
xi1/: Im[xi1] = 0;
xi2/: Im[xi2] = 0;
cp1/: Im[cp1] = 0;
cp2/: Im[cp2] = 0;
(* ---- Substitution of a Fourier harmonic into
        the difference scheme ----------------- *)
  If[nsptr == 1, 
sc0 = sc/. c12rule ; 
Print["The difference scheme under consideration"];
Print[sc0, " = 0"];
sc1 = sc0 /. {u[j_, n_] -> l^n*Exp[I*j*xi]};
(* -- Divide the both sides of obtained equation
           by l^n Exp[I*j*xi] ----------------- *)
      sc3 = sc1/(l^n*Exp[I*j*xi]) //Expand;
      sc2 = Simplify[sc3] ];
  If[nsptr == 2, sc0 = sc/. c12rule;
Print["The difference scheme under consideration"];
Print[sc0, " = 0"];
sc1 = sc0 /. 
{u[j_, k_, n_] -> l^n*Exp[I*j*xi1]*Exp[I*k*xi2]};
(* -- Divide the both sides of obtained equation by
      l^n Exp[I*j*xi1]*Exp[I*j*xi2] ------------ *)
sc3 = sc1/(l^n*Exp[I*j*xi1]*Exp[I*k*xi2]) //Expand;
      sc2 = Simplify[sc3] ];

  sol = Solve[sc2==0, l];
l1 = Expand[l /. sol] ; 
(* l1 = Simplify[l1]; *)
Print["The amplification factor of scheme has",
" the form"];
Print["lambda = ", l1];
l1 >> str2.m;
l4 = ComplexExpand[l1]; 
l = l4; lnum = Numerator[l];
OutputForm[lnum] >>> str2.m;
lden = Denominator[l]; imd = Im[lden];
OutputForm[lden] >>> str2.m;
OutputForm[imd] >>> str2.m;
If[lden == 1, iml = Im[l]; rel = l - I*iml];
If[lden =!= 1 && imd == 0,
imn = Im[lnum]; relnom = lnum - I*imn;
imn = Simplify[imn]; relnom = Simplify[relnom];
iml = imn/lden; rel = relnom/lden];
(* ---- The complex denominator ---- *)
If[lden =!= 1 && imd =!= 0, relden = lden - I*imd;
ld2 = relden*relden + imd*imd;
imn = Im[lnum]; relnom = lnum - I*imn;
imn = Simplify[imn]; relnom = Simplify[relnom];
rel = (relnom*relden + imn*imd)/ld2;
iml = (imn*relden - relnom*imd)/ld2];
rel = Simplify[rel]; iml = Simplify[iml];
OutputForm[rel] >>> str2.m;
OutputForm[iml] >>> str2.m;
          Print["Re(lambda) = ", rel];
          Print["Im(lambda) = ", iml];
  rel >>> str2.m;  
  iml >>> str2.m;
      << Algebra`Trigonometry`;
casa = {Cos[xi] -> ca, Sin[xi] -> sa};
cacb = {Cos[xi1] -> ca, Sin[xi1] -> sa,
        Cos[xi2] -> cb, Sin[xi2] -> sb};
If[nsptr == 1, 
rel = TrigReduce[rel] /. casa; 
iml = TrigReduce[iml] /. casa,
 rel = TrigReduce[rel] /. cacb;
 iml = TrigReduce[iml] /. cacb];
If[nsptr == 1, rel = rel /. {ca^2 -> 1 - sa^2};
               iml = iml /. {ca^2 -> 1 - sa^2}];
rel = Simplify[rel];
Print["Re(lambda) = ", rel];
iml = Simplify[iml];
 Print["Im(lambda) =", iml];
   
(*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%  Part 2. Numerical computations with the purpose  %%%%
%%%%  of determining the coordinates of points of all  %%%%
%%%%  the contours of the stability region boundary    %%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*)
xlt = xl; xrt = xr; ybt = yb; ytt = yt; 
ixt = ix; jyt = jy; epst = eps;
(* - Determination of nspg, the number of grid 
     points along the axis of each spectral 
     variable xi1, xi2 ----------------------- *)
      fbin = Table[0, {i, 1, ix}, {j, 1, jy}];
          nspg0 = 2; npold = 0; dnabs = 1000;
   Print["Determination of nspg"];
     Do[nspg = nspg0 + 2*j;
   ss1 = Table[N[Sin[(k-1)*2*Pi/nspg]], {k, nspg}];
   cc1 = Table[N[Cos[(k-1)*2*Pi/nspg]], {k, nspg}];
  {npnew, fbin} = bingen;
      If[j == 1, npold = npnew, 
 dnabs = N[Abs[npnew - npold]]];
Print["nspg, pointsnew, pointsold, dnabs = ", 
nspg, "  ", npnew, " ", npold, " ",dnabs];
         If[dnabs == 0, Break[]];
  npold = npnew, {j, 48 }];
  nparea = npold; lenmax = ix*jy; 
        Do[k = jy - j + 1; frow = {};
      Do[AppendTo[frow, fbin[[i, k]]], {i, ix}];
      Print[frow], {j,jy}];
If[npold == 0, Print["No stability points"]; 
Interrupt[ ]];
If[npold == ix*jy,
Print["The difference scheme is stable in the",
" given region"];
Print["{(kappa1,kappa2)|",xl,"<=kappa1<=",xr,
",", yb,"<=kappa2<=",yt,"}"];
Print["Computation is interrupted."];
Interrupt[] ];

   Print["j       Xj        sin(Xj)      cos(Xj)"];
Do[ss= ss1[[j]]; cc= cc1[[j]]; xj= N[(j - 1)*2*Pi/nspg];
Print[j,"  ", xj, "  ", ss, "  ", cc], {j, nspg}];

z1 = npold*hx*hy; 
Print["Area of stability region = ", z1];
      nparea = npold; ifir = 0; nsg = 0;
		nsgmax = 10; lenmax = ix*jy;
(*  nsg is the number of contours of the stability
    region boundary  *)
(* -- lenmax is the maximum length, that is the 
      maximum number of pixels, for each detected 
      contour ---------------------------------- *)
(* --- Initialization of a number of lists ----- *)
   xs = Table[999.99999, {i, lenmax}, {j, nsgmax}];
   ys = Table[999.99999, {i, lenmax}, {j, nsgmax}];
(* -- (xs[[i, j]], ys[[i, j]]) are the (kappa1, kappa2)
   coordinates of the i th point of the j th contour --- *)
      jc = Table[99, {i, lenmax}, {j, nsgmax}];
(*  jc is a two-dimensional array of integers used 
    to mark different points of different contours *)
      kss = Table[9999, {j, nsgmax}];
(*  kss[[j]] is the length of the j th contour,
    1 <= j <= nsgmax  *)

(* ------ Tracing the external contours ------- *)
    Do[
       Do[
          If[fbin[[ii, jj]] == 0, Goto[endloop]];
(* - Search for the starting point of the contour - *)
If[fbin[[ii, jj]] > 1, Goto[endloop]];
                          If[ii == 1,Goto[start]];
If[fbin[[ii - 1, jj]] != 0, Goto[endloop]];
Label[start]; i0 = ii; j0 = jj; nsg = nsg + 1;
 If[nsg > nsgmax,
    Print["The number of contours exceeds ", nsgmax];
Print["Detection of further contours is interrupted."];
Print["To detect the remaining contours please increase",
" the value of nsgmax."]; Break[ ]];
   tracer[nsg, i0, j0];
		       Label[endloop], {ii, ix}];
If[nsg > nsgmax, nsg = nsg - 1; Break[ ]],
   {jj, jy}];
(* ------- Tracing the contours of holes ------- *)
 k1 = 1; k2 = nsg; nsg1 = nsg; hx = (xr - xl)/ix;
 hy = (yt - yb)/jy; hx1 = 1/hx; hy1 = 1/hy; k = 1;
 Label[l20];
      ig = kss[[k]]; istar = 1; ifin = ig;
Label[l17]; {id, istar2} = remv[istar, ifin, k];
        istar = istar2;
   If[id == -1, Goto[l3]];  If[id != 9, Goto[l15]];
id0 = id; {id,istar2} = remv[istar, ifin, k];
                istar = istar2;
Label[l15]; If[id0 < 5||id0 > 8, Goto [l16]];
            If[id < 6||id > 8, Goto[l16]];
x1 = xs[[istar, k]]; y1 = ys[[istar, k]];
  ilef = Floor[0.51 + (x1 - xl)*hx1];
                  j2 = Floor[0.51 + (y1 - yb)*hy1];
ilp = ilef + 1; irm = ix - 1;  i2 = ilp;
   Label[labilp];
    ia = fbin[[i2 - 1, j2]]; ib = fbin[[i2, j2]];
   ic = fbin[[i2 + 1, j2]]; If[ia != 0, Goto[l37]];
    If[ib != 1||ib != 2||ic != 0, Goto[l27]];
          i0 = i2; j0 = j2; nsg1 = nsg1 + 1;
 Print["The contour No. ", nsg1, " is detected."];
 tracer[nsg1, i0, j0]; Goto[l16];
Label[l27];
       If[ia == 0 && ib > 2 && id ==-1, Goto[l16]];
Label[l37];
    If[ia == 1 && ib == 2&&id == -1, Goto[l16]];
 i2 = i2+1; If[i2 <= irm, Goto[labilp]]; Goto[l3];
Label[l16]; id0 = id; Goto[l17];
Label[l3];
          k = k + 1; If[k <= k2, Goto[l20]];
If[nsg1 == nsg, Goto[l21]];
nsg = k2; k1 = nsg + 1; k2 = nsg1; Goto[l20];
Label[l21]; nsg = nsg1; 
Print["Number of contours = ",nsg];
   Do[ isg = kss[[k]];
Print["The length of the contour No. ", k, " is ",
       isg, " points"], {k, nsg}];

(* -- Storing the pictures in the elements mt[[k]],
         k = 1,...,nsg ------------------------- *)
             nsg1 = nsg + 1;  mt = {};
          xxxx = Table[99.9999, {j,lenmax}];
          ytab = Table[99.9999, {j,lenmax}];
    Do[ isg = kss[[k]];
Print["The x- and y-coordinates of points of the contour ",
      "No. ", k];
       Do[ xx = xs[[j, k]]; yy = ys[[j, k]];
          Print[j,"   ", xx, "   ", yy], {j, isg}],
          {k, nsg}];
   Do[ isg = kss[[k]];
 Do[xxxx[[j]] = xs[[j, k]]; ytab[[j]] = ys[[j, k]],
          {j, isg}];
    xytb = Table[{xxxx[[j]], ytab[[j]]}, {j, isg}];
     plj = ListPlot[xytb, PlotJoined -> True,
                   AxesLabel->{"kappa1","kappa2"},
                   AspectRatio -> Automatic,
                   DisplayFunction -> Identity];
       AppendTo[mt, plj],
          {k, nsg}];
xxxx = Table[99.999,{j, nparea}]; 
ytab = Table[99.999,{j, nparea}];
   k = 0;
   Do[
      Do[ k1 = fbin[[i, j]];
   If[k1 != 0, k=k+1; xxxx[[k]]=xl + (i - 0.5)*hx;
          ytab[[k]] = yb + (j - 0.5)*hy],
                        {j, jy}],
           {i, ix}];
 xytb=Table[{xxxx[[j]], ytab[[j]]}, {j, nparea}];
   pldot = ListPlot[xytb,
             AxesLabel->{"kappa1","kappa2"},
             AspectRatio -> Automatic,
             DisplayFunction -> Identity];
   AppendTo[mt, pldot];
 gr = Show[mt,DisplayFunction->$DisplayFunction]; 
  Display["fig2_38a", gr];

(*  Specification of the angles adir[[j]] corresponding to
    the eight principal directions; the direction
    adir[[9]] = 2 Pi is an auxiliary direction, which is
    identified with the direction adir[[1]] = 0 in subseq-
    uent computations. *)
 adir = {}; AppendTo[adir, 0.0]; z = ArcTan[hx, hy];
       AppendTo[adir, z]; pi2 = N[Pi/2.]; z2 = N[pi2 - z];
z3 = N[pi2 + z2]; z4 = N[Pi + z]; z7 = N[Pi + pi2];
z8 = N[z7 + z2];
     AppendTo[adir, pi2];
AppendTo[adir, z3]; AppendTo[adir, N[Pi]];
      AppendTo[adir, z4];
      AppendTo[adir, z7]; AppendTo[adir, z8];
               z9 = Pi + Pi; AppendTo[adir, N[z9]];
Print["The values of angles corresponding to nine",
              " principal directions"];
 Print[adir];
 Print["The refinement of coordinates of contour points"];
(*  Refinement of coordinates of boundary points  *)
Do[  mk = kss[[k]]; xxxx = {}; ytab = {};
   Do[ xx6 = xs[[ii,k]]; yy6 = ys[[ii, k]];
   AppendTo[xxxx, xx6]; AppendTo[ytab, yy6],
      {ii, mk}];
   Do[x1 = xs[[ii, k]]; y1 = ys[[ii, k]];
   {x3, y3} = bisec[x1, y1, ii, k, mk, adir];
Print["The point no. ", ii, " has been refined"];
   xs[[ii, k]] = x3; ys[[ii, k]] = y3, {ii, mk}];
 Print["The contour No.", k," has been refined"],
 {k, nsg}];
(* ------- Closing the refined contours ------- *)
Do[ isg = kss[[k]]; z1=0.5*(xs[[1,k]]+xs[[isg,k]]);
                     z2 = 0.5*(ys[[1,k]] + ys[[isg, k]]);
    xs[[1,k]] = z1; ys[[1, k]] = z2;
 xs[[isg, k]] = z1; ys[[isg, k]] = z2, {k, nsg}];
(* - Graphical display of the refined contours - *)
                           mt = {};
   Do[ isg = kss[[k]]; xxxx = {}; ytab = {};
 Do[ AppendTo[xxxx, xs[[j, k]]]; 
       AppendTo[ytab, ys[[j, k]]], {j, isg}];
   xytb = Table[{xxxx[[j]], ytab[[j]]}, {j, isg}];
       plj = ListPlot[xytb, PlotJoined -> True,
                   AxesLabel->{"kappa1","kappa2"},
                   AspectRatio -> Automatic,
                   DisplayFunction -> Identity];
   AppendTo[mt, plj], {k, nsg}];
                             AppendTo[mt, pldot];
gr1 = Show[mt,DisplayFunction->$DisplayFunction];

		  Display["fig2_38b", gr1];

(* ------- End of the procedure stab2 --------- *)
	  )


:[font = section; inactive; ]
Parameters Used in Program st2.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]
______________________________________________________
 Parameter                         Description
______________________________________________________
xl                   the left end of the interval on the kappa1-axis (the
                     horizontal axis), in which the stability region is to
                     be determined;
 xr                 the right end of the above interval on the
                     kappa1-axis; xl<=kappa1<= xr;
 yb                the lower end of the interval on the kappa2-axis (the
                     vertical axis), in which the stability region is to
                     be determined;
 yt                 the upper end of the above interval on the kappa2-
                    axis; yb<=kappa1<= yt;
                    the stability region is thus to be determined in a
                    rectangle in the (kappa1, kappa2) plane;
 ix                the number of cells of an uniform mesh in the inter-
                    val xl<= kappa1<=xr; ix >= 3;
 jy                 the number of cells of an uniform mesh in the inter-
                    val yb<= kappa2<=yt; jy >= 3;
nsptr            the number of spectral variables,  nsptr = 1 or
                    nsptr = 2;
eps              the given accuracy of the computation of the coordi-
                    nates of points of the stability region boundary;
sc                the left-hand side of the difference equation sc = 0
_______________________________________________________

:[font = section; inactive; ]
Examples of Difference Schemes
:[font = message; inactive; nowordwrap; ]

    Attention! In the case of a single spatial variable, only 
the letter j can be used to denote the number of the grid node
on the x-axis, and only the letter n can be used to denote the
time level.
    In the case of difference schemes involving two spatial
variables, only the letters j and k can be used to denote the
indices of the grid node along the x- and y-axis, respectively;
and only the letter n can be used to denote the time level. 
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]

(* -- The explicit difference scheme for advection-
      diffusion equation ----------------------- *)
ClearAll[ut, ux, uxx, a, nu, j, n];
addif1 = ( ut = (u[j,n+1] - u[j,n])/dt;
ux = (u[j+1,n] - u[j-1,n])/(2*h1);
uxx = (u[j+1,n] - 2*u[j,n] + u[j-1,n])/(h1^2);
             ut + a*ux - nu*uxx )  
(* -- Transformation rule for the introduction of
      the nondimensional variables cp1 and cp2 - *)
  (*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  !!  Attention! Only the identifiers cp1  !!
  !!  and cp2 can be used to denote the    !!
  !!  nondimensional variables kappa1 and  !!
  !!  kappa2.                              !!
  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*)

   c12rule = {a -> cp1*h1/dt, nu-> cp2*h1^2/dt}

:[font = subsection; inactive; ]
Example 2
:[font = input; nowordwrap; ]
(* -- Allen's scheme for the one-dimensional
      advection-diffusion equation ------------ *)
ClearAll[ut1, vp, vm, Allen, j, n];
Allen = ( ut1 = u[j,n+1]*(1 + 2*cp2)^2;
vp = u[j+1,n] - (cp1/2)*(u[j+2,n]-u[j,n]) +
     cp2*(u[j+2,n] + u[j,n]);
vm = u[j-1,n] - (cp1/2)*(u[j,n] - u[j-2,n]) +
     cp2*(u[j,n] + u[j-2,n]);
            sc = ut1 - u[j,n]*(1 + 2*cp2) +
(cp1/2)*(vp - vm) - cp2*(vp + vm); sc )  
(* -- Transformation rule for the introduction of
      the nondimensional variables cp1 and cp2 - *)
  (*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  !!  Attention! Only the identifiers cp1  !!
  !!  and cp2 can be used to denote the    !!
  !!  nondimensional variables kappa1 and  !!
  !!  kappa2.                              !!
  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*)

   c12rule = {a -> cp1*h1/dt, nu-> cp2*h1^2/dt}

:[font = subsection; inactive; ]
Example 3
:[font = input; nowordwrap; ]

(* -- The MacCormack scheme for the 2D advection
      equation (2.12.2) ------------------------ *)
(* -- The predictor equation of the MacCormack 
      scheme ----------------------------------- *)
ClearAll[up, MacCormack, a, b, j, k, n];
up[j_, k_, n_]:=
( uxp = (u[j + 1, k, n] - u[j, k, n])/h1;
	   uyp = (u[j, k + 1, n] - u[j, k, n])/h2;
 u[j, k, n] - dt*a*uxp - dt*b*uyp )
(* The corrector equation of the MacCormack scheme*)
MacCormack =
( ut = (u[j,k,n+1]-(1/2)*(u[j,k,n]+up[j,k,n]))/dt;
  ux = a*(up[j, k, n] - up[j - 1, k, n])/(2*h1);
 uy = b*(up[j,k,n]-up[j,k-1,n])/(2*h2); ut+ux+uy )
(* ----------- dt is the time step ------------- *)

(* -- Transformation rule for the introduction of
      the nondimensional variables cp1 and cp2 - *)
  (*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  !!  Attention! Only the identifiers cp1  !!
  !!  and cp2 can be used to denote the    !!
  !!  nondimensional variables kappa1 and  !!
  !!  kappa2.                              !!
  !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!*)

   c12rule = {a -> cp1*h1/dt, b -> cp2*h2/dt}

:[font = section; inactive; ]
Examples of the Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; startGroup; nowordwrap; ]

stab2[-1.2, 1.2, 0.0, 0.6, 40, 10, 1, 0.003, addif1]
:[font = postscript; inactive; output; BITMAP; PostScript; pictureLeft = 23; pictureTop = 0; pictureWidth = 508; pictureHeight = 123; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: .24194 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.512033 0.00576037 0.512033 [
[(-0.75)] .11598 .00576 0 2 Msboxa
[(-0.5)] .24398 .00576 0 2 Msboxa
[(-0.25)] .37199 .00576 0 2 Msboxa
[(0.25)] .62801 .00576 0 2 Msboxa
[(0.5)] .75602 .00576 0 2 Msboxa
[(0.75)] .88402 .00576 0 2 Msboxa
[(kappa1)] 1.025 .00576 -1 0 Msboxa
[(0.1)] .4875 .05696 1 0 Msboxa
[(0.2)] .4875 .10817 1 0 Msboxa
[(0.3)] .4875 .15937 1 0 Msboxa
[(0.4)] .4875 .21057 1 0 Msboxa
[(kappa2)] .5 .24194 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .24294 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.11598 .00576 m
.11598 .01201 L
s
P
[(-0.75)] .11598 .00576 0 2 Mshowa
p
.002 w
.24398 .00576 m
.24398 .01201 L
s
P
[(-0.5)] .24398 .00576 0 2 Mshowa
p
.002 w
.37199 .00576 m
.37199 .01201 L
s
P
[(-0.25)] .37199 .00576 0 2 Mshowa
p
.002 w
.62801 .00576 m
.62801 .01201 L
s
P
[(0.25)] .62801 .00576 0 2 Mshowa
p
.002 w
.75602 .00576 m
.75602 .01201 L
s
P
[(0.5)] .75602 .00576 0 2 Mshowa
p
.002 w
.88402 .00576 m
.88402 .01201 L
s
P
[(0.75)] .88402 .00576 0 2 Mshowa
p
.001 w
.14158 .00576 m
.14158 .00951 L
s
P
p
.001 w
.16718 .00576 m
.16718 .00951 L
s
P
p
.001 w
.19278 .00576 m
.19278 .00951 L
s
P
p
.001 w
.21838 .00576 m
.21838 .00951 L
s
P
p
.001 w
.26959 .00576 m
.26959 .00951 L
s
P
p
.001 w
.29519 .00576 m
.29519 .00951 L
s
P
p
.001 w
.32079 .00576 m
.32079 .00951 L
s
P
p
.001 w
.34639 .00576 m
.34639 .00951 L
s
P
p
.001 w
.39759 .00576 m
.39759 .00951 L
s
P
p
.001 w
.4232 .00576 m
.4232 .00951 L
s
P
p
.001 w
.4488 .00576 m
.4488 .00951 L
s
P
p
.001 w
.4744 .00576 m
.4744 .00951 L
s
P
p
.001 w
.5256 .00576 m
.5256 .00951 L
s
P
p
.001 w
.5512 .00576 m
.5512 .00951 L
s
P
p
.001 w
.5768 .00576 m
.5768 .00951 L
s
P
p
.001 w
.60241 .00576 m
.60241 .00951 L
s
P
p
.001 w
.65361 .00576 m
.65361 .00951 L
s
P
p
.001 w
.67921 .00576 m
.67921 .00951 L
s
P
p
.001 w
.70481 .00576 m
.70481 .00951 L
s
P
p
.001 w
.73041 .00576 m
.73041 .00951 L
s
P
p
.001 w
.78162 .00576 m
.78162 .00951 L
s
P
p
.001 w
.80722 .00576 m
.80722 .00951 L
s
P
p
.001 w
.83282 .00576 m
.83282 .00951 L
s
P
p
.001 w
.85842 .00576 m
.85842 .00951 L
s
P
p
.001 w
.09037 .00576 m
.09037 .00951 L
s
P
p
.001 w
.06477 .00576 m
.06477 .00951 L
s
P
p
.001 w
.03917 .00576 m
.03917 .00951 L
s
P
p
.001 w
.01357 .00576 m
.01357 .00951 L
s
P
p
.001 w
.90963 .00576 m
.90963 .00951 L
s
P
p
.001 w
.93523 .00576 m
.93523 .00951 L
s
P
p
.001 w
.96083 .00576 m
.96083 .00951 L
s
P
p
.001 w
.98643 .00576 m
.98643 .00951 L
s
P
[(kappa1)] 1.025 .00576 -1 0 Mshowa
p
.002 w
0 .00576 m
1 .00576 L
s
P
p
.002 w
.5 .05696 m
.50625 .05696 L
s
P
[(0.1)] .4875 .05696 1 0 Mshowa
p
.002 w
.5 .10817 m
.50625 .10817 L
s
P
[(0.2)] .4875 .10817 1 0 Mshowa
p
.002 w
.5 .15937 m
.50625 .15937 L
s
P
[(0.3)] .4875 .15937 1 0 Mshowa
p
.002 w
.5 .21057 m
.50625 .21057 L
s
P
[(0.4)] .4875 .21057 1 0 Mshowa
p
.001 w
.5 .016 m
.50375 .016 L
s
P
p
.001 w
.5 .02624 m
.50375 .02624 L
s
P
p
.001 w
.5 .03648 m
.50375 .03648 L
s
P
p
.001 w
.5 .04672 m
.50375 .04672 L
s
P
p
.001 w
.5 .0672 m
.50375 .0672 L
s
P
p
.001 w
.5 .07744 m
.50375 .07744 L
s
P
p
.001 w
.5 .08769 m
.50375 .08769 L
s
P
p
.001 w
.5 .09793 m
.50375 .09793 L
s
P
p
.001 w
.5 .11841 m
.50375 .11841 L
s
P
p
.001 w
.5 .12865 m
.50375 .12865 L
s
P
p
.001 w
.5 .13889 m
.50375 .13889 L
s
P
p
.001 w
.5 .14913 m
.50375 .14913 L
s
P
p
.001 w
.5 .16961 m
.50375 .16961 L
s
P
p
.001 w
.5 .17985 m
.50375 .17985 L
s
P
p
.001 w
.5 .19009 m
.50375 .19009 L
s
P
p
.001 w
.5 .20033 m
.50375 .20033 L
s
P
p
.001 w
.5 .22081 m
.50375 .22081 L
s
P
p
.001 w
.5 .23105 m
.50375 .23105 L
s
P
p
.001 w
.5 .2413 m
.50375 .2413 L
s
P
[(kappa2)] .5 .24194 0 -4 Mshowa
p
.002 w
.5 0 m
.5 .24194 L
s
P
P
0 0 m
1 0 L
1 .24194 L
0 .24194 L
closepath
clip
newpath
p
.004 w
.39247 .02112 m
.4232 .02112 L
.45392 .02112 L
.48464 .02112 L
.51536 .02112 L
.54608 .02112 L
.5768 .02112 L
.60753 .02112 L
.63825 .05184 L
.66897 .05184 L
.69969 .05184 L
.73041 .08257 L
.76114 .08257 L
.79186 .11329 L
.82258 .11329 L
.8533 .14401 L
.88402 .17473 L
.91475 .17473 L
.94547 .20545 L
.97619 .23618 L
.94547 .23618 L
.91475 .23618 L
.88402 .23618 L
.8533 .23618 L
.82258 .23618 L
.79186 .23618 L
.76114 .23618 L
.73041 .23618 L
.69969 .23618 L
.66897 .23618 L
.63825 .23618 L
.60753 .23618 L
.5768 .23618 L
.54608 .23618 L
.51536 .23618 L
.48464 .23618 L
.45392 .23618 L
.4232 .23618 L
.39247 .23618 L
.36175 .23618 L
.33103 .23618 L
.30031 .23618 L
.26959 .23618 L
.23886 .23618 L
.20814 .23618 L
.17742 .23618 L
.1467 .23618 L
.11598 .23618 L
.08525 .23618 L
.05453 .23618 L
Mistroke
.02381 .23618 L
.05453 .20545 L
.08525 .17473 L
.11598 .17473 L
.1467 .14401 L
.17742 .11329 L
.20814 .11329 L
.23886 .08257 L
.26959 .08257 L
.30031 .05184 L
.33103 .05184 L
.36175 .05184 L
.39247 .02112 L
Mfstroke
p
.008 w
.02381 .23618 Mdot
.05453 .20545 Mdot
.05453 .23618 Mdot
.08525 .17473 Mdot
.08525 .20545 Mdot
.08525 .23618 Mdot
.11598 .17473 Mdot
.11598 .20545 Mdot
.11598 .23618 Mdot
.1467 .14401 Mdot
.1467 .17473 Mdot
.1467 .20545 Mdot
.1467 .23618 Mdot
.17742 .11329 Mdot
.17742 .14401 Mdot
.17742 .17473 Mdot
.17742 .20545 Mdot
.17742 .23618 Mdot
.20814 .11329 Mdot
.20814 .14401 Mdot
.20814 .17473 Mdot
.20814 .20545 Mdot
.20814 .23618 Mdot
.23886 .08257 Mdot
.23886 .11329 Mdot
.23886 .14401 Mdot
.23886 .17473 Mdot
.23886 .20545 Mdot
.23886 .23618 Mdot
.26959 .08257 Mdot
.26959 .11329 Mdot
.26959 .14401 Mdot
.26959 .17473 Mdot
.26959 .20545 Mdot
.26959 .23618 Mdot
.30031 .05184 Mdot
.30031 .08257 Mdot
.30031 .11329 Mdot
.30031 .14401 Mdot
.30031 .17473 Mdot
.30031 .20545 Mdot
.30031 .23618 Mdot
.33103 .05184 Mdot
.33103 .08257 Mdot
.33103 .11329 Mdot
.33103 .14401 Mdot
.33103 .17473 Mdot
.33103 .20545 Mdot
.33103 .23618 Mdot
.36175 .05184 Mdot
.36175 .08257 Mdot
.36175 .11329 Mdot
.36175 .14401 Mdot
.36175 .17473 Mdot
.36175 .20545 Mdot
.36175 .23618 Mdot
.39247 .02112 Mdot
.39247 .05184 Mdot
.39247 .08257 Mdot
.39247 .11329 Mdot
.39247 .14401 Mdot
.39247 .17473 Mdot
.39247 .20545 Mdot
.39247 .23618 Mdot
.4232 .02112 Mdot
.4232 .05184 Mdot
.4232 .08257 Mdot
.4232 .11329 Mdot
.4232 .14401 Mdot
.4232 .17473 Mdot
.4232 .20545 Mdot
.4232 .23618 Mdot
.45392 .02112 Mdot
.45392 .05184 Mdot
.45392 .08257 Mdot
.45392 .11329 Mdot
.45392 .14401 Mdot
.45392 .17473 Mdot
.45392 .20545 Mdot
.45392 .23618 Mdot
.48464 .02112 Mdot
.48464 .05184 Mdot
.48464 .08257 Mdot
.48464 .11329 Mdot
.48464 .14401 Mdot
.48464 .17473 Mdot
.48464 .20545 Mdot
.48464 .23618 Mdot
.51536 .02112 Mdot
.51536 .05184 Mdot
.51536 .08257 Mdot
.51536 .11329 Mdot
.51536 .14401 Mdot
.51536 .17473 Mdot
.51536 .20545 Mdot
.51536 .23618 Mdot
.54608 .02112 Mdot
.54608 .05184 Mdot
.54608 .08257 Mdot
.54608 .11329 Mdot
.54608 .14401 Mdot
.54608 .17473 Mdot
.54608 .20545 Mdot
.54608 .23618 Mdot
.5768 .02112 Mdot
.5768 .05184 Mdot
.5768 .08257 Mdot
.5768 .11329 Mdot
.5768 .14401 Mdot
.5768 .17473 Mdot
.5768 .20545 Mdot
.5768 .23618 Mdot
.60753 .02112 Mdot
.60753 .05184 Mdot
.60753 .08257 Mdot
.60753 .11329 Mdot
.60753 .14401 Mdot
.60753 .17473 Mdot
.60753 .20545 Mdot
.60753 .23618 Mdot
.63825 .05184 Mdot
.63825 .08257 Mdot
.63825 .11329 Mdot
.63825 .14401 Mdot
.63825 .17473 Mdot
.63825 .20545 Mdot
.63825 .23618 Mdot
.66897 .05184 Mdot
.66897 .08257 Mdot
.66897 .11329 Mdot
.66897 .14401 Mdot
.66897 .17473 Mdot
.66897 .20545 Mdot
.66897 .23618 Mdot
.69969 .05184 Mdot
.69969 .08257 Mdot
.69969 .11329 Mdot
.69969 .14401 Mdot
.69969 .17473 Mdot
.69969 .20545 Mdot
.69969 .23618 Mdot
.73041 .08257 Mdot
.73041 .11329 Mdot
.73041 .14401 Mdot
.73041 .17473 Mdot
.73041 .20545 Mdot
.73041 .23618 Mdot
.76114 .08257 Mdot
.76114 .11329 Mdot
.76114 .14401 Mdot
.76114 .17473 Mdot
.76114 .20545 Mdot
.76114 .23618 Mdot
.79186 .11329 Mdot
.79186 .14401 Mdot
.79186 .17473 Mdot
.79186 .20545 Mdot
.79186 .23618 Mdot
.82258 .11329 Mdot
.82258 .14401 Mdot
.82258 .17473 Mdot
.82258 .20545 Mdot
.82258 .23618 Mdot
.8533 .14401 Mdot
.8533 .17473 Mdot
.8533 .20545 Mdot
.8533 .23618 Mdot
.88402 .17473 Mdot
.88402 .20545 Mdot
.88402 .23618 Mdot
.91475 .17473 Mdot
.91475 .20545 Mdot
.91475 .23618 Mdot
.94547 .20545 Mdot
.94547 .23618 Mdot
.97619 .23618 Mdot
P
P
% End of Graphics
MathPictureEnd
:[font = postscript; inactive; output; endGroup; BITMAP; PostScript; pictureLeft = 32; pictureTop = 0; pictureWidth = 516; pictureHeight = 136; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: .26331 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.500924 0.00626937 0.500924 [
[(-0.75)] .12431 .00627 0 2 Msboxa
[(-0.5)] .24954 .00627 0 2 Msboxa
[(-0.25)] .37477 .00627 0 2 Msboxa
[(0.25)] .62523 .00627 0 2 Msboxa
[(0.5)] .75046 .00627 0 2 Msboxa
[(0.75)] .87569 .00627 0 2 Msboxa
[(kappa1)] 1.025 .00627 -1 0 Msboxa
[(0.1)] .4875 .05636 1 0 Msboxa
[(0.2)] .4875 .10645 1 0 Msboxa
[(0.3)] .4875 .15655 1 0 Msboxa
[(0.4)] .4875 .20664 1 0 Msboxa
[(0.5)] .4875 .25673 1 0 Msboxa
[(kappa2)] .5 .26331 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .26431 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.12431 .00627 m
.12431 .01252 L
s
P
[(-0.75)] .12431 .00627 0 2 Mshowa
p
.002 w
.24954 .00627 m
.24954 .01252 L
s
P
[(-0.5)] .24954 .00627 0 2 Mshowa
p
.002 w
.37477 .00627 m
.37477 .01252 L
s
P
[(-0.25)] .37477 .00627 0 2 Mshowa
p
.002 w
.62523 .00627 m
.62523 .01252 L
s
P
[(0.25)] .62523 .00627 0 2 Mshowa
p
.002 w
.75046 .00627 m
.75046 .01252 L
s
P
[(0.5)] .75046 .00627 0 2 Mshowa
p
.002 w
.87569 .00627 m
.87569 .01252 L
s
P
[(0.75)] .87569 .00627 0 2 Mshowa
p
.001 w
.02412 .00627 m
.02412 .01002 L
s
P
p
.001 w
.04917 .00627 m
.04917 .01002 L
s
P
p
.001 w
.07421 .00627 m
.07421 .01002 L
s
P
p
.001 w
.09926 .00627 m
.09926 .01002 L
s
P
p
.001 w
.14935 .00627 m
.14935 .01002 L
s
P
p
.001 w
.1744 .00627 m
.1744 .01002 L
s
P
p
.001 w
.19945 .00627 m
.19945 .01002 L
s
P
p
.001 w
.22449 .00627 m
.22449 .01002 L
s
P
p
.001 w
.27458 .00627 m
.27458 .01002 L
s
P
p
.001 w
.29963 .00627 m
.29963 .01002 L
s
P
p
.001 w
.32468 .00627 m
.32468 .01002 L
s
P
p
.001 w
.34972 .00627 m
.34972 .01002 L
s
P
p
.001 w
.39982 .00627 m
.39982 .01002 L
s
P
p
.001 w
.42486 .00627 m
.42486 .01002 L
s
P
p
.001 w
.44991 .00627 m
.44991 .01002 L
s
P
p
.001 w
.47495 .00627 m
.47495 .01002 L
s
P
p
.001 w
.52505 .00627 m
.52505 .01002 L
s
P
p
.001 w
.55009 .00627 m
.55009 .01002 L
s
P
p
.001 w
.57514 .00627 m
.57514 .01002 L
s
P
p
.001 w
.60018 .00627 m
.60018 .01002 L
s
P
p
.001 w
.65028 .00627 m
.65028 .01002 L
s
P
p
.001 w
.67532 .00627 m
.67532 .01002 L
s
P
p
.001 w
.70037 .00627 m
.70037 .01002 L
s
P
p
.001 w
.72542 .00627 m
.72542 .01002 L
s
P
p
.001 w
.77551 .00627 m
.77551 .01002 L
s
P
p
.001 w
.80055 .00627 m
.80055 .01002 L
s
P
p
.001 w
.8256 .00627 m
.8256 .01002 L
s
P
p
.001 w
.85065 .00627 m
.85065 .01002 L
s
P
p
.001 w
.90074 .00627 m
.90074 .01002 L
s
P
p
.001 w
.92579 .00627 m
.92579 .01002 L
s
P
p
.001 w
.95083 .00627 m
.95083 .01002 L
s
P
p
.001 w
.97588 .00627 m
.97588 .01002 L
s
P
[(kappa1)] 1.025 .00627 -1 0 Mshowa
p
.002 w
0 .00627 m
1 .00627 L
s
P
p
.002 w
.5 .05636 m
.50625 .05636 L
s
P
[(0.1)] .4875 .05636 1 0 Mshowa
p
.002 w
.5 .10645 m
.50625 .10645 L
s
P
[(0.2)] .4875 .10645 1 0 Mshowa
p
.002 w
.5 .15655 m
.50625 .15655 L
s
P
[(0.3)] .4875 .15655 1 0 Mshowa
p
.002 w
.5 .20664 m
.50625 .20664 L
s
P
[(0.4)] .4875 .20664 1 0 Mshowa
p
.002 w
.5 .25673 m
.50625 .25673 L
s
P
[(0.5)] .4875 .25673 1 0 Mshowa
p
.001 w
.5 .01629 m
.50375 .01629 L
s
P
p
.001 w
.5 .02631 m
.50375 .02631 L
s
P
p
.001 w
.5 .03632 m
.50375 .03632 L
s
P
p
.001 w
.5 .04634 m
.50375 .04634 L
s
P
p
.001 w
.5 .06638 m
.50375 .06638 L
s
P
p
.001 w
.5 .0764 m
.50375 .0764 L
s
P
p
.001 w
.5 .08642 m
.50375 .08642 L
s
P
p
.001 w
.5 .09644 m
.50375 .09644 L
s
P
p
.001 w
.5 .11647 m
.50375 .11647 L
s
P
p
.001 w
.5 .12649 m
.50375 .12649 L
s
P
p
.001 w
.5 .13651 m
.50375 .13651 L
s
P
p
.001 w
.5 .14653 m
.50375 .14653 L
s
P
p
.001 w
.5 .16656 m
.50375 .16656 L
s
P
p
.001 w
.5 .17658 m
.50375 .17658 L
s
P
p
.001 w
.5 .1866 m
.50375 .1866 L
s
P
p
.001 w
.5 .19662 m
.50375 .19662 L
s
P
p
.001 w
.5 .21666 m
.50375 .21666 L
s
P
p
.001 w
.5 .22668 m
.50375 .22668 L
s
P
p
.001 w
.5 .23669 m
.50375 .23669 L
s
P
p
.001 w
.5 .24671 m
.50375 .24671 L
s
P
[(kappa2)] .5 .26331 0 -4 Mshowa
p
.002 w
.5 0 m
.5 .26331 L
s
P
P
0 0 m
1 0 L
1 .26331 L
0 .26331 L
closepath
clip
newpath
p
.004 w
.3934 .01754 m
.42486 .01097 L
.45492 .00909 L
.48497 .00721 L
.51503 .00721 L
.54508 .00909 L
.57514 .01097 L
.60801 .01848 L
.65685 .02975 L
.6653 .03163 L
.70193 .04478 L
.74326 .06356 L
.76392 .07295 L
.80149 .0955 L
.82028 .10677 L
.85785 .12931 L
.89166 .15561 L
.90857 .16876 L
.9405 .19693 L
.97619 .23168 L
.9358 .25704 L
.90575 .25704 L
.87569 .25704 L
.84564 .25704 L
.81558 .25704 L
.78553 .25704 L
.75547 .25704 L
.72542 .25704 L
.69536 .25704 L
.6653 .25704 L
.63525 .25704 L
.60519 .25704 L
.57514 .25704 L
.54508 .25704 L
.51503 .25704 L
.48497 .25704 L
.45492 .25704 L
.42486 .25704 L
.39481 .25704 L
.36475 .25704 L
.3347 .25704 L
.30464 .25704 L
.27458 .25704 L
.24453 .25704 L
.21447 .25704 L
.18442 .25704 L
.15436 .25704 L
.12431 .25704 L
.09425 .25704 L
.0642 .25704 L
Mistroke
.02381 .23168 L
.0595 .19693 L
.09143 .16876 L
.10834 .15561 L
.14215 .12931 L
.17972 .10677 L
.19851 .0955 L
.23608 .07295 L
.25674 .06356 L
.29807 .04478 L
.3347 .03163 L
.34315 .02975 L
.3934 .01754 L
Mfstroke
p
.008 w
.03414 .23168 Mdot
.0642 .20163 Mdot
.0642 .23168 Mdot
.09425 .17157 Mdot
.09425 .20163 Mdot
.09425 .23168 Mdot
.12431 .17157 Mdot
.12431 .20163 Mdot
.12431 .23168 Mdot
.15436 .14152 Mdot
.15436 .17157 Mdot
.15436 .20163 Mdot
.15436 .23168 Mdot
.18442 .11146 Mdot
.18442 .14152 Mdot
.18442 .17157 Mdot
.18442 .20163 Mdot
.18442 .23168 Mdot
.21447 .11146 Mdot
.21447 .14152 Mdot
.21447 .17157 Mdot
.21447 .20163 Mdot
.21447 .23168 Mdot
.24453 .08141 Mdot
.24453 .11146 Mdot
.24453 .14152 Mdot
.24453 .17157 Mdot
.24453 .20163 Mdot
.24453 .23168 Mdot
.27458 .08141 Mdot
.27458 .11146 Mdot
.27458 .14152 Mdot
.27458 .17157 Mdot
.27458 .20163 Mdot
.27458 .23168 Mdot
.30464 .05135 Mdot
.30464 .08141 Mdot
.30464 .11146 Mdot
.30464 .14152 Mdot
.30464 .17157 Mdot
.30464 .20163 Mdot
.30464 .23168 Mdot
.3347 .05135 Mdot
.3347 .08141 Mdot
.3347 .11146 Mdot
.3347 .14152 Mdot
.3347 .17157 Mdot
.3347 .20163 Mdot
.3347 .23168 Mdot
.36475 .05135 Mdot
.36475 .08141 Mdot
.36475 .11146 Mdot
.36475 .14152 Mdot
.36475 .17157 Mdot
.36475 .20163 Mdot
.36475 .23168 Mdot
.39481 .0213 Mdot
.39481 .05135 Mdot
.39481 .08141 Mdot
.39481 .11146 Mdot
.39481 .14152 Mdot
.39481 .17157 Mdot
.39481 .20163 Mdot
.39481 .23168 Mdot
.42486 .0213 Mdot
.42486 .05135 Mdot
.42486 .08141 Mdot
.42486 .11146 Mdot
.42486 .14152 Mdot
.42486 .17157 Mdot
.42486 .20163 Mdot
.42486 .23168 Mdot
.45492 .0213 Mdot
.45492 .05135 Mdot
.45492 .08141 Mdot
.45492 .11146 Mdot
.45492 .14152 Mdot
.45492 .17157 Mdot
.45492 .20163 Mdot
.45492 .23168 Mdot
.48497 .0213 Mdot
.48497 .05135 Mdot
.48497 .08141 Mdot
.48497 .11146 Mdot
.48497 .14152 Mdot
.48497 .17157 Mdot
.48497 .20163 Mdot
.48497 .23168 Mdot
.51503 .0213 Mdot
.51503 .05135 Mdot
.51503 .08141 Mdot
.51503 .11146 Mdot
.51503 .14152 Mdot
.51503 .17157 Mdot
.51503 .20163 Mdot
.51503 .23168 Mdot
.54508 .0213 Mdot
.54508 .05135 Mdot
.54508 .08141 Mdot
.54508 .11146 Mdot
.54508 .14152 Mdot
.54508 .17157 Mdot
.54508 .20163 Mdot
.54508 .23168 Mdot
.57514 .0213 Mdot
.57514 .05135 Mdot
.57514 .08141 Mdot
.57514 .11146 Mdot
.57514 .14152 Mdot
.57514 .17157 Mdot
.57514 .20163 Mdot
.57514 .23168 Mdot
.60519 .0213 Mdot
.60519 .05135 Mdot
.60519 .08141 Mdot
.60519 .11146 Mdot
.60519 .14152 Mdot
.60519 .17157 Mdot
.60519 .20163 Mdot
.60519 .23168 Mdot
.63525 .05135 Mdot
.63525 .08141 Mdot
.63525 .11146 Mdot
.63525 .14152 Mdot
.63525 .17157 Mdot
.63525 .20163 Mdot
.63525 .23168 Mdot
.6653 .05135 Mdot
.6653 .08141 Mdot
.6653 .11146 Mdot
.6653 .14152 Mdot
.6653 .17157 Mdot
.6653 .20163 Mdot
.6653 .23168 Mdot
.69536 .05135 Mdot
.69536 .08141 Mdot
.69536 .11146 Mdot
.69536 .14152 Mdot
.69536 .17157 Mdot
.69536 .20163 Mdot
.69536 .23168 Mdot
.72542 .08141 Mdot
.72542 .11146 Mdot
.72542 .14152 Mdot
.72542 .17157 Mdot
.72542 .20163 Mdot
.72542 .23168 Mdot
.75547 .08141 Mdot
.75547 .11146 Mdot
.75547 .14152 Mdot
.75547 .17157 Mdot
.75547 .20163 Mdot
.75547 .23168 Mdot
.78553 .11146 Mdot
.78553 .14152 Mdot
.78553 .17157 Mdot
.78553 .20163 Mdot
.78553 .23168 Mdot
.81558 .11146 Mdot
.81558 .14152 Mdot
.81558 .17157 Mdot
.81558 .20163 Mdot
.81558 .23168 Mdot
.84564 .14152 Mdot
.84564 .17157 Mdot
.84564 .20163 Mdot
.84564 .23168 Mdot
.87569 .17157 Mdot
.87569 .20163 Mdot
.87569 .23168 Mdot
.90575 .17157 Mdot
.90575 .20163 Mdot
.90575 .23168 Mdot
.9358 .20163 Mdot
.9358 .23168 Mdot
.96586 .23168 Mdot
P
P
% End of Graphics
MathPictureEnd
:[font = subsection; inactive; ]
Example 2
:[font = input; nowordwrap; ]

stab2[0.0, 3.0, 0.0, 1.5, 10, 5, 1, 0.003, Allen]

:[font = postscript; inactive; output; BITMAP; PostScript; pictureLeft = 100; pictureTop = 0; pictureWidth = 300; pictureHeight = 149; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: .49728 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.315244 0.012579 0.315244 [
[(0.5)] .18143 .01258 0 2 Msboxa
[(1)] .33905 .01258 0 2 Msboxa
[(1.5)] .49668 .01258 0 2 Msboxa
[(2)] .6543 .01258 0 2 Msboxa
[(2.5)] .81192 .01258 0 2 Msboxa
[(3)] .96954 .01258 0 2 Msboxa
[(kappa1)] 1.025 .01258 -1 0 Msboxa
[(0.2)] .01131 .07563 1 0 Msboxa
[(0.4)] .01131 .13868 1 0 Msboxa
[(0.6)] .01131 .20173 1 0 Msboxa
[(0.8)] .01131 .26477 1 0 Msboxa
[(1)] .01131 .32782 1 0 Msboxa
[(1.2)] .01131 .39087 1 0 Msboxa
[(1.4)] .01131 .45392 1 0 Msboxa
[(kappa2)] .02381 .49728 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .49828 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.18143 .01258 m
.18143 .01883 L
s
P
[(0.5)] .18143 .01258 0 2 Mshowa
p
.002 w
.33905 .01258 m
.33905 .01883 L
s
P
[(1)] .33905 .01258 0 2 Mshowa
p
.002 w
.49668 .01258 m
.49668 .01883 L
s
P
[(1.5)] .49668 .01258 0 2 Mshowa
p
.002 w
.6543 .01258 m
.6543 .01883 L
s
P
[(2)] .6543 .01258 0 2 Mshowa
p
.002 w
.81192 .01258 m
.81192 .01883 L
s
P
[(2.5)] .81192 .01258 0 2 Mshowa
p
.002 w
.96954 .01258 m
.96954 .01883 L
s
P
[(3)] .96954 .01258 0 2 Mshowa
p
.001 w
.05533 .01258 m
.05533 .01633 L
s
P
p
.001 w
.08686 .01258 m
.08686 .01633 L
s
P
p
.001 w
.11838 .01258 m
.11838 .01633 L
s
P
p
.001 w
.14991 .01258 m
.14991 .01633 L
s
P
p
.001 w
.21296 .01258 m
.21296 .01633 L
s
P
p
.001 w
.24448 .01258 m
.24448 .01633 L
s
P
p
.001 w
.276 .01258 m
.276 .01633 L
s
P
p
.001 w
.30753 .01258 m
.30753 .01633 L
s
P
p
.001 w
.37058 .01258 m
.37058 .01633 L
s
P
p
.001 w
.4021 .01258 m
.4021 .01633 L
s
P
p
.001 w
.43363 .01258 m
.43363 .01633 L
s
P
p
.001 w
.46515 .01258 m
.46515 .01633 L
s
P
p
.001 w
.5282 .01258 m
.5282 .01633 L
s
P
p
.001 w
.55972 .01258 m
.55972 .01633 L
s
P
p
.001 w
.59125 .01258 m
.59125 .01633 L
s
P
p
.001 w
.62277 .01258 m
.62277 .01633 L
s
P
p
.001 w
.68582 .01258 m
.68582 .01633 L
s
P
p
.001 w
.71735 .01258 m
.71735 .01633 L
s
P
p
.001 w
.74887 .01258 m
.74887 .01633 L
s
P
p
.001 w
.78039 .01258 m
.78039 .01633 L
s
P
p
.001 w
.84344 .01258 m
.84344 .01633 L
s
P
p
.001 w
.87497 .01258 m
.87497 .01633 L
s
P
p
.001 w
.90649 .01258 m
.90649 .01633 L
s
P
p
.001 w
.93802 .01258 m
.93802 .01633 L
s
P
[(kappa1)] 1.025 .01258 -1 0 Mshowa
p
.002 w
0 .01258 m
1 .01258 L
s
P
p
.002 w
.02381 .07563 m
.03006 .07563 L
s
P
[(0.2)] .01131 .07563 1 0 Mshowa
p
.002 w
.02381 .13868 m
.03006 .13868 L
s
P
[(0.4)] .01131 .13868 1 0 Mshowa
p
.002 w
.02381 .20173 m
.03006 .20173 L
s
P
[(0.6)] .01131 .20173 1 0 Mshowa
p
.002 w
.02381 .26477 m
.03006 .26477 L
s
P
[(0.8)] .01131 .26477 1 0 Mshowa
p
.002 w
.02381 .32782 m
.03006 .32782 L
s
P
[(1)] .01131 .32782 1 0 Mshowa
p
.002 w
.02381 .39087 m
.03006 .39087 L
s
P
[(1.2)] .01131 .39087 1 0 Mshowa
p
.002 w
.02381 .45392 m
.03006 .45392 L
s
P
[(1.4)] .01131 .45392 1 0 Mshowa
p
.001 w
.02381 .02519 m
.02756 .02519 L
s
P
p
.001 w
.02381 .0378 m
.02756 .0378 L
s
P
p
.001 w
.02381 .05041 m
.02756 .05041 L
s
P
p
.001 w
.02381 .06302 m
.02756 .06302 L
s
P
p
.001 w
.02381 .08824 m
.02756 .08824 L
s
P
p
.001 w
.02381 .10085 m
.02756 .10085 L
s
P
p
.001 w
.02381 .11346 m
.02756 .11346 L
s
P
p
.001 w
.02381 .12607 m
.02756 .12607 L
s
P
p
.001 w
.02381 .15129 m
.02756 .15129 L
s
P
p
.001 w
.02381 .1639 m
.02756 .1639 L
s
P
p
.001 w
.02381 .17651 m
.02756 .17651 L
s
P
p
.001 w
.02381 .18912 m
.02756 .18912 L
s
P
p
.001 w
.02381 .21433 m
.02756 .21433 L
s
P
p
.001 w
.02381 .22694 m
.02756 .22694 L
s
P
p
.001 w
.02381 .23955 m
.02756 .23955 L
s
P
p
.001 w
.02381 .25216 m
.02756 .25216 L
s
P
p
.001 w
.02381 .27738 m
.02756 .27738 L
s
P
p
.001 w
.02381 .28999 m
.02756 .28999 L
s
P
p
.001 w
.02381 .3026 m
.02756 .3026 L
s
P
p
.001 w
.02381 .31521 m
.02756 .31521 L
s
P
p
.001 w
.02381 .34043 m
.02756 .34043 L
s
P
p
.001 w
.02381 .35304 m
.02756 .35304 L
s
P
p
.001 w
.02381 .36565 m
.02756 .36565 L
s
P
p
.001 w
.02381 .37826 m
.02756 .37826 L
s
P
p
.001 w
.02381 .40348 m
.02756 .40348 L
s
P
p
.001 w
.02381 .41609 m
.02756 .41609 L
s
P
p
.001 w
.02381 .4287 m
.02756 .4287 L
s
P
p
.001 w
.02381 .44131 m
.02756 .44131 L
s
P
p
.001 w
.02381 .46653 m
.02756 .46653 L
s
P
p
.001 w
.02381 .47914 m
.02756 .47914 L
s
P
p
.001 w
.02381 .49175 m
.02756 .49175 L
s
P
[(kappa2)] .02381 .49728 0 -4 Mshowa
p
.002 w
.02381 0 m
.02381 .49728 L
s
P
P
0 0 m
1 0 L
1 .49728 L
0 .49728 L
closepath
clip
newpath
p
.004 w
.04745 .03585 m
.16567 .01184 L
.26024 .01184 L
.35482 .01184 L
.46343 .04583 L
.59346 .10494 L
.65701 .13597 L
.78557 .19655 L
.84911 .22759 L
.97619 .28965 L
.96954 .48544 L
.82768 .48544 L
.73311 .48544 L
.63853 .48544 L
.54396 .48544 L
.44939 .48544 L
.35482 .48544 L
.26024 .48544 L
.16567 .48544 L
.02381 .48544 L
.02381 .34358 L
.02381 .24901 L
.02381 .15444 L
.04745 .03585 L
s
p
.008 w
.0711 .05987 Mdot
.0711 .15444 Mdot
.0711 .24901 Mdot
.0711 .34358 Mdot
.0711 .43816 Mdot
.16567 .05987 Mdot
.16567 .15444 Mdot
.16567 .24901 Mdot
.16567 .34358 Mdot
.16567 .43816 Mdot
.26024 .05987 Mdot
.26024 .15444 Mdot
.26024 .24901 Mdot
.26024 .34358 Mdot
.26024 .43816 Mdot
.35482 .05987 Mdot
.35482 .15444 Mdot
.35482 .24901 Mdot
.35482 .34358 Mdot
.35482 .43816 Mdot
.44939 .05987 Mdot
.44939 .15444 Mdot
.44939 .24901 Mdot
.44939 .34358 Mdot
.44939 .43816 Mdot
.54396 .15444 Mdot
.54396 .24901 Mdot
.54396 .34358 Mdot
.54396 .43816 Mdot
.63853 .15444 Mdot
.63853 .24901 Mdot
.63853 .34358 Mdot
.63853 .43816 Mdot
.73311 .24901 Mdot
.73311 .34358 Mdot
.73311 .43816 Mdot
.82768 .24901 Mdot
.82768 .34358 Mdot
.82768 .43816 Mdot
.92225 .34358 Mdot
.92225 .43816 Mdot
P
P
% End of Graphics
MathPictureEnd
:[font = subsection; inactive; ]
Example 3
:[font = input; nowordwrap; ]

stab2[0.0, 3.0, 0.0, 1.5, 20, 10, 1, 0.003, Allen]

:[font = subsection; inactive; ]
Example 4
:[font = input; nowordwrap; ]

stab2[0.0,1.2,0.0,1.2,5,5, 2, 0.005, MacCormack]

:[font = postscript; inactive; output; BITMAP; PostScript; pictureLeft = 188; pictureTop = 0; pictureWidth = 217; pictureHeight = 217; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0950506 0.999875 0.0950506 0.999875 [
[(0.2)] .29503 .09505 0 2 Msboxa
[(0.4)] .495 .09505 0 2 Msboxa
[(0.6)] .69498 .09505 0 2 Msboxa
[(0.8)] .89495 .09505 0 2 Msboxa
[(kappa1)] 1.025 .09505 -1 0 Msboxa
[(0.2)] .08255 .29503 1 0 Msboxa
[(0.4)] .08255 .495 1 0 Msboxa
[(0.6)] .08255 .69498 1 0 Msboxa
[(0.8)] .08255 .89495 1 0 Msboxa
[(kappa2)] .09505 1 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.29503 .09505 m
.29503 .1013 L
s
P
[(0.2)] .29503 .09505 0 2 Mshowa
p
.002 w
.495 .09505 m
.495 .1013 L
s
P
[(0.4)] .495 .09505 0 2 Mshowa
p
.002 w
.69498 .09505 m
.69498 .1013 L
s
P
[(0.6)] .69498 .09505 0 2 Mshowa
p
.002 w
.89495 .09505 m
.89495 .1013 L
s
P
[(0.8)] .89495 .09505 0 2 Mshowa
p
.001 w
.13505 .09505 m
.13505 .0988 L
s
P
p
.001 w
.17504 .09505 m
.17504 .0988 L
s
P
p
.001 w
.21504 .09505 m
.21504 .0988 L
s
P
p
.001 w
.25503 .09505 m
.25503 .0988 L
s
P
p
.001 w
.33502 .09505 m
.33502 .0988 L
s
P
p
.001 w
.37502 .09505 m
.37502 .0988 L
s
P
p
.001 w
.41501 .09505 m
.41501 .0988 L
s
P
p
.001 w
.45501 .09505 m
.45501 .0988 L
s
P
p
.001 w
.535 .09505 m
.535 .0988 L
s
P
p
.001 w
.57499 .09505 m
.57499 .0988 L
s
P
p
.001 w
.61499 .09505 m
.61499 .0988 L
s
P
p
.001 w
.65498 .09505 m
.65498 .0988 L
s
P
p
.001 w
.73497 .09505 m
.73497 .0988 L
s
P
p
.001 w
.77497 .09505 m
.77497 .0988 L
s
P
p
.001 w
.81496 .09505 m
.81496 .0988 L
s
P
p
.001 w
.85496 .09505 m
.85496 .0988 L
s
P
p
.001 w
.05506 .09505 m
.05506 .0988 L
s
P
p
.001 w
.01506 .09505 m
.01506 .0988 L
s
P
p
.001 w
.93495 .09505 m
.93495 .0988 L
s
P
p
.001 w
.97494 .09505 m
.97494 .0988 L
s
P
[(kappa1)] 1.025 .09505 -1 0 Mshowa
p
.002 w
0 .09505 m
1 .09505 L
s
P
p
.002 w
.09505 .29503 m
.1013 .29503 L
s
P
[(0.2)] .08255 .29503 1 0 Mshowa
p
.002 w
.09505 .495 m
.1013 .495 L
s
P
[(0.4)] .08255 .495 1 0 Mshowa
p
.002 w
.09505 .69498 m
.1013 .69498 L
s
P
[(0.6)] .08255 .69498 1 0 Mshowa
p
.002 w
.09505 .89495 m
.1013 .89495 L
s
P
[(0.8)] .08255 .89495 1 0 Mshowa
p
.001 w
.09505 .13505 m
.0988 .13505 L
s
P
p
.001 w
.09505 .17504 m
.0988 .17504 L
s
P
p
.001 w
.09505 .21504 m
.0988 .21504 L
s
P
p
.001 w
.09505 .25503 m
.0988 .25503 L
s
P
p
.001 w
.09505 .33502 m
.0988 .33502 L
s
P
p
.001 w
.09505 .37502 m
.0988 .37502 L
s
P
p
.001 w
.09505 .41501 m
.0988 .41501 L
s
P
p
.001 w
.09505 .45501 m
.0988 .45501 L
s
P
p
.001 w
.09505 .535 m
.0988 .535 L
s
P
p
.001 w
.09505 .57499 m
.0988 .57499 L
s
P
p
.001 w
.09505 .61499 m
.0988 .61499 L
s
P
p
.001 w
.09505 .65498 m
.0988 .65498 L
s
P
p
.001 w
.09505 .73497 m
.0988 .73497 L
s
P
p
.001 w
.09505 .77497 m
.0988 .77497 L
s
P
p
.001 w
.09505 .81496 m
.0988 .81496 L
s
P
p
.001 w
.09505 .85496 m
.0988 .85496 L
s
P
p
.001 w
.09505 .05506 m
.0988 .05506 L
s
P
p
.001 w
.09505 .01506 m
.0988 .01506 L
s
P
p
.001 w
.09505 .93495 m
.0988 .93495 L
s
P
p
.001 w
.09505 .97494 m
.0988 .97494 L
s
P
[(kappa2)] .09505 1 0 -4 Mshowa
p
.002 w
.09505 0 m
.09505 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
.004 w
.11192 .11192 m
.45501 .03131 L
.69498 .02381 L
.97619 .21504 L
.71372 .47375 L
.47375 .71372 L
.21504 .97619 L
.02381 .69498 L
.03131 .45501 L
.11192 .11192 L
s
p
.008 w
.21504 .21504 Mdot
.21504 .45501 Mdot
.21504 .69498 Mdot
.21504 .93495 Mdot
.45501 .21504 Mdot
.45501 .45501 Mdot
.45501 .69498 Mdot
.69498 .21504 Mdot
.69498 .45501 Mdot
.93495 .21504 Mdot
P
P
% End of Graphics
MathPictureEnd
:[font = subsection; inactive; ]
Example 5
:[font = input; nowordwrap; ]

stab2[-1.2,1.2,-1.2,1.2,30,30,2, 0.005, MacCormack]

:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]

    The following data are printed out in the process of the work of the program:

1. The left-hand side of the difference equation sc = 0 under consideration.

2. The symbolic expression for the amplification factor lambda of a given
    difference scheme.

3. The real part Re(lambda) and imaginary part Im(lambda) of the amplificat-
     ion factor lambda.

4. The values of the binary function fbin[[j,k]] for all the nodes (p,q) of an
     uniform grid in the (kappa1,kappa2) plane. The value fbin[[j,k]] = 1
     corresponds to a stable point of difference scheme.

5. The table of the values of sin(xj) and cos(xj) in the nspg nodes of an
     uniform grid in the interval [0, 2Pi).

6. The area of stability region.

7. The number of the detected contours of the stability region boundary.

8. The length of each contour as the number of (p,q) nodes belonging to
     the contour.

9. The x- and y-coordinates of points of each contour.

10. The values of angles (in radians) corresponding to nine principal 
       directions. These values are used in the Pavlidis' algorithm of 
       contour tracing.

11. The stability region with its interior marked by stable points.

12. The refined stability region boundaries together with the interior of 
       the stability region marked by stable points.
^*)