(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Arial", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Arial", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Arial", 14, L0, center, nohscroll, bold;
	fontset = section, "Arial", 14, L0, bold, grayBox;
	fontset = subsection, "Arial", 12, L0, bold, blackBox;
	fontset = subsubsection, "Arial", 10, L0, bold, whiteBox;
	fontset = text, "Arial", 12, L0;
	fontset = smalltext, "Arial", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65280;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Arial", 10, L0, nohscroll, italic, B65280;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Arial", 10, L0, nohscroll;
	fontset = clipboard, "Arial", 12, L0, nohscroll;
	fontset = completions, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Arial", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Arial", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Arial", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = title; inactive; nohscroll; center; ]
The TVD Method
:[font = name; inactive; nohscroll; ]

                                       Victor G. Ganzha and Evgenii V. Vorozhtsov
:[font = section; inactive; ]
Impressum
:[font = special4; inactive; nowordwrap; nohscroll; ]

This Mathematica-Notebook is part of the book entitled
                                     V.G.Ganzha and E.V.Vorozhtsov
   Numerical Solutions For Partial Differential Equations: Problem Solving
   Using Mathematica.   CRC Press, Boca Raton, Ann Arbor, 1996.
:[font = subsection; inactive; ]
Copyright
:[font = special4; inactive; nowordwrap; nohscroll; ]

Numerical Solutions For Partial Differential Equations: Problem Solving
Using Mathematica.   CRC Press, Boca Raton, Ann Arbor, 1996.

:[font = section; inactive; ]
General Description
:[font = special4; inactive; nowordwrap; nohscroll; ]

The program tvd1.ma which follows below implements the computation 
by the  explicit TVD difference scheme (2.7.8)-(2.7.13) under the initial 
condition of the semi-ellipse pulse form.  A more detailed description
of the program can be found in Section 2.7 of the above book.

:[font = section; inactive; ]
User's Guide
:[font = special4; inactive; nowordwrap; nohscroll; ]

Load and compile the program file beginning with the line
:[font = input; nowordwrap; ]

Clear[tvd, minmod, uinit];
:[font = section; inactive; ]
Program Listing
:[font = input; nowordwrap; ]

Clear[tvd, minmod, uinit];

minmod[r_,m_]:=Sign[r]*Max[0,Min[Abs[r],m*Sign[r]]];

uinit[x_,ul_,ur_,jf0_,h_]:=
( xc0 = jf0*h; y1 = (x - xc0)/(15*h);
z = If[Abs[x-xc0] <= 15*h, ul+ur*Sqrt[1-y1*y1], ul]; z );

tvd[a_,a1_,b1_,jf0_,ul_,ur_,M_, cap_, beta_, bfl_, Npic_]:=
(

(* uj = the difference solution at time level n,
   up = the difference solution at time level n + 1 -- *)
If[beta != 1, bflmax =1.00001*(3-beta)/(1-beta)];
If[beta != 1 && (bfl>bflmax||bfl<1),
   Print["bfl = ", bfl];
Print["The coefficient bfl is outside the ",
      "allowed interval"];
     Interrupt[ ]];
     M1 = M + 1; h = (b1 - a1)/M1;  M2 = M - 1;
       dt = cap*h/a;   xf0 = a1 + jf0*h;
	  Tmax = (b1 - 5.0*h - xf0)/a;
uj = Table[ul, {j,0,M}];  up = uj;
                      ug = Table[ur, {j, 1, M1}];
          tnt = Table[Tmax, {j, Npic}];
(* - Tmax is the right end of the time interval - *)
         Nt = Max[Floor[Tmax/dt],1];
       nplot=Max[Floor[Nt/Npic], 1]; 
(* -- The solution graphs u(x, tk) will be given at
      tk = (k-1)*nplot*dt, k = 1,...,Npic  ----- *)
   um = ul + ur;   
Print["um = ",um, ", Nmax = ", Nt];
  t= 0.0;  n2 = nplot;  nt = 1;  tnt[[1]] = 0.0;
(* -- Computation of the initial values u(xj,0)
                               at grid points -- *)
 Do[ xj = a1 + (j + 0.5)*h;
   uj[[j]] = uinit[xj, ul, ur, jf0, h], {j, 0, M}];
(* - Generation of the two-dimensional table ut - *)
      ut = Table[ur, {k, 1, Npic}, {j, 1, M1}];
(* --- Storing the initial profile u(x,0) in 
     ut[[j, 1]] ------------------------------- *)
       Do[ ut[[1,j + 1]] = uj[[j]], {j, 0, M}];
(* --- Begin of the Do-loop for time steps ---- *)
        Do[
            t = t + dt;
            Print["n = ", n, ", t = ", t];
(* --- Do-loop over grid nodes on the x-axis --- *)
      fxr = ul;
            Do[ fxl = fxr; unj = uj[[j]];
(* The TVD scheme (2.7.8)-(2.7.13) for equation 
   (2.1.1) *)
djpun = uj[[j+1]] - unj; djmun = unj - uj[[j - 1]];
        d1un = minmod[djpun, bfl*djmun];
          d2un = minmod[djmun, bfl*djpun];
 fxr = unj + ((1 + beta)*d1un + (1 - beta)*d2un)/4;
 up[[j]] = uj[[j]] - cap*(fxr - fxl), {j, 1, M2 }];
(* ---- The boundary condition on the left 
    boundary x = a1 -------------------------- *)
                  up[[0]] = ul;
(* ---- The boundary condition on the right 
    boundary x= b1 --------------------------- *)
up[[M]]=((uj[[M]]+uj[[M-1]]-up[[M-1]])+
     cap*(uj[[M-1]]+up[[M-1]]-uj[[M]]))/(1 + cap);
(* -------- Exchange of the lists ------------ *)
                  uj = up;

(* -------- Find Max[Abs[u(j,n+1) - um] ------ *)
               umax = 0.0;
Do[ y=Abs[uj[[j]]-um]; umax=If[y>umax, y, umax],
        {j, 0, M, 1}];
           If[n == n2, Goto[store]];
  If[umax > 2.*um, Goto [endt], Goto [endsteps]];
Label[endt]; Tmax = t;
Label[store]; n2 = n2 + nplot;
      nt = nt + 1;
                   If[nt <= Npic,
      tnt[[nt]] = t;
(* - Storing the solution u(x,t) in ut[[nt,j]] - *)
      Do[ ut[[nt, j + 1]] = uj[[j]], {j, 0, M}]];
      If[umax > 2.0*um||nt == Npic, Break[]];
 Label[endsteps],
(* ---------- End of the Do-loop in n ---------- *)
              {n, 0, Nt, 1}];
(* -- Plotting the solution graphs for several
                            moments of time ---- *)
(* ---- Determining min(ut) and max(ut) -------- *)
            umin = 10^6;  umax = -umin;
       nt = If[nt > Npic, Npic, nt];
      Do[
          y = ut[[k, j]];
            umin = If[y < umin, y, umin];
              umax = If[y > umax, y, umax],
         {k, nt}, {j, M1}];
    Print["umin = ", umin, ", umax = ", umax];

(* - Storing the pictures in the elements mt[[j]],
                              j = 1,...,Npic -- *)
     umin = If[umin > 0, 0.0, umin];
     umax = If[umax < 0, 0.0, umax]; mt = {};
     Do[ ug = ut[[j]];  t  = tnt[[j]];
(* -- Determining the values of mlpl and mrpl -- *)
  Do[uk = ug[[k]];
If[Abs[uk-ul]>0.0001, mlpl=k; Break[]], {k, M}];
     mlpl = Max[1, mlpl - 5];
 If[j==1, mlpl=1]; xorg=mlpl; uminpl = Min[0,umin];
        mrpl = Min[mlpl + 80, M1]; xplmax = mrpl;
  xtab = {}; ytbnum={}; ytbex={}; jxmax=mrpl-mlpl + 1;
  Do[j3 = j2 + mlpl - 1; xj = j3;
  unum = ug[[j3]]; AppendTo[xtab, xj]; 
                AppendTo[ytbnum,unum],{j2, jxmax}];
  xytab = Table[{xtab[[j]], ytbnum[[j]]}, {j, jxmax}];
     Print["The solution graph at t = ", t];
     mt1 = ListPlot[xytab,
         PlotStyle -> {RGBColor[0,1,0]},      
         AxesLabel -> {"x", "u"},
         PlotJoined -> True,  
         AxesOrigin -> {xorg, 0},
     PlotRange -> {{xorg, xplmax}, {uminpl, umax}},
     DisplayFunction -> Identity];
(* - Plotting the curves of the exact solution - *)
              uex = { };
 Do[xj = a1 + (j2 - 0.5)*h;
   zj = xj - a*t; uj2 = uinit[zj, ul, ur, jf0, h];
                       AppendTo[uex, uj2],
        {j2, M1}];

  Do[j3 = j2 + mlpl - 1;
uj2 = uex[[j3]]; AppendTo[ytbex,uj2],{j2, jxmax}];
xytab = Table[{xtab[[j]], ytbex[[j]]}, {j, jxmax}];

    mt2 = ListPlot[xytab,
            PlotJoined -> True,
            AxesOrigin -> {xorg, 0},
            PlotStyle -> {Dashing[{0.04}]},
     PlotRange -> {{xorg, xplmax}, {uminpl, umax}},
     DisplayFunction -> Identity];
mt3=Show[mt1,mt2,DisplayFunction->$DisplayFunction];
     AppendTo[mt, mt3],
                       {j, nt}];
If[nt == 2,
 gr = Show[GraphicsArray[{mt[[1]], mt[[2]]}]]  ];
If[nt == 3,
 gr = Show[GraphicsArray[{{mt[[1]],mt[[2]]}, 
                          {mt[[3]]}}]]];
If[nt == 4,
 gr = Show[GraphicsArray[{{mt[[1]], mt[[2]]},
                          {mt[[3]], mt[[4]]}}]] ];
If[nt == 5,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]]},
     {mt[[4]], mt[[5]]}}]] ];
If[nt == 6,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]]},
     {mt[[4]], mt[[5]], mt[[6]]}}]] ];
If[nt == 7,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]], mt[[4]]},
     {mt[[5]], mt[[6]], mt[[7]]}}]] ];
If[nt >= 8,
 gr = Show[GraphicsArray[{
     {mt[[1]], mt[[2]], mt[[3]], mt[[4]]},
     {mt[[5]], mt[[6]], mt[[7]], mt[[8]]}}]] ];
     Display["fig2_15", gr]; 
(* ---------- End of the program ------------- *)
           )


:[font = section; inactive; ]
Parameters Used in Program tvd1.ma
:[font = special4; inactive; nowordwrap; nohscroll; ]
____________________________________________________
 Parameter                         Description
____________________________________________________
a                        the advection speed in eqn (2.1.1), a > 0.
a1                      the abscissa of the left end of the interval on the
                          x-axis;
b1                      the abscissa of the right end of the above interval,
                          a1 < b1;
jf0                      the number of the grid node, 0 < jf0 < M, such that
                          at x = jf0*h there takes place the maximum of the
                          initial semi-ellipse pulse;
ul  and ur          are the constants entering the initial
                          condition, the value ul corresponds to the constant
                          background, and ul + ur is the extremal value of the
                          initial function u(x, 0);
M                      the number of the cell whose right boundary coincides
                          with the right boundary x = b1 of the spatial
                          integration interval;
cap                   the Courant number, cap = a*dt/h, where dt is the
                         time step of the difference scheme, and h is the step
                         of the uniform grid in the interval a1 <=x <= b1;
beta                 the weight parameter in the TVD scheme, -1<=beta<= 1;        
bfl                     the coefficient entering the flux limiters;
                        1 <= bfl <= (3 - beta)/(1 - beta);
Npic                 the number of the pictures of the difference solution
                        graphs for Npic moments of time, Npic > 1."
____________________________________________________


:[font = section; inactive; ]
Examples of Input Data
:[font = subsection; inactive; ]
Example 1
:[font = input; nowordwrap; ]

tvd[1.0, 0.0, 2.0, 20, 0.5, 1.0, 300, 0.4, 1.0,
     2.0, 4]

:[font = subsection; inactive; ]
Example 2
:[font = input; nowordwrap; ]

tvd[1.0, 0.0, 2.0, 20, 0.5, 1.0, 300, 0.4, 1/3,
     4.0, 4]

:[font = subsection; inactive; ]
Example 3
:[font = input; startGroup; nowordwrap; ]

tvd[1.0, 0.0, 2.0, 18, 0.5, 1.0, 80, 0.4, 1.0,
     2.0, 4]

:[font = postscript; inactive; output; endGroup; BITMAP; PostScript; pictureLeft = 36; pictureTop = 0; pictureWidth = 476; pictureHeight = 295; nowordwrap; ]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.5 0.0185185 1.47451e-17 0.412175 [
[(30)] .05556 0 0 2 Msboxa
[(40)] .24074 0 0 2 Msboxa
[(50)] .42593 0 0 2 Msboxa
[(60)] .61111 0 0 2 Msboxa
[(70)] .7963 0 0 2 Msboxa
[(80)] .98148 0 0 2 Msboxa
[(x)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .08244 1 0 Msboxa
[(0.4)] -0.0125 .16487 1 0 Msboxa
[(0.6)] -0.0125 .24731 1 0 Msboxa
[(0.8)] -0.0125 .32974 1 0 Msboxa
[(1)] -0.0125 .41218 1 0 Msboxa
[(1.2)] -0.0125 .49461 1 0 Msboxa
[(1.4)] -0.0125 .57705 1 0 Msboxa
[(u)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.05556 0 m
.05556 .00625 L
s
P
[(30)] .05556 0 0 2 Mshowa
p
.002 w
.24074 0 m
.24074 .00625 L
s
P
[(40)] .24074 0 0 2 Mshowa
p
.002 w
.42593 0 m
.42593 .00625 L
s
P
[(50)] .42593 0 0 2 Mshowa
p
.002 w
.61111 0 m
.61111 .00625 L
s
P
[(60)] .61111 0 0 2 Mshowa
p
.002 w
.7963 0 m
.7963 .00625 L
s
P
[(70)] .7963 0 0 2 Mshowa
p
.002 w
.98148 0 m
.98148 .00625 L
s
P
[(80)] .98148 0 0 2 Mshowa
p
.001 w
.09259 0 m
.09259 .00375 L
s
P
p
.001 w
.12963 0 m
.12963 .00375 L
s
P
p
.001 w
.16667 0 m
.16667 .00375 L
s
P
p
.001 w
.2037 0 m
.2037 .00375 L
s
P
p
.001 w
.27778 0 m
.27778 .00375 L
s
P
p
.001 w
.31481 0 m
.31481 .00375 L
s
P
p
.001 w
.35185 0 m
.35185 .00375 L
s
P
p
.001 w
.38889 0 m
.38889 .00375 L
s
P
p
.001 w
.46296 0 m
.46296 .00375 L
s
P
p
.001 w
.5 0 m
.5 .00375 L
s
P
p
.001 w
.53704 0 m
.53704 .00375 L
s
P
p
.001 w
.57407 0 m
.57407 .00375 L
s
P
p
.001 w
.64815 0 m
.64815 .00375 L
s
P
p
.001 w
.68519 0 m
.68519 .00375 L
s
P
p
.001 w
.72222 0 m
.72222 .00375 L
s
P
p
.001 w
.75926 0 m
.75926 .00375 L
s
P
p
.001 w
.83333 0 m
.83333 .00375 L
s
P
p
.001 w
.87037 0 m
.87037 .00375 L
s
P
p
.001 w
.90741 0 m
.90741 .00375 L
s
P
p
.001 w
.94444 0 m
.94444 .00375 L
s
P
p
.001 w
.01852 0 m
.01852 .00375 L
s
P
[(x)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .08244 m
.00625 .08244 L
s
P
[(0.2)] -0.0125 .08244 1 0 Mshowa
p
.002 w
0 .16487 m
.00625 .16487 L
s
P
[(0.4)] -0.0125 .16487 1 0 Mshowa
p
.002 w
0 .24731 m
.00625 .24731 L
s
P
[(0.6)] -0.0125 .24731 1 0 Mshowa
p
.002 w
0 .32974 m
.00625 .32974 L
s
P
[(0.8)] -0.0125 .32974 1 0 Mshowa
p
.002 w
0 .41218 m
.00625 .41218 L
s
P
[(1)] -0.0125 .41218 1 0 Mshowa
p
.002 w
0 .49461 m
.00625 .49461 L
s
P
[(1.2)] -0.0125 .49461 1 0 Mshowa
p
.002 w
0 .57705 m
.00625 .57705 L
s
P
[(1.4)] -0.0125 .57705 1 0 Mshowa
p
.001 w
0 .01649 m
.00375 .01649 L
s
P
p
.001 w
0 .03297 m
.00375 .03297 L
s
P
p
.001 w
0 .04946 m
.00375 .04946 L
s
P
p
.001 w
0 .06595 m
.00375 .06595 L
s
P
p
.001 w
0 .09892 m
.00375 .09892 L
s
P
p
.001 w
0 .11541 m
.00375 .11541 L
s
P
p
.001 w
0 .1319 m
.00375 .1319 L
s
P
p
.001 w
0 .14838 m
.00375 .14838 L
s
P
p
.001 w
0 .18136 m
.00375 .18136 L
s
P
p
.001 w
0 .19784 m
.00375 .19784 L
s
P
p
.001 w
0 .21433 m
.00375 .21433 L
s
P
p
.001 w
0 .23082 m
.00375 .23082 L
s
P
p
.001 w
0 .26379 m
.00375 .26379 L
s
P
p
.001 w
0 .28028 m
.00375 .28028 L
s
P
p
.001 w
0 .29677 m
.00375 .29677 L
s
P
p
.001 w
0 .31325 m
.00375 .31325 L
s
P
p
.001 w
0 .34623 m
.00375 .34623 L
s
P
p
.001 w
0 .36271 m
.00375 .36271 L
s
P
p
.001 w
0 .3792 m
.00375 .3792 L
s
P
p
.001 w
0 .39569 m
.00375 .39569 L
s
P
p
.001 w
0 .42866 m
.00375 .42866 L
s
P
p
.001 w
0 .44515 m
.00375 .44515 L
s
P
p
.001 w
0 .46164 m
.00375 .46164 L
s
P
p
.001 w
0 .47812 m
.00375 .47812 L
s
P
p
.001 w
0 .5111 m
.00375 .5111 L
s
P
p
.001 w
0 .52758 m
.00375 .52758 L
s
P
p
.001 w
0 .54407 m
.00375 .54407 L
s
P
p
.001 w
0 .56056 m
.00375 .56056 L
s
P
p
.001 w
0 .59353 m
.00375 .59353 L
s
P
p
.001 w
0 .61002 m
.00375 .61002 L
s
P
[(u)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
0 1 0 r
.004 w
0 .20609 m
.01852 .20609 L
.03704 .20609 L
.05556 .20609 L
.07407 .20609 L
.09259 .20619 L
.11111 .20976 L
.12963 .30449 L
.14815 .43138 L
.16667 .47375 L
.18519 .50137 L
.2037 .52962 L
.22222 .55731 L
.24074 .58048 L
.25926 .59705 L
.27778 .60739 L
.2963 .61309 L
.31481 .61589 L
.33333 .61711 L
.35185 .61758 L
.37037 .61773 L
.38889 .61777 L
.40741 .61778 L
.42593 .61778 L
.44444 .61777 L
.46296 .61772 L
.48148 .61676 L
.5 .59215 L
.51852 .54817 L
.53704 .53569 L
.55556 .53296 L
.57407 .53168 L
.59259 .52902 L
.61111 .49865 L
.62963 .31487 L
.64815 .23747 L
.66667 .21492 L
.68519 .20855 L
.7037 .20676 L
.72222 .20626 L
.74074 .20613 L
.75926 .2061 L
.77778 .20609 L
.7963 .20609 L
.81481 .20609 L
.83333 .20609 L
.85185 .20609 L
.87037 .20609 L
.88889 .20609 L
.90741 .20609 L
Mistroke
.92593 .20609 L
.94444 .20609 L
.96296 .20609 L
.98148 .20609 L
1 .20609 L
Mfstroke
P
p
[ .04 ] 0 setdash
.004 w
0 .20609 m
.01852 .20609 L
.03704 .20609 L
.05556 .20609 L
.07407 .20609 L
.09259 .20609 L
.11111 .28811 L
.12963 .37393 L
.14815 .42542 L
.16667 .46402 L
.18519 .49495 L
.2037 .52048 L
.22222 .54185 L
.24074 .55981 L
.25926 .57486 L
.27778 .58734 L
.2963 .59751 L
.31481 .60553 L
.33333 .61153 L
.35185 .61561 L
.37037 .61781 L
s
.38148 .61803 m
.37037 .61781 L
s
.39074 .61803 m
.40741 .61671 L
s
.40741 .61671 m
.42593 .61339 L
.44444 .60816 L
.46296 .60096 L
.48148 .59168 L
.5 .58015 L
.51852 .56616 L
.53704 .54941 L
.55556 .52948 L
.57407 .50573 L
.59259 .47715 L
.61111 .442 L
.62963 .39668 L
.64815 .33053 L
.66667 .20609 L
.68519 .20609 L
.7037 .20609 L
.72222 .20609 L
.74074 .20609 L
.75926 .20609 L
.77778 .20609 L
.7963 .20609 L
.81481 .20609 L
.83333 .20609 L
.85185 .20609 L
.87037 .20609 L
.88889 .20609 L
.90741 .20609 L
.92593 .20609 L
.94444 .20609 L
.96296 .20609 L
.98148 .20609 L
1 .20609 L
s
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.07692 0.025641 1.47451e-17 0.412175 [
[(45)] .07692 0 0 2 Msboxa
[(50)] .20513 0 0 2 Msboxa
[(55)] .33333 0 0 2 Msboxa
[(60)] .46154 0 0 2 Msboxa
[(65)] .58974 0 0 2 Msboxa
[(70)] .71795 0 0 2 Msboxa
[(75)] .84615 0 0 2 Msboxa
[(80)] .97436 0 0 2 Msboxa
[(x)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .08244 1 0 Msboxa
[(0.4)] -0.0125 .16487 1 0 Msboxa
[(0.6)] -0.0125 .24731 1 0 Msboxa
[(0.8)] -0.0125 .32974 1 0 Msboxa
[(1)] -0.0125 .41218 1 0 Msboxa
[(1.2)] -0.0125 .49461 1 0 Msboxa
[(1.4)] -0.0125 .57705 1 0 Msboxa
[(u)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.07692 0 m
.07692 .00625 L
s
P
[(45)] .07692 0 0 2 Mshowa
p
.002 w
.20513 0 m
.20513 .00625 L
s
P
[(50)] .20513 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(55)] .33333 0 0 2 Mshowa
p
.002 w
.46154 0 m
.46154 .00625 L
s
P
[(60)] .46154 0 0 2 Mshowa
p
.002 w
.58974 0 m
.58974 .00625 L
s
P
[(65)] .58974 0 0 2 Mshowa
p
.002 w
.71795 0 m
.71795 .00625 L
s
P
[(70)] .71795 0 0 2 Mshowa
p
.002 w
.84615 0 m
.84615 .00625 L
s
P
[(75)] .84615 0 0 2 Mshowa
p
.002 w
.97436 0 m
.97436 .00625 L
s
P
[(80)] .97436 0 0 2 Mshowa
p
.001 w
.10256 0 m
.10256 .00375 L
s
P
p
.001 w
.12821 0 m
.12821 .00375 L
s
P
p
.001 w
.15385 0 m
.15385 .00375 L
s
P
p
.001 w
.17949 0 m
.17949 .00375 L
s
P
p
.001 w
.23077 0 m
.23077 .00375 L
s
P
p
.001 w
.25641 0 m
.25641 .00375 L
s
P
p
.001 w
.28205 0 m
.28205 .00375 L
s
P
p
.001 w
.30769 0 m
.30769 .00375 L
s
P
p
.001 w
.35897 0 m
.35897 .00375 L
s
P
p
.001 w
.38462 0 m
.38462 .00375 L
s
P
p
.001 w
.41026 0 m
.41026 .00375 L
s
P
p
.001 w
.4359 0 m
.4359 .00375 L
s
P
p
.001 w
.48718 0 m
.48718 .00375 L
s
P
p
.001 w
.51282 0 m
.51282 .00375 L
s
P
p
.001 w
.53846 0 m
.53846 .00375 L
s
P
p
.001 w
.5641 0 m
.5641 .00375 L
s
P
p
.001 w
.61538 0 m
.61538 .00375 L
s
P
p
.001 w
.64103 0 m
.64103 .00375 L
s
P
p
.001 w
.66667 0 m
.66667 .00375 L
s
P
p
.001 w
.69231 0 m
.69231 .00375 L
s
P
p
.001 w
.74359 0 m
.74359 .00375 L
s
P
p
.001 w
.76923 0 m
.76923 .00375 L
s
P
p
.001 w
.79487 0 m
.79487 .00375 L
s
P
p
.001 w
.82051 0 m
.82051 .00375 L
s
P
p
.001 w
.87179 0 m
.87179 .00375 L
s
P
p
.001 w
.89744 0 m
.89744 .00375 L
s
P
p
.001 w
.92308 0 m
.92308 .00375 L
s
P
p
.001 w
.94872 0 m
.94872 .00375 L
s
P
p
.001 w
.05128 0 m
.05128 .00375 L
s
P
p
.001 w
.02564 0 m
.02564 .00375 L
s
P
[(x)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .08244 m
.00625 .08244 L
s
P
[(0.2)] -0.0125 .08244 1 0 Mshowa
p
.002 w
0 .16487 m
.00625 .16487 L
s
P
[(0.4)] -0.0125 .16487 1 0 Mshowa
p
.002 w
0 .24731 m
.00625 .24731 L
s
P
[(0.6)] -0.0125 .24731 1 0 Mshowa
p
.002 w
0 .32974 m
.00625 .32974 L
s
P
[(0.8)] -0.0125 .32974 1 0 Mshowa
p
.002 w
0 .41218 m
.00625 .41218 L
s
P
[(1)] -0.0125 .41218 1 0 Mshowa
p
.002 w
0 .49461 m
.00625 .49461 L
s
P
[(1.2)] -0.0125 .49461 1 0 Mshowa
p
.002 w
0 .57705 m
.00625 .57705 L
s
P
[(1.4)] -0.0125 .57705 1 0 Mshowa
p
.001 w
0 .01649 m
.00375 .01649 L
s
P
p
.001 w
0 .03297 m
.00375 .03297 L
s
P
p
.001 w
0 .04946 m
.00375 .04946 L
s
P
p
.001 w
0 .06595 m
.00375 .06595 L
s
P
p
.001 w
0 .09892 m
.00375 .09892 L
s
P
p
.001 w
0 .11541 m
.00375 .11541 L
s
P
p
.001 w
0 .1319 m
.00375 .1319 L
s
P
p
.001 w
0 .14838 m
.00375 .14838 L
s
P
p
.001 w
0 .18136 m
.00375 .18136 L
s
P
p
.001 w
0 .19784 m
.00375 .19784 L
s
P
p
.001 w
0 .21433 m
.00375 .21433 L
s
P
p
.001 w
0 .23082 m
.00375 .23082 L
s
P
p
.001 w
0 .26379 m
.00375 .26379 L
s
P
p
.001 w
0 .28028 m
.00375 .28028 L
s
P
p
.001 w
0 .29677 m
.00375 .29677 L
s
P
p
.001 w
0 .31325 m
.00375 .31325 L
s
P
p
.001 w
0 .34623 m
.00375 .34623 L
s
P
p
.001 w
0 .36271 m
.00375 .36271 L
s
P
p
.001 w
0 .3792 m
.00375 .3792 L
s
P
p
.001 w
0 .39569 m
.00375 .39569 L
s
P
p
.001 w
0 .42866 m
.00375 .42866 L
s
P
p
.001 w
0 .44515 m
.00375 .44515 L
s
P
p
.001 w
0 .46164 m
.00375 .46164 L
s
P
p
.001 w
0 .47812 m
.00375 .47812 L
s
P
p
.001 w
0 .5111 m
.00375 .5111 L
s
P
p
.001 w
0 .52758 m
.00375 .52758 L
s
P
p
.001 w
0 .54407 m
.00375 .54407 L
s
P
p
.001 w
0 .56056 m
.00375 .56056 L
s
P
p
.001 w
0 .59353 m
.00375 .59353 L
s
P
p
.001 w
0 .61002 m
.00375 .61002 L
s
P
[(u)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
0 1 0 r
.004 w
0 .20609 m
.02564 .20609 L
.05128 .20609 L
.07692 .20609 L
.10256 .2061 L
.12821 .20644 L
.15385 .21727 L
.17949 .34307 L
.20513 .44457 L
.23077 .49904 L
.25641 .53962 L
.28205 .56996 L
.30769 .59077 L
.33333 .6037 L
.35897 .61101 L
.38462 .61477 L
.41026 .61655 L
.4359 .61732 L
.46154 .61762 L
.48718 .61773 L
.51282 .61776 L
.53846 .61777 L
.5641 .61777 L
.58974 .61777 L
.61538 .61777 L
.64103 .61753 L
.66667 .60657 L
.69231 .55864 L
.71795 .54204 L
.74359 .53855 L
.76923 .53762 L
.79487 .53621 L
.82051 .52575 L
.84615 .38037 L
.87179 .25295 L
.89744 .21912 L
.92308 .2097 L
.94872 .20708 L
.97436 .20636 L
1 .20615 L
s
P
p
[ .04 ] 0 setdash
.004 w
0 .20609 m
.02564 .20609 L
.05128 .20609 L
.07692 .20609 L
.10256 .20609 L
.12821 .20609 L
.15385 .34671 L
.17949 .40687 L
.20513 .44969 L
.23077 .48332 L
.25641 .51083 L
.28205 .53375 L
.30769 .553 L
.33333 .56917 L
.35897 .58264 L
.38462 .59371 L
.41026 .60257 L
.4359 .60936 L
.46154 .6142 L
.48718 .61715 L
s
.5077 .61803 m
.48718 .61715 L
s
.52051 .61803 m
.53846 .61752 L
s
.53846 .61752 m
.5641 .61494 L
.58974 .61049 L
.61538 .60409 L
.64103 .59565 L
.66667 .58504 L
.69231 .57207 L
.71795 .55647 L
.74359 .53787 L
.76923 .51574 L
.79487 .48925 L
.82051 .45701 L
.84615 .41642 L
.87179 .36102 L
.89744 .2536 L
.92308 .20609 L
.94872 .20609 L
.97436 .20609 L
1 .20609 L
s
P
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0125 0.0125 1.47451e-17 0.412175 [
[(10)] .1125 0 0 2 Msboxa
[(20)] .2375 0 0 2 Msboxa
[(30)] .3625 0 0 2 Msboxa
[(40)] .4875 0 0 2 Msboxa
[(50)] .6125 0 0 2 Msboxa
[(60)] .7375 0 0 2 Msboxa
[(70)] .8625 0 0 2 Msboxa
[(80)] .9875 0 0 2 Msboxa
[(x)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .08244 1 0 Msboxa
[(0.4)] -0.0125 .16487 1 0 Msboxa
[(0.6)] -0.0125 .24731 1 0 Msboxa
[(0.8)] -0.0125 .32974 1 0 Msboxa
[(1)] -0.0125 .41218 1 0 Msboxa
[(1.2)] -0.0125 .49461 1 0 Msboxa
[(1.4)] -0.0125 .57705 1 0 Msboxa
[(u)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.1125 0 m
.1125 .00625 L
s
P
[(10)] .1125 0 0 2 Mshowa
p
.002 w
.2375 0 m
.2375 .00625 L
s
P
[(20)] .2375 0 0 2 Mshowa
p
.002 w
.3625 0 m
.3625 .00625 L
s
P
[(30)] .3625 0 0 2 Mshowa
p
.002 w
.4875 0 m
.4875 .00625 L
s
P
[(40)] .4875 0 0 2 Mshowa
p
.002 w
.6125 0 m
.6125 .00625 L
s
P
[(50)] .6125 0 0 2 Mshowa
p
.002 w
.7375 0 m
.7375 .00625 L
s
P
[(60)] .7375 0 0 2 Mshowa
p
.002 w
.8625 0 m
.8625 .00625 L
s
P
[(70)] .8625 0 0 2 Mshowa
p
.002 w
.9875 0 m
.9875 .00625 L
s
P
[(80)] .9875 0 0 2 Mshowa
p
.001 w
.1375 0 m
.1375 .00375 L
s
P
p
.001 w
.1625 0 m
.1625 .00375 L
s
P
p
.001 w
.1875 0 m
.1875 .00375 L
s
P
p
.001 w
.2125 0 m
.2125 .00375 L
s
P
p
.001 w
.2625 0 m
.2625 .00375 L
s
P
p
.001 w
.2875 0 m
.2875 .00375 L
s
P
p
.001 w
.3125 0 m
.3125 .00375 L
s
P
p
.001 w
.3375 0 m
.3375 .00375 L
s
P
p
.001 w
.3875 0 m
.3875 .00375 L
s
P
p
.001 w
.4125 0 m
.4125 .00375 L
s
P
p
.001 w
.4375 0 m
.4375 .00375 L
s
P
p
.001 w
.4625 0 m
.4625 .00375 L
s
P
p
.001 w
.5125 0 m
.5125 .00375 L
s
P
p
.001 w
.5375 0 m
.5375 .00375 L
s
P
p
.001 w
.5625 0 m
.5625 .00375 L
s
P
p
.001 w
.5875 0 m
.5875 .00375 L
s
P
p
.001 w
.6375 0 m
.6375 .00375 L
s
P
p
.001 w
.6625 0 m
.6625 .00375 L
s
P
p
.001 w
.6875 0 m
.6875 .00375 L
s
P
p
.001 w
.7125 0 m
.7125 .00375 L
s
P
p
.001 w
.7625 0 m
.7625 .00375 L
s
P
p
.001 w
.7875 0 m
.7875 .00375 L
s
P
p
.001 w
.8125 0 m
.8125 .00375 L
s
P
p
.001 w
.8375 0 m
.8375 .00375 L
s
P
p
.001 w
.8875 0 m
.8875 .00375 L
s
P
p
.001 w
.9125 0 m
.9125 .00375 L
s
P
p
.001 w
.9375 0 m
.9375 .00375 L
s
P
p
.001 w
.9625 0 m
.9625 .00375 L
s
P
p
.001 w
.0875 0 m
.0875 .00375 L
s
P
p
.001 w
.0625 0 m
.0625 .00375 L
s
P
p
.001 w
.0375 0 m
.0375 .00375 L
s
P
p
.001 w
.0125 0 m
.0125 .00375 L
s
P
[(x)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .08244 m
.00625 .08244 L
s
P
[(0.2)] -0.0125 .08244 1 0 Mshowa
p
.002 w
0 .16487 m
.00625 .16487 L
s
P
[(0.4)] -0.0125 .16487 1 0 Mshowa
p
.002 w
0 .24731 m
.00625 .24731 L
s
P
[(0.6)] -0.0125 .24731 1 0 Mshowa
p
.002 w
0 .32974 m
.00625 .32974 L
s
P
[(0.8)] -0.0125 .32974 1 0 Mshowa
p
.002 w
0 .41218 m
.00625 .41218 L
s
P
[(1)] -0.0125 .41218 1 0 Mshowa
p
.002 w
0 .49461 m
.00625 .49461 L
s
P
[(1.2)] -0.0125 .49461 1 0 Mshowa
p
.002 w
0 .57705 m
.00625 .57705 L
s
P
[(1.4)] -0.0125 .57705 1 0 Mshowa
p
.001 w
0 .01649 m
.00375 .01649 L
s
P
p
.001 w
0 .03297 m
.00375 .03297 L
s
P
p
.001 w
0 .04946 m
.00375 .04946 L
s
P
p
.001 w
0 .06595 m
.00375 .06595 L
s
P
p
.001 w
0 .09892 m
.00375 .09892 L
s
P
p
.001 w
0 .11541 m
.00375 .11541 L
s
P
p
.001 w
0 .1319 m
.00375 .1319 L
s
P
p
.001 w
0 .14838 m
.00375 .14838 L
s
P
p
.001 w
0 .18136 m
.00375 .18136 L
s
P
p
.001 w
0 .19784 m
.00375 .19784 L
s
P
p
.001 w
0 .21433 m
.00375 .21433 L
s
P
p
.001 w
0 .23082 m
.00375 .23082 L
s
P
p
.001 w
0 .26379 m
.00375 .26379 L
s
P
p
.001 w
0 .28028 m
.00375 .28028 L
s
P
p
.001 w
0 .29677 m
.00375 .29677 L
s
P
p
.001 w
0 .31325 m
.00375 .31325 L
s
P
p
.001 w
0 .34623 m
.00375 .34623 L
s
P
p
.001 w
0 .36271 m
.00375 .36271 L
s
P
p
.001 w
0 .3792 m
.00375 .3792 L
s
P
p
.001 w
0 .39569 m
.00375 .39569 L
s
P
p
.001 w
0 .42866 m
.00375 .42866 L
s
P
p
.001 w
0 .44515 m
.00375 .44515 L
s
P
p
.001 w
0 .46164 m
.00375 .46164 L
s
P
p
.001 w
0 .47812 m
.00375 .47812 L
s
P
p
.001 w
0 .5111 m
.00375 .5111 L
s
P
p
.001 w
0 .52758 m
.00375 .52758 L
s
P
p
.001 w
0 .54407 m
.00375 .54407 L
s
P
p
.001 w
0 .56056 m
.00375 .56056 L
s
P
p
.001 w
0 .59353 m
.00375 .59353 L
s
P
p
.001 w
0 .61002 m
.00375 .61002 L
s
P
[(u)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
0 1 0 r
.004 w
0 .20609 m
.0125 .20609 L
.025 .20609 L
.0375 .31162 L
.05 .38575 L
.0625 .43393 L
.075 .47072 L
.0875 .50044 L
.1 .52506 L
.1125 .5457 L
.125 .56304 L
.1375 .57755 L
.15 .58956 L
.1625 .59928 L
.175 .60689 L
.1875 .6125 L
.2 .6162 L
.2125 .61803 L
.225 .61803 L
.2375 .6162 L
.25 .6125 L
.2625 .60689 L
.275 .59928 L
.2875 .58956 L
.3 .57755 L
.3125 .56304 L
.325 .5457 L
.3375 .52506 L
.35 .50044 L
.3625 .47072 L
.375 .43393 L
.3875 .38575 L
.4 .31162 L
.4125 .20609 L
.425 .20609 L
.4375 .20609 L
.45 .20609 L
.4625 .20609 L
.475 .20609 L
.4875 .20609 L
.5 .20609 L
.5125 .20609 L
.525 .20609 L
.5375 .20609 L
.55 .20609 L
.5625 .20609 L
.575 .20609 L
.5875 .20609 L
.6 .20609 L
.6125 .20609 L
Mistroke
.625 .20609 L
.6375 .20609 L
.65 .20609 L
.6625 .20609 L
.675 .20609 L
.6875 .20609 L
.7 .20609 L
.7125 .20609 L
.725 .20609 L
.7375 .20609 L
.75 .20609 L
.7625 .20609 L
.775 .20609 L
.7875 .20609 L
.8 .20609 L
.8125 .20609 L
.825 .20609 L
.8375 .20609 L
.85 .20609 L
.8625 .20609 L
.875 .20609 L
.8875 .20609 L
.9 .20609 L
.9125 .20609 L
.925 .20609 L
.9375 .20609 L
.95 .20609 L
.9625 .20609 L
.975 .20609 L
.9875 .20609 L
1 .20609 L
Mfstroke
P
p
[ .04 ] 0 setdash
.004 w
0 .20609 m
.0125 .20609 L
.025 .20609 L
.0375 .31162 L
.05 .38575 L
.0625 .43393 L
.075 .47072 L
.0875 .50044 L
.1 .52506 L
.1125 .5457 L
.125 .56304 L
.1375 .57755 L
.15 .58956 L
.1625 .59928 L
.175 .60689 L
.1875 .6125 L
.2 .6162 L
.2125 .61803 L
.225 .61803 L
.2375 .6162 L
.25 .6125 L
.2625 .60689 L
.275 .59928 L
.2875 .58956 L
.3 .57755 L
.3125 .56304 L
.325 .5457 L
.3375 .52506 L
.35 .50044 L
.3625 .47072 L
.375 .43393 L
.3875 .38575 L
.4 .31162 L
.4125 .20609 L
.425 .20609 L
.4375 .20609 L
.45 .20609 L
.4625 .20609 L
.475 .20609 L
.4875 .20609 L
.5 .20609 L
.5125 .20609 L
.525 .20609 L
.5375 .20609 L
.55 .20609 L
.5625 .20609 L
.575 .20609 L
.5875 .20609 L
.6 .20609 L
.6125 .20609 L
Mistroke
.625 .20609 L
.6375 .20609 L
.65 .20609 L
.6625 .20609 L
.675 .20609 L
.6875 .20609 L
.7 .20609 L
.7125 .20609 L
.725 .20609 L
.7375 .20609 L
.75 .20609 L
.7625 .20609 L
.775 .20609 L
.7875 .20609 L
.8 .20609 L
.8125 .20609 L
.825 .20609 L
.8375 .20609 L
.85 .20609 L
.8625 .20609 L
.875 .20609 L
.8875 .20609 L
.9 .20609 L
.9125 .20609 L
.925 .20609 L
.9375 .20609 L
.95 .20609 L
.9625 .20609 L
.975 .20609 L
.9875 .20609 L
1 .20609 L
Mfstroke
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.173913 0.0144928 1.47451e-17 0.412175 [
[(20)] .11594 0 0 2 Msboxa
[(30)] .26087 0 0 2 Msboxa
[(40)] .4058 0 0 2 Msboxa
[(50)] .55072 0 0 2 Msboxa
[(60)] .69565 0 0 2 Msboxa
[(70)] .84058 0 0 2 Msboxa
[(80)] .98551 0 0 2 Msboxa
[(x)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .08244 1 0 Msboxa
[(0.4)] -0.0125 .16487 1 0 Msboxa
[(0.6)] -0.0125 .24731 1 0 Msboxa
[(0.8)] -0.0125 .32974 1 0 Msboxa
[(1)] -0.0125 .41218 1 0 Msboxa
[(1.2)] -0.0125 .49461 1 0 Msboxa
[(1.4)] -0.0125 .57705 1 0 Msboxa
[(u)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.11594 0 m
.11594 .00625 L
s
P
[(20)] .11594 0 0 2 Mshowa
p
.002 w
.26087 0 m
.26087 .00625 L
s
P
[(30)] .26087 0 0 2 Mshowa
p
.002 w
.4058 0 m
.4058 .00625 L
s
P
[(40)] .4058 0 0 2 Mshowa
p
.002 w
.55072 0 m
.55072 .00625 L
s
P
[(50)] .55072 0 0 2 Mshowa
p
.002 w
.69565 0 m
.69565 .00625 L
s
P
[(60)] .69565 0 0 2 Mshowa
p
.002 w
.84058 0 m
.84058 .00625 L
s
P
[(70)] .84058 0 0 2 Mshowa
p
.002 w
.98551 0 m
.98551 .00625 L
s
P
[(80)] .98551 0 0 2 Mshowa
p
.001 w
.14493 0 m
.14493 .00375 L
s
P
p
.001 w
.17391 0 m
.17391 .00375 L
s
P
p
.001 w
.2029 0 m
.2029 .00375 L
s
P
p
.001 w
.23188 0 m
.23188 .00375 L
s
P
p
.001 w
.28986 0 m
.28986 .00375 L
s
P
p
.001 w
.31884 0 m
.31884 .00375 L
s
P
p
.001 w
.34783 0 m
.34783 .00375 L
s
P
p
.001 w
.37681 0 m
.37681 .00375 L
s
P
p
.001 w
.43478 0 m
.43478 .00375 L
s
P
p
.001 w
.46377 0 m
.46377 .00375 L
s
P
p
.001 w
.49275 0 m
.49275 .00375 L
s
P
p
.001 w
.52174 0 m
.52174 .00375 L
s
P
p
.001 w
.57971 0 m
.57971 .00375 L
s
P
p
.001 w
.6087 0 m
.6087 .00375 L
s
P
p
.001 w
.63768 0 m
.63768 .00375 L
s
P
p
.001 w
.66667 0 m
.66667 .00375 L
s
P
p
.001 w
.72464 0 m
.72464 .00375 L
s
P
p
.001 w
.75362 0 m
.75362 .00375 L
s
P
p
.001 w
.78261 0 m
.78261 .00375 L
s
P
p
.001 w
.81159 0 m
.81159 .00375 L
s
P
p
.001 w
.86957 0 m
.86957 .00375 L
s
P
p
.001 w
.89855 0 m
.89855 .00375 L
s
P
p
.001 w
.92754 0 m
.92754 .00375 L
s
P
p
.001 w
.95652 0 m
.95652 .00375 L
s
P
p
.001 w
.08696 0 m
.08696 .00375 L
s
P
p
.001 w
.05797 0 m
.05797 .00375 L
s
P
p
.001 w
.02899 0 m
.02899 .00375 L
s
P
[(x)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .08244 m
.00625 .08244 L
s
P
[(0.2)] -0.0125 .08244 1 0 Mshowa
p
.002 w
0 .16487 m
.00625 .16487 L
s
P
[(0.4)] -0.0125 .16487 1 0 Mshowa
p
.002 w
0 .24731 m
.00625 .24731 L
s
P
[(0.6)] -0.0125 .24731 1 0 Mshowa
p
.002 w
0 .32974 m
.00625 .32974 L
s
P
[(0.8)] -0.0125 .32974 1 0 Mshowa
p
.002 w
0 .41218 m
.00625 .41218 L
s
P
[(1)] -0.0125 .41218 1 0 Mshowa
p
.002 w
0 .49461 m
.00625 .49461 L
s
P
[(1.2)] -0.0125 .49461 1 0 Mshowa
p
.002 w
0 .57705 m
.00625 .57705 L
s
P
[(1.4)] -0.0125 .57705 1 0 Mshowa
p
.001 w
0 .01649 m
.00375 .01649 L
s
P
p
.001 w
0 .03297 m
.00375 .03297 L
s
P
p
.001 w
0 .04946 m
.00375 .04946 L
s
P
p
.001 w
0 .06595 m
.00375 .06595 L
s
P
p
.001 w
0 .09892 m
.00375 .09892 L
s
P
p
.001 w
0 .11541 m
.00375 .11541 L
s
P
p
.001 w
0 .1319 m
.00375 .1319 L
s
P
p
.001 w
0 .14838 m
.00375 .14838 L
s
P
p
.001 w
0 .18136 m
.00375 .18136 L
s
P
p
.001 w
0 .19784 m
.00375 .19784 L
s
P
p
.001 w
0 .21433 m
.00375 .21433 L
s
P
p
.001 w
0 .23082 m
.00375 .23082 L
s
P
p
.001 w
0 .26379 m
.00375 .26379 L
s
P
p
.001 w
0 .28028 m
.00375 .28028 L
s
P
p
.001 w
0 .29677 m
.00375 .29677 L
s
P
p
.001 w
0 .31325 m
.00375 .31325 L
s
P
p
.001 w
0 .34623 m
.00375 .34623 L
s
P
p
.001 w
0 .36271 m
.00375 .36271 L
s
P
p
.001 w
0 .3792 m
.00375 .3792 L
s
P
p
.001 w
0 .39569 m
.00375 .39569 L
s
P
p
.001 w
0 .42866 m
.00375 .42866 L
s
P
p
.001 w
0 .44515 m
.00375 .44515 L
s
P
p
.001 w
0 .46164 m
.00375 .46164 L
s
P
p
.001 w
0 .47812 m
.00375 .47812 L
s
P
p
.001 w
0 .5111 m
.00375 .5111 L
s
P
p
.001 w
0 .52758 m
.00375 .52758 L
s
P
p
.001 w
0 .54407 m
.00375 .54407 L
s
P
p
.001 w
0 .56056 m
.00375 .56056 L
s
P
p
.001 w
0 .59353 m
.00375 .59353 L
s
P
p
.001 w
0 .61002 m
.00375 .61002 L
s
P
[(u)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
0 1 0 r
.004 w
0 .20609 m
.01449 .20609 L
.02899 .20609 L
.04348 .20609 L
.05797 .20609 L
.07246 .20613 L
.08696 .20774 L
.10145 .25806 L
.11594 .38994 L
.13043 .45227 L
.14493 .49122 L
.15942 .51813 L
.17391 .53704 L
.18841 .5537 L
.2029 .57109 L
.21739 .58784 L
.23188 .6012 L
.24638 .60993 L
.26087 .61463 L
.27536 .61673 L
.28986 .61751 L
.30435 .61775 L
.31884 .6178 L
.33333 .61781 L
.34783 .61772 L
.36232 .61368 L
.37681 .60281 L
.3913 .5986 L
.4058 .59154 L
.42029 .55541 L
.43478 .52952 L
.44928 .52252 L
.46377 .51904 L
.47826 .51219 L
.49275 .44774 L
.50725 .28843 L
.52174 .23013 L
.53623 .21274 L
.55072 .20778 L
.56522 .20648 L
.57971 .20617 L
.5942 .2061 L
.6087 .20609 L
.62319 .20609 L
.63768 .20609 L
.65217 .20609 L
.66667 .20609 L
.68116 .20609 L
.69565 .20609 L
.71014 .20609 L
Mistroke
.72464 .20609 L
.73913 .20609 L
.75362 .20609 L
.76812 .20609 L
.78261 .20609 L
.7971 .20609 L
.81159 .20609 L
.82609 .20609 L
.84058 .20609 L
.85507 .20609 L
.86957 .20609 L
.88406 .20609 L
.89855 .20609 L
.91304 .20609 L
.92754 .20609 L
.94203 .20609 L
.95652 .20609 L
.97101 .20609 L
.98551 .20609 L
1 .20609 L
Mfstroke
P
p
[ .04 ] 0 setdash
.004 w
0 .20609 m
.01449 .20609 L
.02899 .20609 L
.04348 .20609 L
.05797 .20609 L
.07246 .20609 L
.08696 .20609 L
.10145 .33053 L
.11594 .39668 L
.13043 .442 L
.14493 .47715 L
.15942 .50573 L
.17391 .52948 L
.18841 .54941 L
.2029 .56616 L
.21739 .58015 L
.23188 .59168 L
.24638 .60096 L
.26087 .60816 L
.27536 .61339 L
.28986 .61671 L
s
.3029 .61803 m
.28986 .61671 L
s
.31014 .61803 m
.31884 .61781 L
s
.31884 .61781 m
.33333 .61561 L
.34783 .61153 L
.36232 .60553 L
.37681 .59751 L
.3913 .58734 L
.4058 .57486 L
.42029 .55981 L
.43478 .54185 L
.44928 .52048 L
.46377 .49495 L
.47826 .46402 L
.49275 .42542 L
.50725 .37393 L
.52174 .28811 L
.53623 .20609 L
.55072 .20609 L
.56522 .20609 L
.57971 .20609 L
.5942 .20609 L
.6087 .20609 L
.62319 .20609 L
.63768 .20609 L
.65217 .20609 L
.66667 .20609 L
.68116 .20609 L
.69565 .20609 L
.71014 .20609 L
.72464 .20609 L
.73913 .20609 L
.75362 .20609 L
.76812 .20609 L
.78261 .20609 L
.7971 .20609 L
.81159 .20609 L
.82609 .20609 L
.84058 .20609 L
.85507 .20609 L
.86957 .20609 L
.88406 .20609 L
.89855 .20609 L
.91304 .20609 L
.92754 .20609 L
.94203 .20609 L
.95652 .20609 L
.97101 .20609 L
.98551 .20609 L
1 .20609 L
s
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
:[font = section; inactive; ]
The Structure of the Output
:[font = special4; inactive; nowordwrap; nohscroll; ]

The following data are printed out in the process of the work of the
program:

1. um = ul + ur;

2. The maximum number of time steps to be computed (the actual
     number of the executed time steps can be smaller);

3. The current values of n, the time step number, and the time t;
                                                           n      n
4. The numerical solution graphs u   = u  (x) for Npic fixed moments
    of time; the values of these times are printed out in the message
    like
                      The solution graph at t = 0.

    To resize an individual picture obtained by Mathematica, please

(i) Click anywhere inside the cell, but not the cell bracket itself. A bo-
     unding  box with small handles appears around the graphic image.

(ii) Drag one of the handles to adjust the size and shape of the bound-
     ing box. In this way it is possible to resize the height and width of
     the graphic image.


^*)